@@ -103,7 +103,8 @@ class CActions : public QObject
         void funcDistance();
         void funcCombineDistOvl();
 
-        void funcDiary();
+//        void funcDiary();
+        void funcOcm();
         void funcColorPicker();
         void funcWorldBasemap();
 
