@@ -136,7 +136,7 @@ class CCanvas : public QWidget
         void slotCopyPosition();
         void slotHighlightTrack(CTrack * track);
         void slotTrackChanged();
-        void slotActiveTrackPoint(double dist);
+        void slotFocusTrackPoint(double dist);
 
     protected:
         void paintEvent(QPaintEvent * e);
