@@ -170,6 +170,8 @@ CDiaryEdit::CDiaryEdit(CDiary& diary, QWidget * parent)
     checkProfile->setChecked(cfg.value("diary/showProfiles", true).toBool());
     connect(checkProfile, SIGNAL(clicked()), this, SLOT(slotIntReload()));
 
+    checkAddMap->setChecked(cfg.value("diary/addMapView", true).toBool());
+
 }
 
 CDiaryEdit::~CDiaryEdit()
@@ -179,6 +181,7 @@ CDiaryEdit::~CDiaryEdit()
     QSettings cfg;
     cfg.setValue("diary/showGeoCaches", checkGeoCache->isChecked());
     cfg.setValue("diary/showProfiles", checkProfile->isChecked());
+    cfg.setValue("diary/addMapView", checkAddMap->isChecked());
 }
 
 
@@ -213,6 +216,22 @@ void CDiaryEdit::resizeEvent(QResizeEvent * e)
     draw(*textEdit->document());
 }
 
+void CDiaryEdit::closeEvent(QCloseEvent * e)
+{
+    if(diary.isModified())
+    {
+        QMessageBox::Button res = QMessageBox::warning(this, tr("Diary modified..."), tr("The diary is modified. Do you want to save it?"), QMessageBox::Yes|QMessageBox::No,QMessageBox::Yes);
+
+        if(res == QMessageBox::Yes)
+        {
+            slotSave();
+        }
+    }
+
+
+    QWidget::closeEvent(e);
+}
+
 void CDiaryEdit::setWindowModified()
 {
     setWindowModified(true);
@@ -287,10 +306,12 @@ void CDiaryEdit::slotPrintPreview()
     doc.setPageSize(pageSize);
     draw(doc);
 
-    QImage img;
-    theMainWindow->getCanvas()->print(img, pageSize.toSize() - QSize(10,10));
-
-    doc.rootFrame()->lastCursorPosition().insertImage(img);
+    if(checkAddMap->isChecked())
+    {
+        QImage img;
+        theMainWindow->getCanvas()->print(img, pageSize.toSize() - QSize(10,10));
+        doc.rootFrame()->lastCursorPosition().insertImage(img);
+    }
     doc.print(&printer);
 
     textEdit->clear();
@@ -494,8 +515,23 @@ void CDiaryEdit::setTabTitle()
     }
 }
 
+static bool qSortWptLessName(CWpt * p1, CWpt * p2)
+{
+
+    QString name1 = p1->isGeoCache() ? p1->getGeocacheData().name : p1->getName();
+    QString name2 = p2->isGeoCache() ? p2->getGeocacheData().name : p2->getName();
+
+    return name1.toUpper() < name2.toUpper();
+}
+
+
 static bool qSortWptLessTime(CWpt * p1, CWpt * p2)
 {
+    if(p1->getTimestamp() == p2->getTimestamp())
+    {
+        return qSortWptLessName(p1,p2);
+    }
+
     return p1->getTimestamp() < p2->getTimestamp();
 }
 
@@ -664,7 +700,9 @@ void CDiaryEdit::draw(QTextDocument& doc)
             table->cellAt(cnt,eInfo).firstCursorPosition().insertText(trk->getInfo(), fmtCharStandard);
             if(checkProfile->isChecked())
             {
-                QImage profile(fm.width("X") * 30,fm.height()*7,QImage::Format_ARGB32);
+                quint32 w =  doc.textWidth();
+                //QImage profile(fm.width("X") * 30,fm.height()*7,QImage::Format_ARGB32);
+                QImage profile(w/2.5,(w * 6)/(16 * 2.5),QImage::Format_ARGB32);
                 getTrackProfile(trk, profile);
                 table->cellAt(cnt,eInfo).lastCursorPosition().insertBlock(fmtBlockStandard);
                 table->cellAt(cnt,eInfo).lastCursorPosition().insertImage(profile);
@@ -714,7 +752,6 @@ void CDiaryEdit::getTrackProfile(CTrack * track, QImage& image)
 {
     CPlot plot(CPlotData::eLinear, CPlot::eNormal, 0);
     plot.hide();
-    plot.resize(image.size());
     plot.clear();
 
 
@@ -745,8 +782,7 @@ void CDiaryEdit::getTrackProfile(CTrack * track, QImage& image)
     plot.resetZoom();
 
     QPainter p(&image);
-    USE_ANTI_ALIASING(p,true);
-    plot.draw(p);
+    plot.draw(p,image.size());
 
 }
 
@@ -797,7 +833,10 @@ void CDiaryEdit::collectData()
 
         foreach(CWpt* wpt, wpts)
         {
-            wpt->setComment(QLGT::QTextHtmlExporter(textEdit->document()).toHtml(diary.tblWpt->cellAt(cnt, 2)));
+            if(cnt < diary.tblWpt->columns())
+            {
+                wpt->setComment(QLGT::QTextHtmlExporter(textEdit->document()).toHtml(diary.tblWpt->cellAt(cnt, 2)));
+            }
             cnt++;
         }
     }
@@ -810,7 +849,10 @@ void CDiaryEdit::collectData()
 
         foreach(CTrack* trk, trks)
         {
-            trk->setComment(QLGT::QTextHtmlExporter(textEdit->document()).toHtml(diary.tblTrk->cellAt(cnt, 2)));
+            if(cnt < diary.tblTrk->columns())
+            {
+                trk->setComment(QLGT::QTextHtmlExporter(textEdit->document()).toHtml(diary.tblTrk->cellAt(cnt, 2)));
+            }
             cnt++;
         }
     }
