@@ -46,10 +46,11 @@ CDlgConfig::CDlgConfig(QWidget * parent)
 
 #ifndef HAS_GEODB
     groupBoxGeoDB->hide();
+    connect(toolPathGeoDB, SIGNAL(clicked()),this,SLOT(slotSelectPathGeoDB()));
+    connect(checkUseGeoDB, SIGNAL(clicked(bool)), groupSaveWks, SLOT(setEnabled(bool)));
+    connect(checkGeoDBSaveOnExit, SIGNAL(clicked(bool)), spinGeoDBMinutes, SLOT(setEnabled(bool)));
 #endif
 
-    connect(toolPathGeoDB, SIGNAL(clicked()),this,SLOT(slotSelectPathGeoDB()));
-    connect(checkUseGeoDB, SIGNAL(clicked(bool)), checkGeoDBSaveOnExit, SLOT(setEnabled(bool)));
 }
 
 
@@ -87,17 +88,18 @@ void CDlgConfig::exec()
     checkShowNorth->setChecked(resources.m_showNorth);
     checkShowScale->setChecked(resources.m_showScale);
     checkTooltip->setChecked(resources.m_showToolTip);
-    checkShowTrackMax->setChecked(resources.m_showTrackMax);
     checkShowZoomLevel->setChecked(resources.m_showZoomLevel);
     checkAntiAliasing->setChecked(resources.m_useAntiAliasing);
     checkReducePoiIcons->setChecked(resources.m_reducePoiIcons);
 #ifdef HAS_GEODB
     checkUseGeoDB->setChecked(resources.m_useGeoDB);
-    checkGeoDBSaveOnExit->setEnabled(resources.m_useGeoDB);
+    groupSaveWks->setEnabled(resources.m_useGeoDB);
     checkGeoDBSaveOnExit->setChecked(resources.m_saveGeoDBOnExit);
+    spinGeoDBMinutes->setValue(resources.m_saveGeoDBMinutes);
     labelPathGeoDB->setText(resources.m_pathGeoDB.absolutePath());
 #endif
 
+
     comboDevice->addItem(tr(""),"");
     comboDevice->addItem(tr("QLandkarte M"), "QLandkarteM");
     comboDevice->addItem(tr("Garmin"), "Garmin");
@@ -126,7 +128,7 @@ void CDlgConfig::exec()
     lineDevIPPort->setText(QString::number(resources.m_devIPPort));
     lineDevSerialPort->setText(resources.m_devSerialPort);
 #ifdef Q_OS_WIN32
-    lineDevSerialPort->setToolTip(tr("Pass something like \"COM1:\" or \"\\\\.\\COM13\" for serial Garmin devices or NMEA devices. For Garmin USB devices leave blank."));
+    lineDevSerialPort->setToolTip(tr("Pass something like \"COM1:\" or \"\\\\.\\COM13\" or \"\\\\.\\com13\" for serial Garmin devices or NMEA devices. For Garmin USB devices leave blank."));
 #endif
 
     checkDownloadTrk->setChecked(IDevice::m_DownloadAllTrk);
@@ -175,7 +177,6 @@ void CDlgConfig::accept()
     resources.m_showNorth       = checkShowNorth->isChecked();
     resources.m_showScale       = checkShowScale->isChecked();
     resources.m_showToolTip     = checkTooltip->isChecked();
-    resources.m_showTrackMax    = checkShowTrackMax->isChecked();
     resources.m_showZoomLevel   = checkShowZoomLevel->isChecked();
     resources.m_playSound       = checkPlaySound->isChecked();
     resources.m_useAntiAliasing = checkAntiAliasing->isChecked();
@@ -184,6 +185,7 @@ void CDlgConfig::accept()
 #ifdef HAS_GEODB
     resources.m_useGeoDB        = checkUseGeoDB->isChecked();
     resources.m_saveGeoDBOnExit = checkGeoDBSaveOnExit->isChecked();
+    resources.m_saveGeoDBMinutes = spinGeoDBMinutes->value();
     resources.m_pathGeoDB       = QDir(labelPathGeoDB->text());
 #endif
 
