@@ -37,8 +37,9 @@ class CDlgConfig : public QDialog, private Ui::IDlgConfig
     private slots:
         void slotCurrentDeviceChanged(int index);
         void slotSelectFont();
-        void slotBrowserChanged(int idx);
+        void slotSelectWptTextColor();
         void slotSetupGarminIcons();
+        void slotSelectPathGeoDB();
 
     private:
         void fillTypeCombo();
