@@ -28,15 +28,17 @@
 #include "IMap.h"
 #include "IUnit.h"
 
+#include "config.h"
+
 #include <QtGui>
-#ifdef HAS_DMTX
-#include <dmtx.h>
-#endif                           //HAS_DMTX
 
 CDlgEditWpt::CDlgEditWpt(CWpt &wpt, QWidget * parent)
 : QDialog(parent)
 , wpt(wpt)
 , idxImg(0)
+#ifdef HAS_DMTX
+, enc(0)
+#endif
 {
     setupUi(this);
     connect(pushAdd, SIGNAL(clicked()), this, SLOT(slotAddImage()));
@@ -48,27 +50,45 @@ CDlgEditWpt::CDlgEditWpt(CWpt &wpt, QWidget * parent)
     connect(pushUpdateBarcode, SIGNAL(clicked()), this, SLOT(slotUpdateBarcode()));
     connect(labelLink, SIGNAL(linkActivated(const QString&)),this,SLOT(slotOpenLink(const QString&)));
     connect(toolLink, SIGNAL(pressed()),this,SLOT(slotEditLink()));
+    connect(checkHint, SIGNAL(toggled(bool)), this, SLOT(slotToggleHint(bool)));
 
     labelUnitElevation->setText(IUnit::self().baseunit);
     labelUnitProximity->setText(IUnit::self().baseunit);
+
+    connect(webView, SIGNAL(linkClicked( const QUrl&)), this, SLOT(slotOpenLink(const QUrl&)));
+
+    if(wpt.isGeoCache())
+    {
+        toolIcon->setEnabled(false);
+        lineName->setEnabled(false);
+        linePosition->setEnabled(false);
+    }
+
+#ifdef HAS_DMTX
+    enc = dmtxEncodeCreate();
+#endif
+
 }
 
 
 CDlgEditWpt::~CDlgEditWpt()
 {
-
+    //wpt.showBuddies(false);
+#ifdef HAS_DMTX
+    dmtxEncodeDestroy(&enc);
+#endif
 }
 
 
 int CDlgEditWpt::exec()
 {
 
-    QString barcode;
     QString val, unit;
-    toolIcon->setIcon(getWptIconByName(wpt.icon));
-    toolIcon->setObjectName(wpt.icon);
+    toolIcon->setIcon(wpt.getIcon());
+    toolIcon->setObjectName(wpt.getIconString());
 
-    lineName->setText(wpt.name);
+
+    lineName->setText(wpt.getName());
 
     checkSticky->setChecked(wpt.sticky);
 
@@ -102,13 +122,104 @@ int CDlgEditWpt::exec()
     if(!link.isEmpty())
     {
         QString str;
-        str = "<a href='" + link + "'>" + link + "</a>";
+
+        if(wpt.urlname.isEmpty())
+        {
+
+            if(link.count() < 50)
+            {
+                str = "<a href='" + link + "'>" + link + "</a>";
+            }
+            else
+            {
+                str = "<a href='" + link + "'>" + link.left(47) + "...</a>";
+            }
+        }
+        else
+        {
+            str = "<a href='" + link + "'>" + wpt.urlname + "</a>";
+        }
         labelLink->setText(str);
     }
 
-    textComment->setPlainText(wpt.comment);
+    textComment->setHtml(wpt.getComment());
+    lineDesc->setText(wpt.getDescription());
 
     slotUpdateBarcode();
+
+    QString html = wpt.getExtInfo(checkHint->isChecked());
+
+    if(wpt.isGeoCache())
+    {
+        checkExportBuddies->setChecked(wpt.geocache.exportBuddies);
+
+        wpt.showBuddies(true);
+
+        if(wpt.buddies.isEmpty())
+        {
+            listBuddies->hide();
+            checkExportBuddies->hide();
+        }
+        else
+        {
+            CWpt::buddy_t buddy;
+            foreach(buddy, wpt.buddies)
+            {
+                QListWidgetItem * item = new QListWidgetItem();
+                item->setText(buddy.name);
+                item->setToolTip(*buddy.pos.begin());
+                listBuddies->addItem(item);
+
+
+                qDebug() << buddy.pos << buddy.name;
+
+                foreach(const QString& pos, buddy.pos)
+                {
+                    html.replace(pos, QString("%1 (<b><i style='color: black;'>%2</i></b>)").arg(pos).arg(buddy.name));
+                }
+            }
+            listBuddies->sortItems();
+            listBuddies->show();
+            checkExportBuddies->show();
+        }
+    }
+    else
+    {
+        listBuddies->hide();
+        checkExportBuddies->hide();
+    }
+
+
+    webView->setHtml(html);
+    webView->page()->setLinkDelegationPolicy( QWebPage::DelegateAllLinks );
+
+    checkHint->setEnabled(wpt.hasHiddenInformation());
+
+
+    QStringList caches;
+    CWptDB::self().getListOfGeoCaches(caches);
+    caches.prepend("");
+    comboParentWpt->addItems(caches);
+
+    if(wpt.parentWpt.isEmpty())
+    {
+        comboParentWpt->setCurrentIndex(0);
+    }
+    else
+    {
+        int idx = comboParentWpt->findText(wpt.parentWpt);
+        if(idx < 0)
+        {
+            comboParentWpt->insertItem(1, wpt.parentWpt);
+            comboParentWpt->setCurrentIndex(1);
+        }
+        else
+        {
+            comboParentWpt->setCurrentIndex(idx);
+        }
+
+    }
+
     return QDialog::exec();
 }
 
@@ -130,8 +241,10 @@ void CDlgEditWpt::accept()
     {
         return;
     }
-    wpt.icon        = toolIcon->objectName();
-    wpt.name        = lineName->text();
+    wpt.setIcon(toolIcon->objectName());
+    wpt.setName(lineName->text());
+    wpt.setDescription(lineDesc->text());
+    wpt.setComment(textComment->toHtml());
     wpt.sticky      = checkSticky->isChecked();
 
     wpt.ele         = lineAltitude->text().isEmpty() ? WPT_NOFLOAT : IUnit::self().elevation2meter(lineAltitude->text());
@@ -144,7 +257,6 @@ void CDlgEditWpt::accept()
     }
 
     wpt.prx         = lineProximity->text().isEmpty() ? WPT_NOFLOAT : IUnit::self().elevation2meter(lineProximity->text());
-    wpt.comment     = textComment->toPlainText();
     wpt.link        = link;
 
     if(!lineDistance->text().isEmpty() && !lineBearing->text().isEmpty())
@@ -153,21 +265,30 @@ void CDlgEditWpt::accept()
         double distance = lineDistance->text().toDouble();
 
         XY pt1, pt2;
-        pt1.u   = wpt.lon * DEG_TO_RAD;
-        pt1.v   = wpt.lat * DEG_TO_RAD;
-        pt2     = GPS_Math_Wpt_Projection(pt1, distance, bearing);
+        pt1.u       = wpt.lon * DEG_TO_RAD;
+        pt1.v       = wpt.lat * DEG_TO_RAD;
+        pt2         = GPS_Math_Wpt_Projection(pt1, distance, bearing);
 
         CWpt * wpt2 = new CWpt(&CWptDB::self());
-        wpt2->lon = pt2.u * RAD_TO_DEG;
-        wpt2->lat = pt2.v * RAD_TO_DEG;
-        wpt2->icon = wpt.icon;
-        wpt2->name = wpt.name + tr("(proj.)");
+        wpt2->lon   = pt2.u * RAD_TO_DEG;
+        wpt2->lat   = pt2.v * RAD_TO_DEG;
+        wpt2->setName(wpt.name + tr("(proj.)"));
+        wpt2->setIcon(wpt.iconString);
+
+        float ele = CMapDB::self().getDEM().getElevation(pt2.u, pt2.v);
+        if(ele != WPT_NOFLOAT) wpt2->ele = ele;
+
 
         CWptDB::self().addWpt(wpt2,false);
     }
 
+    wpt.geocache.exportBuddies = checkExportBuddies->isChecked();
+
+    wpt.parentWpt = comboParentWpt->currentText();
+
     emit CWptDB::self().sigChanged();
     emit CWptDB::self().sigModified();
+    emit CWptDB::self().sigModified(wpt.getKey());
 
     QDialog::accept();
 }
@@ -186,7 +307,7 @@ void CDlgEditWpt::slotAddImage()
         ,"./"
         ,"Image (*)"
         ,0
-        , QFileDialog::DontUseNativeDialog
+        , FILE_DIALOG_FLAGS
         );
     if(filename.isEmpty()) return;
 
@@ -247,10 +368,16 @@ void CDlgEditWpt::showImage(int idx)
     }
 }
 
+void CDlgEditWpt::slotOpenLink(const QUrl& url)
+{
+
+    QDesktopServices::openUrl(url);
+}
 
 void CDlgEditWpt::slotOpenLink(const QString& link)
 {
-    CResources::self().openLink(link);
+
+    QDesktopServices::openUrl(QUrl(link));
 }
 
 
@@ -283,7 +410,7 @@ void CDlgEditWpt::slotSaveBarcode()
         ,QDir::home().path()
         ,"Bitmap (*.png);;"
         ,&filter
-        , QFileDialog::DontUseNativeDialog
+        , FILE_DIALOG_FLAGS
         );
 
     if(filename.isEmpty()) return;
@@ -309,8 +436,6 @@ void CDlgEditWpt::slotUpdateBarcode()
     }
 
 #ifdef HAS_DMTX
-    DmtxEncode * enc = dmtxEncodeCreate();
-
     if(enc)
     {
         dmtxEncodeSetProp( enc, DmtxPropPixelPacking, DmtxPack32bppRGBX );
@@ -327,16 +452,37 @@ void CDlgEditWpt::slotUpdateBarcode()
 
         QImage curBarCode( enc->image->pxl, enc->image->width, enc->image->height, QImage::Format_RGB32 );
         labelBarcode->setPixmap(QPixmap::fromImage(curBarCode));
-
-        dmtxEncodeDestroy(&enc);
     }
     else
     {
         labelBarcode->setText("Failed!");
     }
 #else
-    labelBarcode->setPixmap(QPixmap(":/pics/DummyBarcode"));
+    labelBarcode->setPixmap(QPixmap(":/pics/DummyBarcode.png"));
     pushSaveBarcode->setEnabled(false);
 #endif                       //HAS_DMTX
 
 }
+
+void CDlgEditWpt::slotToggleHint(bool show)
+{
+    QString html = wpt.getExtInfo(show);
+
+    if(wpt.isGeoCache())
+    {
+        wpt.showBuddies(true);
+
+        if(!wpt.buddies.isEmpty())
+        {
+            CWpt::buddy_t buddy;
+            foreach(buddy, wpt.buddies)
+            {
+                foreach(const QString& pos, buddy.pos)
+                {
+                    html.replace(pos, QString("%1 (<b><i style='color: black;'>%2</i></b>)").arg(pos).arg(buddy.name));
+                }
+            }
+        }
+    }
+    webView->setHtml(html);
+}
