@@ -22,6 +22,10 @@
 #include <QDialog>
 
 #include "ui_IDlgEditWpt.h"
+#ifdef HAS_DMTX
+#include <dmtx.h>
+#endif //HAS_DMTX
+
 
 class CWpt;
 
@@ -44,9 +48,11 @@ class CDlgEditWpt : public QDialog, private Ui::IDlgEditWpt
         void slotPrevImage();
         void slotSelectIcon();
         void slotOpenLink(const QString& link);
+        void slotOpenLink(const QUrl& url);
         void slotEditLink();
         void slotSaveBarcode();
         void slotUpdateBarcode();
+        void slotToggleHint(bool show);
 
     private:
         void showImage(int idx);
@@ -55,5 +61,9 @@ class CDlgEditWpt : public QDialog, private Ui::IDlgEditWpt
         QString link;
         double oldLon;
         double oldLat;
+        QSet<QString> wptBuddies;
+#ifdef HAS_DMTX
+        DmtxEncode * enc;
+#endif
 };
 #endif                           //CDLGEDITWPT_H
