@@ -39,7 +39,7 @@ CDlgProjWizzard::CDlgProjWizzard(QLineEdit& line, QWidget * parent)
     mitab_entry_t           entry;
     QList<mitab_entry_t>    list;
     int idx                 = 0;
-    const MapInfoDatumInfo * di   = asDatumInfoList;
+    const MapInfoDatumInfo * di   = asDatumInfoListQL;
 
     while(di->nMapInfoDatumID != -1)
     {
@@ -55,12 +55,16 @@ CDlgProjWizzard::CDlgProjWizzard(QLineEdit& line, QWidget * parent)
         comboDatum->addItem(entry.name, entry.idx);
     }
 
+    comboHemisphere->addItem(tr("north"), "");
+    comboHemisphere->addItem(tr("south"), "+south");
+
     connect(radioLonLat, SIGNAL(clicked()), this, SLOT(slotChange()));
     connect(radioMercator, SIGNAL(clicked()), this, SLOT(slotChange()));
     connect(radioWorldMercator, SIGNAL(clicked()), this, SLOT(slotChange()));
     connect(radioUTM, SIGNAL(clicked()), this, SLOT(slotChange()));
     connect(radioUserDef, SIGNAL(clicked()), this, SLOT(slotChange()));
     connect(comboDatum, SIGNAL(currentIndexChanged(int)), this, SLOT(slotChange()));
+    connect(comboHemisphere, SIGNAL(currentIndexChanged(int)), this, SLOT(slotChange()));
     connect(lineUserDef, SIGNAL(textChanged(const QString&)), this, SLOT(slotChange()));
     connect(spinUTMZone, SIGNAL(valueChanged(int)), this, SLOT(slotChange()));
 }
@@ -91,7 +95,8 @@ void CDlgProjWizzard::slotChange()
     }
     else if(radioUTM->isChecked())
     {
-        str += QString("+proj=utm +zone=%1 ").arg(spinUTMZone->value());
+        str += QString("+proj=utm +zone=%1 %2").arg(spinUTMZone->value()).arg(comboHemisphere->itemData(comboHemisphere->currentIndex()).toString());
+
     }
     else if(radioUserDef->isChecked())
     {
@@ -99,7 +104,7 @@ void CDlgProjWizzard::slotChange()
     }
 
     int idx = comboDatum->itemData(comboDatum->currentIndex()).toInt();
-    const MapInfoDatumInfo      di = asDatumInfoList[idx];
+    const MapInfoDatumInfo      di = asDatumInfoListQL[idx];
     if(di.pszOGCDatumName != QString(""))
     {
         const MapInfoSpheroidInfo * si = asSpheroidInfoList;
