@@ -95,6 +95,7 @@ CDlgTrackFilter::CDlgTrackFilter(CTrack &track, QWidget * parent)
     connect(spinAzimuthDelta, SIGNAL(valueChanged(int)), this, SLOT(slotSpinAzimuthDelta(int)));
     connect(spinTimedelta, SIGNAL(valueChanged(int)), this, SLOT(slotSpinTimedelta(int)));
     connect(comboMeterFeet, SIGNAL(currentIndexChanged(const QString &)), this, SLOT(slotComboMeterFeet(const QString &)));
+    connect(checkMedian, SIGNAL(clicked()), this, SLOT(slotCheckMedian()));
 
     connect(radioSplitChunks, SIGNAL(clicked()), this, SLOT(slotRadioSplitChunks()));
     connect(radioSplitPoints, SIGNAL(clicked()), this, SLOT(slotRadioSplitPoints()));
@@ -162,6 +163,7 @@ void CDlgTrackFilter::splitTrack(CTrack * trk)
 
     CTrack * track1 = new CTrack(&CTrackDB::self());
     track1->setName(trk->getName() + QString("_%1").arg(trkCnt++));
+    track1->setColor(trk->getColorIdx());
 
     while(trkpt != trkpts.end())
     {
@@ -180,6 +182,7 @@ void CDlgTrackFilter::splitTrack(CTrack * trk)
             trkptCnt = 0;
             track1 = new CTrack(&CTrackDB::self());
             track1->setName(trk->getName() + QString("_%1").arg(trkCnt++));
+            track1->setColor(trk->getColorIdx());
         }
 
         trkpt++;
@@ -324,6 +327,8 @@ void CDlgTrackFilter::reduceDataset(CTrack * trk)
 
             int i = 1;
 
+            double lastEle = trkpt->ele;
+
             while(trkpt != trkpts.end())
             {
 
@@ -335,6 +340,7 @@ void CDlgTrackFilter::reduceDataset(CTrack * trk)
                 double a1, a2;
 
                 double delta = distance(p1,p2,a1,a2);
+
                 if(checkAzimuthDelta->isEnabled() && checkAzimuthDelta->isChecked())
                 {
                     if (abs(trkpt->azimuth) <= 180)
@@ -354,9 +360,15 @@ void CDlgTrackFilter::reduceDataset(CTrack * trk)
                     }
                 }
 
-                if(delta < min_distance || (AzimuthDelta < minAzimuthDelta && checkAzimuthDelta->isEnabled() && checkAzimuthDelta->isChecked()))
+                double deltaEle = abs(lastEle - trkpt->ele);
+
+                if( delta < min_distance || (AzimuthDelta < minAzimuthDelta && checkAzimuthDelta->isEnabled() && checkAzimuthDelta->isChecked()))
                 {
-                    trkpt->flags |= CTrack::pt_t::eDeleted;
+                    if(deltaEle < 3)
+                    {
+                        trkpt->flags |= CTrack::pt_t::eDeleted;
+                    }
+
                 }
                 else
                 {
@@ -367,15 +379,49 @@ void CDlgTrackFilter::reduceDataset(CTrack * trk)
                     {
                         lastAzimuth = trkpt->azimuth;
                     }
+
+                    lastEle = trkpt->ele;
                 }
                 ++trkpt;
                 ++i;
                 if (progress.wasCanceled())
+                {
                     break;
+                }
             }
 
             QApplication::restoreOverrideCursor();
         }
+
+        // can be done in parallel to othe reductions
+        if(checkMedian->isChecked())
+        {
+            QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
+            QList<float> window;
+            window << 0.0 << 0.0 << 0.0 << 0.0 << 0.0;
+
+
+            for(int i = 2; i < trkpts.size()-2; i++)
+            {
+                // apply median filter over all trackpoints
+                window[0] = trkpts[i - 2]._ele;
+                window[1] = trkpts[i - 1]._ele;
+                window[2] = trkpts[i]._ele;
+                window[3] = trkpts[i + 1]._ele;
+                window[4] = trkpts[i + 2]._ele;
+
+                qSort(window);
+                trkpts[i].ele = window[2];
+
+                progress.setValue(i);
+                qApp->processEvents(QEventLoop::AllEvents, 100);
+                if (progress.wasCanceled())
+                {
+                    break;
+                }
+            }
+            QApplication::restoreOverrideCursor();
+        }
         progress.setValue(npts);
         track.rebuild(false);
 
@@ -439,6 +485,11 @@ void CDlgTrackFilter::slotRadioDistance()
     }
 }
 
+void CDlgTrackFilter::slotCheckMedian()
+{
+    checkReduceDataset->setChecked(true);
+}
+
 void CDlgTrackFilter::slotSpinDistance(int i)
 {
     radioDistance->setChecked(true);
