@@ -28,13 +28,13 @@
 CGarminExport::CGarminExport(QWidget * parent)
 : QDialog(parent)
 , e1(9)
-, e2(5)
+, e2(7)
 , blocksize(pow(2.0f, e1 + e2))
 , errors(false)
 , isDialog(true)
 {
     setupUi(this);
-    toolPath->setIcon(QPixmap(":/icons/iconFileLoad16x16"));
+    toolPath->setIcon(QPixmap(":/icons/iconFileLoad16x16.png"));
 
     QSettings cfg;
     labelPath->setText(cfg.value("path/export","./").toString());
@@ -55,7 +55,7 @@ CGarminExport::~CGarminExport()
 
 void CGarminExport::slotOutputPath()
 {
-    QString path = QFileDialog::getExistingDirectory(this, tr("Select ouput path..."), labelPath->text(), QFileDialog::DontUseNativeDialog);
+    QString path = QFileDialog::getExistingDirectory(this, tr("Select ouput path..."), labelPath->text(), FILE_DIALOG_FLAGS);
     if(path.isEmpty()) return;
 
     QSettings cfg;
@@ -109,6 +109,45 @@ void CGarminExport::exportToFile(CMapSelectionGarmin& ms, const QString& fn)
             writeStdout(tr("    %1 (%2 MB)").arg(myTile.name).arg(double(myTile.memsize) / (1024 * 1024), 0, 'f', 2));
             ++tile;
         }
+
+
+        if(!map->mdrfile.isEmpty())
+        {
+            tile_t  mdrTile;
+            quint32 total = 0;
+
+            mdrTile.filename = map->mdrfile;
+            mdrTile.name     = "MDR file";
+            try
+            {
+                readTileInfo(mdrTile);
+
+                QMap<QString,gmapsupp_subfile_desc_t>::const_iterator subfile = mdrTile.subfiles.begin();
+                while(subfile != mdrTile.subfiles.end())
+                {
+                    const QList<gmapsupp_subfile_part_t>& parts = subfile->parts.values();
+                    QList<gmapsupp_subfile_part_t>::const_iterator part = parts.begin();
+                    while(part != parts.end())
+                    {
+                        total += part->size;
+                        ++part;
+                    }
+                    ++subfile;
+                }
+
+                mdrTile.memsize = total;
+                mdrTile.isMdr   = true;
+                writeStdout(tr("    %1 (%2 MB)").arg(mdrTile.name).arg(double(mdrTile.memsize) / (1024 * 1024), 0, 'f', 2));
+
+                tiles << mdrTile;
+            }
+            catch(const exce_t& /*e*/)
+            {
+                //writeStderr(e.msg + tr(" (this is not fatal)"));
+            }
+
+        }
+
         writeStdout(" ");
         ++map;
     }
@@ -131,6 +170,34 @@ void CGarminExport::exportToFile(CMapSelectionGarmin& ms, const QString& fn)
     }
 }
 
+quint32 CGarminExport::estimateBlockCount(QVector<tile_t>& _tiles, quint8 _e2)
+{
+    tile_t tile;
+    quint32 _blocksize  = pow(2.0f, e1 + _e2);
+    quint32 _mask       = 0xFFFFFFFF >> (32 - e1 - _e2);
+    quint32 _totalSize  = 0;
+    quint32 _totalSize2  = 0;
+    quint32 _nBlocks    = 0;
+
+    foreach(tile, _tiles)
+    {
+        quint32 size = tile.memsize;
+        _totalSize2 += size;
+        if(size & _mask)
+        {
+            size = (size + _blocksize) & ~_mask;
+        }
+
+        _totalSize += size;
+    }
+
+    _nBlocks = _totalSize >> (e1 + _e2);
+
+//    qDebug() << hex << _e2 << _mask << _totalSize << _nBlocks << _totalSize2 << _blocksize;
+
+    return _nBlocks;
+}
+
 
 void CGarminExport::writeStdout(const QString& msg)
 {
@@ -138,7 +205,7 @@ void CGarminExport::writeStdout(const QString& msg)
     textBrowser->append(msg);
     textBrowser->verticalScrollBar()->setValue(textBrowser->verticalScrollBar()->maximum());
 
-    qApp->processEvents();
+    qApp->processEvents(QEventLoop::ExcludeUserInputEvents);
 }
 
 
@@ -148,7 +215,7 @@ void CGarminExport::writeStderr(const QString& msg)
     textBrowser->append(msg);
     textBrowser->verticalScrollBar()->setValue(textBrowser->verticalScrollBar()->maximum());
 
-    qApp->processEvents();
+    qApp->processEvents(QEventLoop::ExcludeUserInputEvents);
 }
 
 
@@ -370,6 +437,7 @@ void CGarminExport::readTileInfo(tile_t& t)
 
 #ifdef DEBUG_SHOW_SECT_DESC
     {
+        quint32 total = 0;
         QMap<QString,gmapsupp_subfile_desc_t>::const_iterator subfile = subfiles.begin();
         while(subfile != subfiles.end())
         {
@@ -380,10 +448,12 @@ void CGarminExport::readTileInfo(tile_t& t)
             while(part != parts.end())
             {
                 qDebug() << part->key << hex << part->offset << part->size;
+                total += part->size;
                 ++part;
             }
             ++subfile;
         }
+        qDebug() << "total" << total;
     }
 #endif                       //DEBUG_SHOW_SECT_DESC
 
@@ -445,7 +515,15 @@ void CGarminExport::slotStart()
         while(tile != tiles.end())
         {
             // read img file
-            readTileInfo(*tile);
+            try
+            {
+                readTileInfo(*tile);
+            }
+            catch(const exce_t& e)
+            {
+                writeStderr(e.msg);
+                return;
+            }
 
             // iterate over all subfiles and their parts to count FAT blocks and blocks
             QMap<QString, gmapsupp_subfile_desc_t>& subfiles          = tile->subfiles;
@@ -470,7 +548,10 @@ void CGarminExport::slotStart()
             }
 
             // add tile to mapsource.mps section
-            addTileToMPS(*tile, mps);
+            if(!tile->isMdr)
+            {
+                addTileToMPS(*tile, mps);
+            }
 
             ++tile;
         }
@@ -543,6 +624,17 @@ void CGarminExport::slotStart()
             writeStdout(tr("FAT entries: %1 (of %2) ").arg(totalFATs).arg(maxFATs));
         }
 
+        if(totalBlocks >= 65536)
+        {
+            writeStderr(tr("Block count: %1 (of %2) Failed!").arg(totalBlocks).arg(65536));
+            throw exce_t(errLogic, tr("Too many tiles."));
+        }
+        else
+        {
+            writeStdout(tr("Block count: %1 (of %2)").arg(totalBlocks).arg(65536));
+        }
+
+
         if(filesize > maxFileSize)
         {
             writeStderr(tr("File size: %1 MB (of %2 MB) Failed!").arg(double(filesize) / (1024 * 1024), 0, 'f', 2).arg(double(maxFileSize) / (1024 * 1024), 0, 'f', 2));
