@@ -66,7 +66,7 @@ class CGarminPolygon
         QStringList labels;
 
         static quint32 cnt;
-        static quint32 maxVecSize;
+        static qint32 maxVecSize;
     private:
         void bits_per_coord(quint8 base, quint8 bfirst, quint32& bx, quint32& by, sign_info_t& signinfo, bool isVer2);
         int bits_per_coord(quint8 base, bool is_signed);
