@@ -28,6 +28,6 @@ class CGarminStrTbl8 : public IGarminStrTbl
         CGarminStrTbl8(const quint16 codepage, const quint8 mask, QObject * parent);
         virtual ~CGarminStrTbl8();
 
-        void get(QFile& file, quint32 offset, type_e t, QStringList& info);
+        void get(QFileExt& file, quint32 offset, type_e t, QStringList& info);
 };
 #endif                           //CGARMINSTRTBL8_H
