@@ -205,6 +205,8 @@ class CGarminTile : public QObject
         void loadSubDiv(QFileExt& file, const subdiv_desc_t& subdiv, IGarminStrTbl * strtbl, const QByteArray& rgndata, bool fast, const QRectF& viewport, polytype_t& polylines, polytype_t& polygons, pointtype_t& points, pointtype_t& pois);
         void createIndexSubDiv(QFileExt& file, quint32 idSubfile, const subdiv_desc_t& subdiv, IGarminStrTbl * strtbl, const QByteArray& rgndata, QSqlDatabase& db);
 
+        void readDEM(subfile_desc_t& subfile, QFileExt &file);
+
         // share the structures
         friend class CGarminExport;
 #pragma pack(1)
@@ -415,6 +417,38 @@ class CGarminTile : public QObject
             quint32 net3_length; ///< 0x0000002B .. 0x0000002E
         };
 
+        struct hdr_dem_t : public hdr_subfile_part_t
+        {
+            quint32 dem_flags;      ///< 0x00000015 .. 0x00000018
+            quint16 levels;         ///< 0x00000019 .. 0x0000001A
+            quint8  byte0x0000001B_0x0000001E[4];
+            quint16 blk3_size;      ///< 0x0000001f .. 0x00000020
+            quint32 blk3_offset;    ///< 0x00000021 .. 0x00000024
+        };
+
+
+        struct dem_level_t
+        {
+            quint16 index;
+            quint32 nPixelPerTileX;
+            quint32 nPixelPerTileY;
+            quint32 Unknown1;
+            quint32 Unknown2;
+            quint16 Unknown3;
+            quint32 nTilesX;
+            quint32 nTilesY;
+            quint16 format;
+            quint16 blk1_size;
+            quint32 blk1_offset;
+            quint32 blk2_offset;
+            quint32 westernBound;
+            quint32 northernBound;
+            quint32 PixelPerMeterX;
+            quint32 PixelPerMeterY;
+            quint16 minHeight;
+            quint16 maxHeight;
+        };
+
 #define TRE_MAP_LEVEL(r) ((r)->zoom & 0x0f)
 #define TRE_MAP_INHER(r) (((r)->zoom & 0x80) != 0)
 
