@@ -28,8 +28,12 @@ const QString CGpx::gpx_ns = "http://www.topografix.com/GPX/1/1";
 const QString CGpx::xsi_ns = "http://www.w3.org/2001/XMLSchema-instance";
 const QString CGpx::gpxx_ns = "http://www.garmin.com/xmlschemas/GpxExtensions/v3";
 const QString CGpx::gpxtpx_ns = "http://www.garmin.com/xmlschemas/TrackPointExtension/v1";
+const QString CGpx::gpxwpx_ns = "http://www.garmin.com/xmlschemas/WaypointExtension/v1";
 const QString CGpx::rmc_ns = "urn:net:trekbuddy:1.0:nmea:rmc";
 const QString CGpx::ql_ns = "http://www.qlandkarte.org/xmlschemas/v1.1";
+const QString CGpx::gs_ns = "http://www.groundspeak.com/cache/1/0";
+
+
 
 uint qHash(QColor color)
 {
@@ -37,11 +41,12 @@ uint qHash(QColor color)
 }
 
 
-CGpx::CGpx(QObject * parent, bool exportFlag)
+CGpx::CGpx(QObject * parent, exportMode_e mode)
 : QObject(parent)
 , QDomDocument()
+, exportMode(mode)
 {
-    export_flag = exportFlag;
+
     writeMetadata();
 
     colorMap.insert("Black",       QColor(Qt::black));
@@ -101,7 +106,9 @@ void CGpx::writeMetadata()
     root.setAttribute("xmlns:gpxx",gpxx_ns);
     root.setAttribute("xmlns:gpxtpx",gpxtpx_ns);
     root.setAttribute("xmlns:rmc",rmc_ns);
-    if (!export_flag)
+//    root.setAttribute("xmlns:groundspeak",gs_ns);
+
+    if (exportMode == eQlgtExport)
     {
         root.setAttribute("xmlns:ql",ql_ns);
     }
@@ -109,7 +116,8 @@ void CGpx::writeMetadata()
         + gpx_ns    + " http://www.topografix.com/GPX/1/1/gpx.xsd "
         + gpxx_ns   + " http://www.garmin.com/xmlschemas/GpxExtensionsv3.xsd "
         + gpxtpx_ns + " http://www.garmin.com/xmlschemas/TrackPointExtensionv1.xsd";
-    if (!export_flag)
+
+    if (exportMode == eQlgtExport)
     {
         schemaLocation += " ";
         schemaLocation += ql_ns;
@@ -147,9 +155,9 @@ void CGpx::save(const QString& filename)
 {
     QFile file(filename);
 
-    if(file.exists())
+    if(file.exists() && (exportMode == eQlgtExport))
     {
-        CGpx gpx(0);
+        CGpx gpx(0,exportMode);
         try
         {
             gpx.load(filename);
@@ -160,7 +168,7 @@ void CGpx::save(const QString& filename)
                 throw tr("bad application");
             }
         }
-        catch(const QString& msg)
+        catch(const QString&)
         {
             int res = QMessageBox::warning(0,tr("File exists ...")
                 ,tr("The file exists and it has not been created by QLandkarte GT. "
@@ -266,6 +274,7 @@ QMap<QString,QDomElement> CGpx::mapChildElements(const QDomNode& parent)
             else
             {
                 map.insert(child.namespaceURI()+":"+child.localName(), child.toElement());
+                qDebug() << (child.namespaceURI()+":"+child.localName());
             }
         }
         child = child.nextSibling();
