@@ -41,6 +41,10 @@ class CActions;
 class CMenus;
 class QSocketNotifier;
 class QAction;
+class CGeoDB;
+#ifdef HAS_DBUS
+class CDBus;
+#endif
 
 class CMainWindow : public QMainWindow
 {
@@ -62,7 +66,9 @@ class CMainWindow : public QMainWindow
 
         const QString& getCurrentFilename(){return wksFile;}
 
-        CMenus *getActionGroupProvider() { return actionGroupProvider;};
+        CMenus *getActionGroupProvider() { return actionGroupProvider;}
+
+        void exportToOcm();
 
     protected:
         void closeEvent(QCloseEvent * e);
@@ -82,7 +88,6 @@ class CMainWindow : public QMainWindow
         void slotExportData();
         void slotSaveImage();
         void slotPrint();
-        void slotPrintPreview();
         void slotModified();
         void slotDataChanged();
         void slotOpenLink(const QString& link);
@@ -93,16 +98,25 @@ class CMainWindow : public QMainWindow
         void slotItemDestroyed(QObject *);
         void slotTabCloseRequest(int i);
 
+        void slotFAQ();
+        void slotHelp();
+        void slotSupport();
+
+        void slotToggleToolView();
+
     private:
+        friend class CDBus;
         CMenus *actionGroupProvider;
         void setupMenuBar();
         void addRecent(const QString& filename);
 
-        void loadData(QString& filename, const QString& filter);
+        void loadData(const QString& filename, const QString& filter);
         void setTitleBar();
         bool maybeSave();
         void saveData(QString& filename, const QString& filter, bool exportFlag = false);
         bool convertData(const QString& inFormat, const QString& inFile, const QString& outFormat, const QString& outFile);
+        bool isGPSBabel();
+        QString getGeoDataFormats();
 
         QMenu *setupMenu;
         QMenu *groupProvidedMenu;
@@ -149,6 +163,8 @@ class CMainWindow : public QMainWindow
 
         CRouteDB * routedb;
 
+        CGeoDB * geodb;
+
         /// the current loaded geo data (workspace) file
         QString wksFile;
         /// true if any data has been changed
@@ -166,6 +182,10 @@ class CMainWindow : public QMainWindow
         QStringList mostRecent;
 
         QTabWidget * tmpTabWidget;
+#ifdef HAS_DBUS
+        CDBus * dbus;
+#endif
+
 };
 
 extern CMainWindow * theMainWindow;
