@@ -23,6 +23,7 @@
 #include "CMapTDB.h"
 #include "CMapRaster.h"
 #include "CMapGeoTiff.h"
+#include "CMapJnx.h"
 #include "CMapDEM.h"
 #include "CMapOSM.h"
 #include "CMainWindow.h"
@@ -41,10 +42,14 @@
 #ifdef WMS_CLIENT
 #include "CMapWMS.h"
 #endif
+#include "CQlb.h"
+#include "IMouse.h"
 
 #include <QtGui>
 #include <QtXml/QDomDocument>
 
+#include <gdal_priv.h>
+
 CMapDB * CMapDB::m_self = 0;
 
 CMapDB::CMapDB(QTabWidget * tb, QObject * parent)
@@ -68,6 +73,8 @@ CMapDB::CMapDB(QTabWidget * tb, QObject * parent)
     m.type              = IMap::eTile;
     knownMaps[m.key]    = m;
 
+    theMap = defaultMap;
+
     QSettings cfg;
     QString map;
     QStringList maps = cfg.value("maps/knownMaps","").toString().split("|",QString::SkipEmptyParts);
@@ -134,14 +141,17 @@ CMapDB::~CMapDB()
         maps += map.filename + "|";
     }
     cfg.setValue("maps/knownMaps",maps);
+
+    GDALDestroyDriverManager();
 }
 
 
+#ifdef PLOT_3D
 CMap3D * CMapDB::getMap3D()
 {
     return map3D;
 }
-
+#endif
 
 void CMapDB::clear()
 {
@@ -168,6 +178,8 @@ void CMapDB::closeVisibleMaps()
     if(!demMap.isNull()) delete demMap;
 
     theMap = defaultMap;
+
+    IMouse::resetPos1();
 }
 
 
@@ -227,6 +239,31 @@ void CMapDB::openMap(const QString& filename, bool asRaster, CCanvas& canvas)
         cfg.setValue(map.filename, map.description);
         cfg.endGroup();
     }
+#ifdef HAS_JNX
+    else if(ext == "jnx")
+    {
+
+        CMapJnx * mapjnx;
+
+        map.filename    = filename;
+        map.key         = filename;
+        map.type        = IMap::eRaster;
+
+        theMap = mapjnx = new CMapJnx(map.key, filename, &canvas);
+
+        map.description = mapjnx->getName();
+        if(map.description.isEmpty()) map.description = fi.fileName();
+
+        // add map to known maps
+        knownMaps[map.key] = map;
+
+        // store current map filename for next session
+        cfg.setValue("maps/visibleMaps",filename);
+        cfg.beginGroup("garmin/maps/alias");
+        cfg.setValue(map.filename, map.description);
+        cfg.endGroup();
+    }
+#endif // HAS_JNX
 #ifdef WMS_CLIENT
     else if(ext == "xml" )
     {
@@ -282,8 +319,8 @@ void CMapDB::openMap(const QString& filename, bool asRaster, CCanvas& canvas)
     if(!fileDEM.isEmpty()) openDEM(fileDEM);
 
 #ifdef PLOT_3D_NEW
-    CMap3D * map3D = new CMap3D(theMap, theMainWindow->getCanvas());
-    theMainWindow->getCanvasTab()->addTab(map3D, tr("Map 3D..."));
+//    CMap3D * map3D = new CMap3D(theMap, theMainWindow->getCanvas());
+//    theMainWindow->getCanvasTab()->addTab(map3D, tr("Map 3D..."));
 #endif
 
     emit sigChanged();
@@ -321,6 +358,12 @@ void CMapDB::openMap(const QString& key)
     {
         theMap = new CMapTDB(key,filename,theMainWindow->getCanvas());
     }
+#ifdef HAS_JNX
+    else if(ext == "jnx")
+    {
+        theMap = new CMapJnx(key,filename,theMainWindow->getCanvas());
+    }
+#endif // HAS_JNX
 #ifdef WMS_CLIENT
     else if(ext == "xml" )
     {
@@ -353,8 +396,8 @@ void CMapDB::openMap(const QString& key)
     }
 
 #ifdef PLOT_3D_NEW
-    CMap3D * map3D = new CMap3D(theMap, theMainWindow->getCanvas());
-    theMainWindow->getCanvasTab()->addTab(map3D, tr("Map 3D..."));
+//    CMap3D * map3D = new CMap3D(theMap, theMainWindow->getCanvas());
+//    theMainWindow->getCanvasTab()->addTab(map3D, tr("Map 3D..."));
 #endif
 
     emit sigChanged();
@@ -401,17 +444,24 @@ void CMapDB::openDEM(const QString& filename)
     try
     {
         CMapDEM * dem;
-        demMap = dem = new CMapDEM(filename, theMainWindow->getCanvas());
-        theMap->registerDEM(*dem);
+        dem = new CMapDEM(filename, theMainWindow->getCanvas());
+        if (dem->loaded())
+            demMap = dem, theMap->registerDEM(*dem);
+        else
+            delete dem;
     }
     catch(const QString& msg)
     {
         cfg.setValue(QString("map/dem/%1").arg(theMap->getKey()), "");
-        QMessageBox:: critical(0,tr("Error..."), msg, QMessageBox::Abort, QMessageBox::Abort);
+        cfg.setValue(QString("map/dem/%1/ignoreWarning").arg(theMap->getKey()), false);
         return;
     }
 
     cfg.setValue(QString("map/dem/%1").arg(theMap->getKey()), filename);
+    if(filename.isEmpty())
+    {
+        cfg.setValue(QString("map/dem/%1/ignoreWarning").arg(theMap->getKey()), false);
+    }
 
     emit sigChanged();
 }
@@ -454,12 +504,23 @@ void CMapDB::delSelectedMap(const QStringList& keys)
     QString key;
     foreach(key, keys)
     {
-        delete selectedMaps.take(key);
+        delSelectedMap(key,true);
     }
 
     emit sigChanged();
 }
 
+void CMapDB::delSelectedMap(const QString& key, bool silent)
+{
+    if(selectedMaps.contains(key))
+    {
+        delete selectedMaps.take(key);
+        if(!silent)
+        {
+            emit sigChanged();
+        }
+    }
+}
 
 void CMapDB::selSelectedMap(const QString& key)
 {
@@ -480,13 +541,195 @@ void CMapDB::saveGPX(CGpx& gpx, const QStringList& keys)
 }
 
 
-void CMapDB::loadQLB(CQlb& qlb)
+QDataStream& CMapDB::operator<<(QDataStream& s)
 {
+    qint32 type;
+    quint32 timestamp;
+    QString key;
+    QString mapkey;
+    QString name;
+    QString comment;
+    QString description;
+
+
+    double lon1;             ///< top left longitude [rad]
+    double lat1;             ///< top left latitude [rad]
+    double lon2;             ///< bottom right longitude [rad]
+    double lat2;             ///< bottom right latitude [rad]
+
+    QIODevice * dev = s.device();
+    qint64      pos = dev->pos();
+
+    char magic[9];
+    s.readRawData(magic,9);
+
+    if(strncmp(magic,"QLMapSel",9))
+    {
+        dev->seek(pos);
+        return s;
+    }
+
+    QList<IMapSelection::sel_head_entry_t> entries;
+    while(1)
+    {
+        IMapSelection::sel_head_entry_t entry;
+        s >> entry.type >> entry.offset;
+        entries << entry;
+        if(entry.type == CWpt::eEnd) break;
+    }
+
+    QList<IMapSelection::sel_head_entry_t>::iterator entry = entries.begin();
+    while(entry != entries.end())
+    {
+        qint64 o = pos + entry->offset;
+        dev->seek(o);
+        s >> entry->data;
+
+        switch(entry->type)
+        {
+            case IMapSelection::eHeadBase:
+            {
+
+                QDataStream s1(&entry->data, QIODevice::ReadOnly);
+                s1.setVersion(QDataStream::Qt_4_5);
+
+                s1 >> type;
+                s1 >> key;
+                s1 >> mapkey;
+                s1 >> timestamp;
+                s1 >> name;
+                s1 >> comment;
+                s1 >> description;
+                s1 >> lon1;             ///< top left longitude [rad]
+                s1 >> lat1;             ///< top left latitude [rad]
+                s1 >> lon2;             ///< bottom right longitude [rad]
+                s1 >> lat2;             ///< bottom right latitude [rad]
+                break;
+            }
+
+            case IMapSelection::eHeadRaster:
+            {
+                QDataStream s1(&entry->data, QIODevice::ReadOnly);
+                s1.setVersion(QDataStream::Qt_4_5);
+
+                CMapSelectionRaster * ms = new CMapSelectionRaster(this);
+                ms->setKey(key);
+                ms->mapkey = mapkey;
+                ms->setTimestamp(timestamp);
+                ms->setName(name);
+                ms->setComment(comment);
+                ms->setDescription(description);
+                ms->lon1 = lon1;
+                ms->lat1 = lat1;
+                ms->lon2 = lon2;
+                ms->lat2 = lat2;
+
+                s1 >> ms->selTiles ;
+
+                selectedMaps[ms->getKey()] = ms;
+
+                break;
+            }
+
+            case IMapSelection::eHeadGarmin:
+            {
+                int nMaps, nTiles, m, t;
+
+                QDataStream s1(&entry->data, QIODevice::ReadOnly);
+                s1.setVersion(QDataStream::Qt_4_5);
+
+                CMapSelectionGarmin * ms = new CMapSelectionGarmin(this);
+                ms->setKey(key);
+                ms->mapkey = mapkey;
+                ms->setTimestamp(timestamp);
+                ms->setName(name);
+                ms->setComment(comment);
+                ms->setDescription(description);
+                ms->lon1 = lon1;
+                ms->lat1 = lat1;
+                ms->lon2 = lon2;
+                ms->lat2 = lat2;
+
+                s1 >> nMaps;
+                for(m = 0; m < nMaps; m++)
+                {
+                    QString key;
+                    s1 >> key;
+                    CMapSelectionGarmin::map_t map;
+                    s1 >> map.unlockKey;
+                    s1 >> map.name;
+                    s1 >> map.typfile;
+                    s1 >> map.mdrfile;
+                    s1 >> map.fid;
+                    s1 >> map.pid;
+
+                    s1 >> nTiles;
+                    for(t = 0; t < nTiles; t++)
+                    {
+                        QString key;
+                        s1 >> key;
+                        CMapSelectionGarmin::tile_t tile;
+                        s1 >> tile.id;
+                        s1 >> tile.name;
+                        s1 >> tile.filename;
+                        s1 >> tile.u;
+                        s1 >> tile.v;
+                        s1 >> tile.memSize;
+                        s1 >> tile.area;
+                        s1 >> tile.fid;
+                        s1 >> tile.pid;
+
+                        map.tiles[key] = tile;
+                    }
+
+                    ms->maps[key] = map;
+                }
+
+                QString key;
+                foreach(key, selectedMaps.keys())
+                {
+                    IMapSelection * mapSel = selectedMaps[key];
+                    if(mapSel->type == IMapSelection::eGarmin)
+                    {
+                        delete selectedMaps.take(key);
+                    }
+                }
+
+                selectedMaps[ms->getKey()] = ms;
+                break;
+            }
+            default:;
+        }
+
+        ++entry;
+    }
+    return s;
+}
+
+void CMapDB::loadQLB(CQlb& qlb, bool newKey)
+{
+    QDataStream stream(&qlb.mapsels(),QIODevice::ReadOnly);
+    stream.setVersion(QDataStream::Qt_4_5);
+
+    while(!stream.atEnd())
+    {
+        *this << stream;
+    }
+    if(selectedMaps.size())
+    {
+        emitSigChanged();
+    }
 }
 
 
 void CMapDB::saveQLB(CQlb& qlb)
 {
+    QMap<QString, IMapSelection*>::iterator sel = selectedMaps.begin();
+    while(sel != selectedMaps.end())
+    {
+        qlb << *(*sel);
+        ++sel;
+    }
 }
 
 
@@ -552,8 +795,11 @@ void CMapDB::show3DMap(bool show)
 {
     if(map3D.isNull() && show)
     {
-        map3D = new CMap3D(theMap, theMainWindow->getCanvas());
-        theMainWindow->getCanvasTab()->addTab(map3D, tr("Map 3D..."));
+        if(!theMap.isNull())
+        {
+            map3D = new CMap3D(theMap, theMainWindow->getCanvas());
+            theMainWindow->getCanvasTab()->addTab(map3D, tr("Map 3D..."));
+        }
     }
     else if(!map3D.isNull() && !show)
     {
@@ -576,7 +822,7 @@ void CMapDB::searchMap()
 }
 
 
-void CMapDB::select(const QRect& rect)
+void CMapDB::select(const QRect& rect, const QMap< QPair<int,int>, bool>& selTiles)
 {
     QString mapkey = theMap->getKey();
     if(mapkey.isEmpty())
@@ -589,17 +835,18 @@ void CMapDB::select(const QRect& rect)
     {
         CMapSelectionRaster * ms = new CMapSelectionRaster(this);
         ms->mapkey       = mapkey;
-        ms->description  = knownMaps[mapkey].description;
+        ms->selTiles     = selTiles;
+        ms->setName(knownMaps[mapkey].description);
 
         try
         {
             theMap->select(*ms, rect);
 
-            selectedMaps[ms->key] = ms;
+            selectedMaps[ms->getKey()] = ms;
 
             if(ms->isEmpty())
             {
-                delete selectedMaps.take(ms->key);
+                delete selectedMaps.take(ms->getKey());
             }
             else if(mapsearch)
             {
@@ -617,27 +864,86 @@ void CMapDB::select(const QRect& rect)
     }
     else if(theMap->maptype == IMap::eGarmin)
     {
+        bool isEdit = false;
         IMapSelection * ms = 0;
-        if(selectedMaps.contains("gmapsupp"))
+        IMapSelection * mapSel;
+        foreach(mapSel, selectedMaps)
         {
-            ms = selectedMaps["gmapsupp"];
+            if(mapSel->type == IMapSelection::eGarmin)
+            {
+                ms     = mapSel;
+                isEdit = true;
+                break;
+            }
         }
-        else
+
+        if(ms == 0)
         {
             ms = new CMapSelectionGarmin(this);
         }
-        ms->key          = "gmapsupp";
+
+
         ms->mapkey       = mapkey;
-        ms->description  = "Garmin - gmapsupp.img";
+        ms->setDescription("Garmin - gmapsupp.img");
         theMap->select(*ms, rect);
 
-        selectedMaps[ms->key] = ms;
+        selectedMaps[ms->getKey()] = ms;
 
         if(ms->isEmpty())
         {
-            delete selectedMaps.take(ms->key);
+            delete selectedMaps.take(ms->getKey());
+            ms = 0;
         }
 
+        if(ms && isEdit)
+        {
+            emit sigModified(ms->getKey());
+        }
         emit sigChanged();
     }
 }
+
+
+IMapSelection * CMapDB::getSelectedMap(double lon, double lat)
+{
+    IMap& map = getMap();
+
+    if(map.maptype != IMap::eRaster)
+    {
+        return 0;
+    }
+
+    if(tabbar->currentWidget() != toolview)
+    {
+        return 0;
+    }
+
+
+    QString mapkey = map.getKey();
+    IMapSelection * mapSel = 0;
+    foreach(mapSel, selectedMaps)
+    {
+        if(mapSel->mapkey != mapkey)
+        {
+            continue;
+        }
+
+        QRectF r(QPointF(mapSel->lon1, mapSel->lat1), QPointF(mapSel->lon2, mapSel->lat2));
+        if(r.contains(lon, lat))
+        {
+            return mapSel;
+        }
+    }
+
+    return 0;
+}
+
+IMapSelection * CMapDB::getMapSelectionByKey(const QString& key)
+{
+    if(selectedMaps.contains(key))
+    {
+        return selectedMaps[key];
+    }
+
+    return 0;
+}
