@@ -46,7 +46,6 @@ CMapFile::CMapFile(const QString& filename, QObject * parent)
     char str[1024];
     strncpy(str,dataset->GetProjectionRef(),sizeof(str));
     char * ptr = str;
-    OGRSpatialReference oSRS;
     oSRS.importFromWkt(&ptr);
     oSRS.exportToProj4(&ptr);
     strOrigProj = strProj = ptr;
@@ -83,6 +82,7 @@ CMapFile::CMapFile(const QString& filename, QObject * parent)
     xref2   = xref1 + xsize_px * xscale;
     yref2   = yref1 + ysize_px * yscale;
 
+    qDebug() << "xscale" << xscale << "yscale" << yscale;
     qDebug() << xref1 << yref1 << xref2 << yref2;
 
     rasterBandCount = dataset->GetRasterCount();
@@ -120,6 +120,7 @@ CMapFile::CMapFile(const QString& filename, QObject * parent)
 
         if(success)
         {
+            qDebug() << "set transparent color for index" << idx;
             QColor tmp(colortable[idx]);
             tmp.setAlpha(0);
             colortable[idx] = tmp.rgba();
