@@ -24,6 +24,7 @@
 #include <QRgb>
 #include <QVector>
 #include <projects.h>
+#include <ogr_spatialref.h>
 #ifdef __MINGW32__
 #undef LP
 #endif
@@ -97,5 +98,7 @@ class CMapFile : public QObject
 
         bool is32BitRgb();
 
+        OGRSpatialReference oSRS;
+
 };
 #endif                           //CMAPFILE_H
