@@ -313,7 +313,10 @@ void CMapGeoTiff::draw()
                         unsigned int offset;
 
                         for (offset = 0; offset < sizeof(testPix) && *(((quint8 *)&testPix) + offset) != pbandColour; offset++);
-
+/// @todo this has to be removed with GDAL 1.8.0
+#ifdef WIN32
+                        offset = 3 - b;
+#endif // WIN32
                         if(offset < sizeof(testPix))
                         {
                             quint8 * pTar   = img.bits() + offset;
