@@ -123,6 +123,24 @@ void CMapRaster::convertM2Pt(double& u, double& v)
     v = (v - y) / zoomfactor;
 }
 
+void CMapRaster::convertPt2Pixel(double& u, double& v)
+{
+    convertPt2M(u,v);
+    if(u < 0 || u > maparea.width())
+    {
+        u = -1;
+        v = -1;
+        return;
+    }
+    if(v < 0 || v > maparea.height())
+    {
+        u = -1;
+        v = -1;
+        return;
+    }
+
+}
+
 
 void CMapRaster::move(const QPoint& old, const QPoint& next)
 {
@@ -234,6 +252,11 @@ void CMapRaster::draw()
     qint32 w    = (qint32)(pxx / zoomfactor) & 0xFFFFFFFC;
     qint32 h    = (qint32)(pxy / zoomfactor);
 
+    if((w*h) == 0)
+    {
+        return;
+    }
+
     CPLErr err = CE_Failure;
     if(rasterBandCount == 1)
     {
@@ -257,6 +280,8 @@ void CMapRaster::draw()
         QVector<quint8> buffer(w*h);
 
         img.fill(qRgba(255,255,255,255));
+        QRgb testPix = qRgba(GCI_RedBand, GCI_GreenBand, GCI_BlueBand, GCI_AlphaBand);
+
         for(int b = 1; b <= rasterBandCount; ++b)
         {
 
@@ -267,15 +292,23 @@ void CMapRaster::draw()
 
             if(!err)
             {
-                quint8 * pTar   = img.bits() - (pBand->GetColorInterpretation() - 5);
-                quint8 * pSrc   = buffer.data();
-                const int size  = buffer.size();
+                int pbandColour = pBand->GetColorInterpretation();
+                unsigned int offset;
 
-                for(int i = 0; i < size; ++i)
+                for (offset = 0; offset < sizeof(testPix) && *(((quint8 *)&testPix) + offset) != pbandColour; offset++);
+
+                if(offset < sizeof(testPix))
                 {
-                    *pTar = *pSrc;
-                    pTar += 4;
-                    pSrc += 1;
+                    quint8 * pTar   = img.bits() + offset;
+                    quint8 * pSrc   = buffer.data();
+                    const int size  = buffer.size();
+
+                    for(int i = 0; i < size; ++i)
+                    {
+                        *pTar = *pSrc;
+                        pTar += sizeof(testPix);
+                        pSrc += 1;
+                    }
                 }
             }
         }
