@@ -27,6 +27,16 @@ class CMapSelectionRaster : public IMapSelection
         CMapSelectionRaster(QObject * parent);
         virtual ~CMapSelectionRaster();
 
+        QDataStream& operator>>(QDataStream&);
+
         void draw(QPainter& p, const QRect& rect);
+
+        QString getDescription();
+
+        QString getInfo(){return getDescription();}
+
+        void setIcon(const QString&){};
+
+        QMap< QPair<int, int>, bool > selTiles;
 };
 #endif                           //CMAPSELECTIONRASTER_H
