@@ -62,7 +62,13 @@ class CMapTDB : public IMap
         void getArea_n_Scaling(XY& p1, XY& p2, float& my_xscale, float& my_yscale);
         void registerDEM(CMapDEM& dem);
         void select(IMapSelection& ms, const QRect& rect);
-        void getClosePolyline(QPoint& pt, qint32 threshold, QPolygon& line);
+        void getClosePolyline(QPoint& pt1, QPoint& pt2, qint32 threshold, QPolygon& line);
+
+        QString getCopyright();
+        QString getMapLevelInfo();
+        QString getLegendLines();
+        QString getLegendArea();
+        QString getLegendPoints();
 
 #ifdef SQL_SEARCH_GARMIN
         void createSearchIndex(QObject * reveiver, const char * slot);
@@ -84,22 +90,27 @@ class CMapTDB : public IMap
         void slotDetailChanged(int idx);
         void slotLanguageChanged(int idx);
         void slotTypfileChanged(int idx);
+        void slotToolTip();
 
     private:
         friend class CDlgMapTDBConfig;
         void setup();
         void checkTypFiles();
+        void checkMdrFile();
 
         struct strlbl_t
         {
+            strlbl_t() : type(IGarminTyp::eStandard){}
+
             QPoint  pt;
             QRect   rect;
             QString str;
+            IGarminTyp::label_type_e type;
         };
 
         struct typ_section_t
         {
-            typ_section_t() : dataOffset(0), dataLength(0), arrayOffset(0), arrayModulo(0), arraySize(0){};
+            typ_section_t() : dataOffset(0), dataLength(0), arrayOffset(0), arrayModulo(0), arraySize(0){}
             quint32  dataOffset;
             quint32  dataLength;
             quint32  arrayOffset;
@@ -126,6 +137,8 @@ class CMapTDB : public IMap
         void drawLine(QPainter& p, CGarminPolygon& l, const IGarminTyp::polyline_property& property, const QFontMetricsF& metrics, const QFont& font);
         void drawLine(QPainter& p, const CGarminPolygon& l);
 
+        QString createLegendString(const QMap<int,QString>& strings);
+
 #pragma pack(1)
         struct tdb_hdr_t
         {
@@ -239,6 +252,8 @@ class CMapTDB : public IMap
         QString filename;
         /// typ filename
         QString typfile;
+        /// mdr filename
+        QString mdrfile;
         /// copyright string
         QString copyright;
         /// map collection name
@@ -293,6 +308,7 @@ class CMapTDB : public IMap
         QPoint          topLeftInfo;
 
         QPoint          pointFocus;
+        QPoint          pointMouse;
 
         int detailsFineTune;
 
@@ -341,5 +357,7 @@ class CMapTDB : public IMap
 
         QComboBox * comboTypfiles;
 
+        QTimer * toolTipTimer;
+
 };
 #endif                           //CMAPTDB_H
