@@ -26,6 +26,8 @@
 #include "CGarminExport.h"
 #include "CMapSelectionGarmin.h"
 
+#include "config.h"
+
 #include <QtGui>
 
 CMapToolWidget::CMapToolWidget(QTabWidget * parent)
@@ -34,7 +36,7 @@ CMapToolWidget::CMapToolWidget(QTabWidget * parent)
 {
     setupUi(this);
     setObjectName("Maps");
-    parent->addTab(this,QIcon(":/icons/iconMap16x16"),"");
+    parent->addTab(this,QIcon(":/icons/iconMap16x16.png"),"");
     parent->setTabToolTip(parent->indexOf(this), tr("Maps"));
 
     connect(&CMapDB::self(), SIGNAL(sigChanged()), this, SLOT(slotDBChanged()));
@@ -42,7 +44,7 @@ CMapToolWidget::CMapToolWidget(QTabWidget * parent)
     contextMenuKnownMaps = new QMenu(this);
     actAddDEM = contextMenuKnownMaps->addAction(QPixmap(":/icons/iconDEM16x16.png"),tr("Add DEM..."),this,SLOT(slotAddDEM()));
     actDelDEM = contextMenuKnownMaps->addAction(QPixmap(":/icons/iconNoDEM16x16.png"),tr("Del. DEM..."),this,SLOT(slotDelDEM()));
-    actCfgMap = contextMenuKnownMaps->addAction(QPixmap(":/icons/iconConfig16x16.png"),tr("Configure"),this,SLOT(slotCfgMap()));
+    actCfgMap = contextMenuKnownMaps->addAction(QPixmap(":/icons/iconInfo16x16.png"),tr("Info/Config"),this,SLOT(slotCfgMap()));
     actDelMap = contextMenuKnownMaps->addAction(QPixmap(":/icons/iconClear16x16.png"),tr("Delete"),this,SLOT(slotDeleteKnownMap()));
     connect(treeKnownMapsRaster,SIGNAL(customContextMenuRequested(const QPoint&)),this,SLOT(slotContextMenuKnownMaps(const QPoint&)));
     connect(treeKnownMapsRaster,SIGNAL(itemClicked(QTreeWidgetItem*, int)),this,SLOT(slotKnownMapClicked(QTreeWidgetItem*, int)));
@@ -61,9 +63,9 @@ CMapToolWidget::CMapToolWidget(QTabWidget * parent)
 
     connect(pushExportMap, SIGNAL(clicked()), this, SLOT(slotExportMap()));
 
-    tabWidget->setTabIcon(0, QIcon(":/icons/iconRaster16x16"));
+    tabWidget->setTabIcon(0, QIcon(":/icons/iconRaster16x16.png"));
     tabWidget->setTabText(0,tr("Raster"));
-    tabWidget->setTabIcon(1, QIcon(":/icons/iconVector16x16"));
+    tabWidget->setTabIcon(1, QIcon(":/icons/iconVector16x16.png"));
     tabWidget->setTabText(1,tr("Vector"));
 
 }
@@ -101,23 +103,23 @@ void CMapToolWidget::slotDBChanged()
             item->setText(eName, map->description);
             item->setToolTip(eName, map->description);
             item->setData(eName, Qt::UserRole, map.key());
-            item->setIcon(eType, map->type == IMap::eRaster ? QIcon(":/icons/iconRaster16x16") : map->type == IMap::eGarmin ? QIcon(":/icons/iconVector16x16") : map->type == IMap::eTile ? QIcon(":/icons/iconTile16x16") : QIcon(":/icons/iconUnknown16x16"));
+            item->setIcon(eType, map->type == IMap::eRaster ? QIcon(":/icons/iconRaster16x16.png") : map->type == IMap::eGarmin ? QIcon(":/icons/iconVector16x16.png") : map->type == IMap::eTile ? QIcon(":/icons/iconTile16x16.png") : QIcon(":/icons/iconUnknown16x16.png"));
             item->setData(eType, Qt::UserRole, map->type);
 
             if(map.key() == key)
             {
                 selected = item;
-                item->setIcon(eMode, QIcon(QIcon(":/icons/iconOk16x16")));
+                item->setIcon(eMode, QIcon(QIcon(":/icons/iconOk16x16.png")));
                 item->setData(eMode, Qt::UserRole, eSelected);
             }
             else if(basemap.hasOverlayMap(map.key()))
             {
-                item->setIcon(eMode, QIcon(QIcon(":/icons/iconOvlOk16x16")));
+                item->setIcon(eMode, QIcon(QIcon(":/icons/iconOvlOk16x16.png")));
                 item->setData(eMode, Qt::UserRole, eOverlayActive);
             }
             else if(map->type == IMap::eGarmin)
             {
-                item->setIcon(eMode, QIcon(QIcon(":/icons/iconOvl16x16")));
+                item->setIcon(eMode, QIcon(QIcon(":/icons/iconOvl16x16.png")));
                 item->setData(eMode, Qt::UserRole, eOverlay);
             }
             else
@@ -166,10 +168,10 @@ void CMapToolWidget::slotDBChanged()
         {
             QListWidgetItem * item = new QListWidgetItem(listSelectedMaps);
 
-            item->setText((*map)->description);
-            item->setData(Qt::UserRole, (*map)->key);
+            item->setText((*map)->getDescription());
+            item->setData(Qt::UserRole, (*map)->getKey());
 
-            if(IMapSelection::focusedMap == (*map)->key) selected = item;
+            if(IMapSelection::focusedMap == (*map)->getKey()) selected = item;
             ++map;
         }
 
@@ -246,8 +248,7 @@ void CMapToolWidget::slotContextMenuKnownMaps(const QPoint& pos)
             actAddDEM->setEnabled(true);
             actDelDEM->setEnabled(dem.maptype == IMap::eDEM);
             int mapType = item->data(eType, Qt::UserRole).toInt();
-//            if(mapType == IMap::eGarmin || mapType == IMap::eTile)
-            if(0)
+            if(mapType == IMap::eGarmin || mapType == IMap::eRaster || mapType == IMap::eTile)
             {
                 actCfgMap->setEnabled(true);
             }
@@ -359,12 +360,12 @@ void CMapToolWidget::slotExportMap()
         proc1.start(GDALWARP " --version");
         proc1.waitForFinished();
         qDebug() << proc1.exitCode() << proc1.error() << proc1.errorString();
-        bool haveGDALWarp = proc1.exitCode() == 0;
+        bool haveGDALWarp = proc1.error() == QProcess::UnknownError;
 
         proc1.start(GDALTRANSLATE " --version");
         proc1.waitForFinished();
         qDebug() << proc1.exitCode() << proc1.error() << proc1.errorString();
-        bool haveGDALTranslate = proc1.exitCode() == 0;
+        bool haveGDALTranslate = proc1.error() == QProcess::UnknownError;
 
         bool haveGDAL = haveGDALWarp && haveGDALTranslate;
 
@@ -392,7 +393,7 @@ void CMapToolWidget::slotAddDEM()
     QSettings cfg;
     path = QDir(cfg.value("path/DEM",path.path()).toString());
 
-    QString filename = QFileDialog::getOpenFileName(0, tr("Select DEM file..."),path.path(), tr("16bit Srtm Data (*.tif *.tiff *.hgt)"), 0, QFileDialog::DontUseNativeDialog);
+    QString filename = QFileDialog::getOpenFileName(0, tr("Select DEM file..."),path.path(), tr("16bit Srtm Data (*.tif *.tiff *.hgt)"), 0, FILE_DIALOG_FLAGS);
     if(filename.isEmpty()) return;
 
     QFileInfo fi(filename);
@@ -410,6 +411,7 @@ void CMapToolWidget::slotDelDEM()
     {
         QSettings cfg;
         cfg.setValue(QString("map/dem/%1").arg(CMapDB::self().getMap().getKey()), "");
+        cfg.setValue(QString("map/dem/%1/ignoreWarning").arg(CMapDB::self().getMap().getKey()), false);
         dem.deleteLater();
     }
 }
