@@ -272,7 +272,7 @@ void CMegaMenu::paintEvent(QPaintEvent *e)
         style()->drawControl(QStyle::CE_MenuItem, &opt, &p, this);
 
         ++idx;
-        if (idx >= 11)
+        if (idx >= SIZE_OF_MEGAMENU)
             break;
     }
 }
@@ -289,7 +289,7 @@ void CMegaMenu::resizeEvent(QResizeEvent * e)
     yoff    = 0;
 
     rectTitle = QRect(0,yoff, w, h);
-    for(int i=0; i < 11; ++i)
+    for(int i=0; i < SIZE_OF_MEGAMENU; ++i)
     {
         yoff += h;
         rectF[i] = QRect(0,yoff, w, h);
@@ -321,7 +321,7 @@ void CMegaMenu::mouseReleaseEvent(QMouseEvent * e)
 
     QPoint pos = e->pos();
     currentItemIndex = -1;
-    for(int i = 0; i < 11; ++i)
+    for(int i = 0; i < SIZE_OF_MEGAMENU; ++i)
     {
         if(rectF[i].contains(pos))
         {
@@ -342,7 +342,7 @@ void CMegaMenu::mouseMoveEvent(QMouseEvent * e)
 {
     QPoint pos = e->pos();
     currentItemIndex = -1;
-    for(int i = 0; i < 11; ++i)
+    for(int i = 0; i < SIZE_OF_MEGAMENU; ++i)
     {
         if(rectF[i].contains(pos))
         {
