@@ -35,11 +35,15 @@ class CMouseMoveMap : public IMouse
         void mouseMoveEvent(QMouseEvent * e);
         void mousePressEvent(QMouseEvent * e);
         void mouseReleaseEvent(QMouseEvent * e);
+        void mouseDoubleClickEvent(QMouseEvent * e);
+        void keyPressEvent(QKeyEvent * e);
+        void keyReleaseEvent(QKeyEvent * e);
 
         void draw(QPainter& p);
 
         void contextMenu(QMenu& menu);
 
+
     private slots:
         void slotEditWpt();
         void slotCopyPositionWpt();
@@ -50,13 +54,21 @@ class CMouseMoveMap : public IMouse
         void slotEditTrack();
 		void slotOpenGoogleMaps();	//TODO: GOOGLE MAPS
 
+        void slotCopyPosDegree();
+        void slotCopyPosMeter();
+        void slotCopyPosPixel();
+        void slotCopyPosPixelSize();
+
     private:
         /// true if left mouse button is pressed
         bool moveMap;
+
+        bool leftButtonPressed;
+        bool altKeyPressed;
+
         /// the initial starting point of the transformation
         QPoint oldPoint;
 
-        QPoint mousePos;
 
 };
 #endif                           //CMOUSEMOVEMAP_H
