@@ -33,7 +33,7 @@ CMouseMoveWpt::CMouseMoveWpt(CCanvas * canvas)
 : IMouse(canvas)
 , moveWpt(false)
 {
-    cursor = QCursor(QPixmap(":/cursors/cursorMoveWpt"),0,0);
+    cursor = QCursor(QPixmap(":/cursors/cursorMoveWpt.png"),0,0);
 }
 
 
@@ -66,7 +66,7 @@ void CMouseMoveWpt::mousePressEvent(QMouseEvent * e)
             newPos = e->pos();
             moveWpt = true;
         }
-        else if(moveWpt && !selWpt.isNull())
+        else if(moveWpt && !selWpt.isNull() && selWpt->isMovable())
         {
             IMap& map = CMapDB::self().getMap();
             double u = e->pos().x();
@@ -80,6 +80,7 @@ void CMouseMoveWpt::mousePressEvent(QMouseEvent * e)
 
             emit CWptDB::self().sigChanged();
             emit CWptDB::self().sigModified();
+            emit CWptDB::self().sigModified(selWpt->getKey());
 
             moveWpt = false;
             canvas->setMouseMode(CCanvas::eMouseMoveArea);
@@ -101,7 +102,7 @@ void CMouseMoveWpt::mouseReleaseEvent(QMouseEvent * e)
 
 void CMouseMoveWpt::draw(QPainter& p)
 {
-    if(moveWpt && !selWpt.isNull())
+    if(moveWpt && !selWpt.isNull() && selWpt->isMovable())
     {
         double x1, y1, x2, y2;
         XY p1, p2;
@@ -129,7 +130,7 @@ void CMouseMoveWpt::draw(QPainter& p)
         p.drawLine(x1, y1, x2, y2);
 
         // draw waypoint icon
-        QPixmap icon = getWptIconByName(selWpt->icon);
+        QPixmap icon = selWpt->getIcon();
         QPixmap back = QPixmap(icon.size());
         back.fill(Qt::white);
         back.setMask(icon.alphaChannel().createMaskFromColor(Qt::black));
