@@ -29,7 +29,7 @@ CMouseRefPoint::CMouseRefPoint(CCanvas * canvas)
 , moveRef(false)
 , selRefPt(0)
 {
-    cursor = QCursor(QPixmap(":/cursors/cursorMoveRefPoint"),0,0);
+    cursor = QCursor(QPixmap(":/cursors/cursorMoveRefPoint.png"),0,0);
 }
 
 
@@ -49,7 +49,7 @@ void CMouseRefPoint::draw(QPainter& p)
         double y = selRefPt->y;
         map.convertM2Pt(x,y);
 
-        p.drawPixmap(x - 15,y - 31,QPixmap(":/icons/iconRefPointHL31x31"));
+        p.drawPixmap(x - 15,y - 31,QPixmap(":/icons/iconRefPointHL31x31.png"));
 
     }
 }
@@ -59,6 +59,8 @@ void CMouseRefPoint::mouseMoveEvent(QMouseEvent * e)
 {
     IMap& map = CMapDB::self().getMap();
 
+    mousePos = e->pos();
+
     if(moveMap)
     {
         map.move(oldPoint, e->pos());
@@ -135,12 +137,17 @@ void CMouseRefPoint::mousePressEvent(QMouseEvent * e)
         }
         else
         {
-            cursor = QCursor(QPixmap(":/cursors/cursorMove"));
+            cursor = QCursor(QPixmap(":/cursors/cursorMove.png"));
             QApplication::setOverrideCursor(cursor);
             moveMap     = true;
             oldPoint    = e->pos();
         }
     }
+    else if(e->button() == Qt::RightButton)
+    {
+        mousePos = e->pos();
+        canvas->raiseContextMenu(e->pos());
+    }
 
     canvas->update();
 }
@@ -153,7 +160,7 @@ void CMouseRefPoint::mouseReleaseEvent(QMouseEvent * e)
         if(moveMap)
         {
             moveMap = false;
-            cursor = QCursor(QPixmap(":/cursors/cursorMoveRefPoint"),0,0);
+            cursor = QCursor(QPixmap(":/cursors/cursorMoveRefPoint.png"),0,0);
             QApplication::restoreOverrideCursor();
             canvas->update();
         }
@@ -173,3 +180,64 @@ void CMouseRefPoint::mouseReleaseEvent(QMouseEvent * e)
         }
     }
 }
+
+void CMouseRefPoint::contextMenu(QMenu& menu)
+{
+    IMap& map = CMapDB::self().getMap();
+
+    double u = mousePos.x();
+    double v = mousePos.y();
+    map.convertPt2Pixel(u,v);
+
+    if(u >= 0 && v >= 0)
+    {
+        QString posPixel = tr("Pixel %1x%2").arg(u, 0,'f',0).arg(v,0,'f',0);
+        menu.addAction(QIcon(":/icons/iconClipboard16x16.png"), posPixel, this, SLOT(slotCopyPosPixel()));
+
+        if(pos1Pixel.x() >= 0 && pos1Pixel.y() >= 0)
+        {
+            double u1 = pos1Pixel.x();
+            double v1 = pos1Pixel.y();
+
+            QString posPixelSize = tr("Pos1 -> Pos %1x%2 w:%3 h:%4").arg(u1, 0,'f',0).arg(v1,0,'f',0).arg(u - u1,0,'f',0).arg(v - v1, 0,'f',0);
+            menu.addAction(QIcon(":/icons/iconClipboard16x16.png"), posPixelSize, this, SLOT(slotCopyPosPixelSize()));
+        }
+
+        menu.addAction(QIcon(":/icons/wpt/flag_pin_red15x15.png"), tr("Set as Pos1"), this, SLOT(slotSetPos1()));
+
+    }
+
+}
+
+void CMouseRefPoint::slotCopyPosPixel()
+{
+    IMap& map = CMapDB::self().getMap();
+
+    double u = mousePos.x();
+    double v = mousePos.y();
+
+    map.convertPt2Pixel(u,v);
+    QString position = QString("%1 %2").arg(u, 0,'f',0).arg(v,0,'f',0);
+
+    QClipboard *clipboard = QApplication::clipboard();
+    clipboard->setText(position);
+
+}
+
+void CMouseRefPoint::slotCopyPosPixelSize()
+{
+    IMap& map = CMapDB::self().getMap();
+
+    double u1 = pos1Pixel.x();
+    double v1 = pos1Pixel.y();
+    double u2 = mousePos.x();
+    double v2 = mousePos.y();
+
+    map.convertPt2Pixel(u2,v2);
+    QString position = QString("%1 %2 %3 %4").arg(u1, 0,'f',0).arg(v1,0,'f',0).arg(u2 - u1, 0,'f',0).arg(v2 - v1,0,'f',0);
+
+    QClipboard *clipboard = QApplication::clipboard();
+    clipboard->setText(position);
+
+}
+
