@@ -28,6 +28,7 @@
 #include "CQlb.h"
 #include "CGpx.h"
 #include "CDlgCombineDistOvl.h"
+#include "CMapDB.h"
 
 #include <QtGui>
 #include <projects.h>
@@ -42,13 +43,18 @@ COverlayDB::COverlayDB(QTabWidget * tb, QObject * parent)
 , addOverlaysAsDuplicate(false)
 {
     m_self      = this;
+
+    QSettings cfg;
+    COverlayDistance::setShowBullets(cfg.value("overlay/showBullets", COverlayDistance::getShowBullets()).toBool());
+
     toolview    = new COverlayToolWidget(tb);
 }
 
 
 COverlayDB::~COverlayDB()
 {
-
+    QSettings cfg;
+    cfg.setValue("overlay/showBullets", COverlayDistance::getShowBullets());
 }
 
 
@@ -71,13 +77,11 @@ void COverlayDB::looseFocus()
 
 void COverlayDB::draw(QPainter& p, const QRect& r, bool& needsRedraw)
 {
-    p.setRenderHint(QPainter::Antialiasing,true);
     IOverlay * overlay;
     foreach(overlay, overlays)
     {
-        overlay->draw(p);
+        overlay->draw(p, r);
     }
-    p.setRenderHint(QPainter::Antialiasing,false);
 }
 
 
@@ -86,6 +90,7 @@ void COverlayDB::loadGPX(CGpx& gpx)
     if (gpx.version() == CGpx::qlVer_foreign)
         return;
 
+    bool hasItems = false;
     // QLandkarteGT file format v1.0 had more than one extensions
     // tags, so we have to scan all of them.  We can stop once we
     // found an overlay tag below it.
@@ -93,15 +98,14 @@ void COverlayDB::loadGPX(CGpx& gpx)
     while(!extensions.isNull())
     {
         QMap<QString,QDomElement> extensionsmap = CGpx::mapChildElements(extensions);
-        const QDomElement ovl = extensionsmap.value(gpx.version() == CGpx::qlVer_1_0?
-            "overlays":
-        (CGpx::ql_ns + ":" + "overlays"));
+        const QDomElement ovl = extensionsmap.value(gpx.version() == CGpx::qlVer_1_0 ? "overlays" : (CGpx::ql_ns + ":" + "overlays"));
         if(!ovl.isNull())
         {
             QDomNodeList ovllist = ovl.childNodes();
             uint i;
             for(i = 0; i < ovllist.length(); i++)
             {
+                hasItems = true;
                 QDomNode child = ovllist.item(i);
                 QString type;
                 if (child.isNull() || !child.isElement())
@@ -118,9 +122,7 @@ void COverlayDB::loadGPX(CGpx& gpx)
                 }
                 const QDomElement element = child.toElement();
 
-                if(type == (gpx.version() == CGpx::qlVer_1_0?
-                    "text":
-                    (CGpx::ql_ns + ":" + "text")))
+                if(type == (gpx.version() == CGpx::qlVer_1_0 ? "text" : (CGpx::ql_ns + ":" + "text")))
                 {
                     int top     = element.attribute("top","0").toInt();
                     int left    = element.attribute("left","0").toInt();
@@ -131,12 +133,10 @@ void COverlayDB::loadGPX(CGpx& gpx)
                     if(rect.isValid())
                     {
                         QString text = element.text();
-                        addText(text,rect);
+                        addText(text,rect, "", true);
                     }
                 }
-                else if(type == (gpx.version() == CGpx::qlVer_1_0?
-                    "textbox":
-                    (CGpx::ql_ns + ":" + "textbox")))
+                else if(type == (gpx.version() == CGpx::qlVer_1_0 ? "textbox" : (CGpx::ql_ns + ":" + "textbox")))
                 {
                     int top     = element.attribute("top","0").toInt();
                     int left    = element.attribute("left","0").toInt();
@@ -151,12 +151,10 @@ void COverlayDB::loadGPX(CGpx& gpx)
                     if(rect.isValid())
                     {
                         QString text = element.text();
-                        addTextBox(text,lon, lat, QPoint(anchorx, anchory), rect);
+                        addTextBox(text,lon, lat, QPoint(anchorx, anchory), rect, "", true);
                     }
                 }
-                else if(type == (gpx.version() == CGpx::qlVer_1_0?
-                    "distance":
-                    (CGpx::ql_ns + ":" + "distance")))
+                else if(type == (gpx.version() == CGpx::qlVer_1_0 ? "distance" : (CGpx::ql_ns + ":" + "distance")))
                 {
                     QString name;
                     QString comment;
@@ -195,7 +193,7 @@ void COverlayDB::loadGPX(CGpx& gpx)
                         points << pt;
                     }
 
-                    addDistance(name, comment, speed, points);
+                    addDistance(name, comment, speed, points, "", true);
                 }
 
             }
@@ -203,12 +201,18 @@ void COverlayDB::loadGPX(CGpx& gpx)
         }
         extensions = extensions.nextSiblingElement("extensions");
     }
+    IOverlay::resetKeyCnt();
+
+    if(hasItems)
+    {
+        emit sigChanged();
+    }
 }
 
 
 void COverlayDB::saveGPX(CGpx& gpx, const QStringList& keys)
 {
-    if (gpx.getExportFlag())
+    if ((gpx.getExportMode() != CGpx::eQlgtExport))
     {
         return;
     }
@@ -218,7 +222,6 @@ void COverlayDB::saveGPX(CGpx& gpx, const QStringList& keys)
     }
 
     QString str;
-    QDomElement root        = gpx.documentElement();
     QDomElement extensions  = gpx.getExtensions();
     QDomElement _overlay_   = gpx.createElement("ql:overlays");
 
@@ -241,7 +244,7 @@ void COverlayDB::saveGPX(CGpx& gpx, const QStringList& keys)
             text.setAttribute("width", overlaytext->rect.width());
             text.setAttribute("height", overlaytext->rect.height());
 
-            QDomText _text_ = gpx.createTextNode(overlaytext->sometext);
+            QDomText _text_ = gpx.createTextNode(overlaytext->comment);
             text.appendChild(_text_);
         }
         else if(overlay->type == "TextBox")
@@ -263,7 +266,7 @@ void COverlayDB::saveGPX(CGpx& gpx, const QStringList& keys)
             str.sprintf("%1.8f",ovl->lat * RAD_TO_DEG);
             text.setAttribute("lat", str);
 
-            QDomText _text_ = gpx.createTextNode(ovl->text);
+            QDomText _text_ = gpx.createTextNode(ovl->comment);
             text.appendChild(_text_);
         }
         else if(overlay->type == "Distance")
@@ -301,17 +304,22 @@ void COverlayDB::saveGPX(CGpx& gpx, const QStringList& keys)
 }
 
 
-void COverlayDB::loadQLB(CQlb& qlb)
+void COverlayDB::loadQLB(CQlb& qlb, bool newKey)
 {
     QDataStream stream(&qlb.overlays(),QIODevice::ReadOnly);
     stream.setVersion(QDataStream::Qt_4_5);
 
+    addOverlaysAsDuplicate = newKey;
     while(!stream.atEnd())
     {
         stream >> *this;
     }
+    addOverlaysAsDuplicate = false;
 
-    emit sigChanged();
+    if(qlb.overlays().size())
+    {
+        emit sigChanged();
+    }
 }
 
 
@@ -329,6 +337,7 @@ void COverlayDB::saveQLB(CQlb& qlb)
 void COverlayDB::clear()
 {
     delOverlays(overlays.keys());
+    IOverlay::resetKeyCnt();
 }
 
 
@@ -337,66 +346,119 @@ void COverlayDB::delOverlays(const QStringList& keys)
     QString key;
     foreach(key, keys)
     {
-        IOverlay * overlay = overlays.take(key);
-        overlay->deleteLater();
+        delOverlay(key, true);
     }
-    emit sigChanged();
-    emit sigModified();
+    if(!keys.isEmpty())
+    {
+        emit sigChanged();
+        emit sigModified();
+    }
+
 }
 
+void COverlayDB::delOverlay(const QString& key, bool silent)
+{
+    if(overlays.contains(key))
+    {
+        IOverlay * overlay = overlays.take(key);
+        overlay->deleteLater();
 
-COverlayText * COverlayDB::addText(const QString& text, const QRect& rect, const QString& key)
+        if(!silent)
+        {
+            emit sigChanged();
+            emit sigModified();
+        }
+    }
+}
+
+COverlayText * COverlayDB::addText(const QString& text, const QRect& rect, const QString& key, bool silent)
 {
     IOverlay * overlay = new COverlayText(text, rect, this);
-    if(!key.isEmpty() && !addOverlaysAsDuplicate)
+
+    if(addOverlaysAsDuplicate)
     {
-        overlay->_key_ = key;
+        if(key.isEmpty())
+        {
+            overlay->setKey(key + QString("%1").arg(QDateTime::currentDateTime().toTime_t()));
+        }
     }
-    overlays[overlay->key()] = overlay;
+    else
+    {
+        overlay->setKey(key);
+    }
+
+    overlays[overlay->getKey()] = overlay;
 
     connect(overlay, SIGNAL(sigChanged()),SIGNAL(sigChanged()));
     connect(overlay, SIGNAL(sigChanged()),SIGNAL(sigModified()));
+    connect(overlay, SIGNAL(sigChanged()),SLOT(slotModified()));
 
-    emit sigChanged();
-    emit sigModified();
+    if(!silent)
+    {
+        emit sigChanged();
+    }
 
     return qobject_cast<COverlayText*>(overlay);
 }
 
 
-COverlayTextBox * COverlayDB::addTextBox(const QString& text, double lon, double lat, const QPoint& anchor, const QRect& rect, const QString& key)
+COverlayTextBox * COverlayDB::addTextBox(const QString& text, double lon, double lat, const QPoint& anchor, const QRect& rect, const QString& key, bool silent)
 {
     IOverlay * overlay = new COverlayTextBox(text, lon, lat, anchor, rect, this);
-    if(!key.isEmpty() && !addOverlaysAsDuplicate)
+
+    if(addOverlaysAsDuplicate)
     {
-        overlay->_key_ = key;
+        if(key.isEmpty())
+        {
+            overlay->setKey(key + QString("%1").arg(QDateTime::currentDateTime().toTime_t()));
+        }
     }
-    overlays[overlay->key()] = overlay;
+    else
+    {
+        overlay->setKey(key);
+    }
+
+    overlays[overlay->getKey()] = overlay;
 
     connect(overlay, SIGNAL(sigChanged()),SIGNAL(sigChanged()));
     connect(overlay, SIGNAL(sigChanged()),SIGNAL(sigModified()));
+    connect(overlay, SIGNAL(sigChanged()),SLOT(slotModified()));
 
-    emit sigChanged();
-    emit sigModified();
+    if(!silent)
+    {
+        emit sigChanged();
+    }
 
     return qobject_cast<COverlayTextBox*>(overlay);
 }
 
 
-COverlayDistance * COverlayDB::addDistance(const QString& name, const QString& comment, double speed, const QList<COverlayDistance::pt_t>& pts, const QString& key)
+COverlayDistance * COverlayDB::addDistance(const QString& name, const QString& comment, double speed, const QList<COverlayDistance::pt_t>& pts, const QString& key, bool silent)
 {
     IOverlay * overlay = new COverlayDistance(name, comment, speed, pts, this);
-    if(!key.isEmpty() && !addOverlaysAsDuplicate)
+
+    if(addOverlaysAsDuplicate)
     {
-        overlay->_key_ = key;
+        if(key.isEmpty())
+        {
+            overlay->setKey(key + QString("%1").arg(QDateTime::currentDateTime().toTime_t()));
+        }
     }
-    overlays[overlay->key()] = overlay;
+    else
+    {
+        overlay->setKey(key);
+    }
+
+    overlays[overlay->getKey()] = overlay;
 
     connect(overlay, SIGNAL(sigChanged()),SIGNAL(sigChanged()));
     connect(overlay, SIGNAL(sigChanged()),SIGNAL(sigModified()));
+    connect(overlay, SIGNAL(sigChanged()),SLOT(slotModified()));
 
-    emit sigChanged();
-    emit sigModified();
+    if(!silent)
+    {
+        emit sigChanged();
+    }
 
     return qobject_cast<COverlayDistance*>(overlay);
 }
@@ -470,9 +532,7 @@ void COverlayDB::pasteFromClipboard()
         CQlb qlb(this);
         qlb.load(&buffer);
 
-        addOverlaysAsDuplicate = true;
-        loadQLB(qlb);
-        addOverlaysAsDuplicate = false;
+        loadQLB(qlb, true);
 
         emit sigModified();
     }
@@ -528,3 +588,86 @@ void COverlayDB::combineDistOvl()
     dlg.exec();
 
 }
+
+QList<COverlayDB::keys_t> COverlayDB::keys()
+{
+    QList<keys_t> k;
+
+    QString k1;
+    QStringList ks = overlays.keys();
+
+    foreach(k1, ks)
+    {
+        keys_t k2;
+        IOverlay * ovl = overlays[k1];
+
+        if(ovl->type == "Text")
+        {
+            COverlayText * text = qobject_cast<COverlayText*>(ovl);
+
+            k2.key      = k1;
+            k2.name     = tr("Static text");
+            k2.comment  = text->getInfo();
+            k2.icon     = text->getIcon();
+
+        }
+        else if(ovl->type == "TextBox")
+        {
+            COverlayTextBox * textbox = qobject_cast<COverlayTextBox*>(ovl);
+            k2.key      = k1;
+            k2.name     = tr("Geo ref. text");
+            k2.comment  = textbox->getInfo();
+            k2.icon     = textbox->getIcon();
+        }
+        else if(ovl->type == "Distance")
+        {
+            COverlayDistance * dist = qobject_cast<COverlayDistance*>(ovl);
+            k2.key      = k1;
+            k2.name     = dist->name;
+            k2.comment  = dist->comment.left(32);
+            k2.icon     = dist->getIcon();
+        }
+
+
+        k << k2;
+    }
+
+    return k;
+}
+
+void COverlayDB::slotModified()
+{
+    IOverlay * ovl = qobject_cast<IOverlay*>(sender());
+    if(ovl)
+    {
+        emit sigModified(ovl->getKey());
+    }
+}
+
+
+void COverlayDB::makeVisible(const QStringList& keys)
+{
+    QRectF r;
+    QString key;
+    foreach(key, keys)
+    {
+
+        IOverlay * ovl =  overlays[key];
+
+        if(r.isNull() && !ovl->getBoundingRectF().isNull())
+        {
+            r = ovl->getBoundingRectF();
+        }
+        else if(!ovl->getBoundingRectF().isNull())
+        {
+            r |= ovl->getBoundingRectF();
+        }
+
+    }
+
+    if (!r.isNull ())
+    {
+        CMapDB::self().getMap().zoom(r.left() * DEG_TO_RAD, r.top() * DEG_TO_RAD, r.right() * DEG_TO_RAD, r.bottom() * DEG_TO_RAD);
+    }
+
+}
