@@ -56,7 +56,7 @@ class COverlayDistance : public IOverlay
         bool isCloseEnough(const QPoint& pt);
 
         /// draw the ployline, waypoints and action icons
-        void draw(QPainter& p);
+        void draw(QPainter& p, const QRect& viewport);
 
         void mouseMoveEvent(QMouseEvent * e);
         void mousePressEvent(QMouseEvent * e);
@@ -80,10 +80,10 @@ class COverlayDistance : public IOverlay
 
         void delPointsByIdx(const QList<int>& idx);
 
-        const QString& getName(){return name;}
-
         const QList<pt_t>& getPoints(){return points;}
 
+        static void setShowBullets(bool show){showBullets = show;}
+        static bool getShowBullets(){return showBullets;}
     signals:
         void sigSelectionChanged();
 
@@ -91,12 +91,16 @@ class COverlayDistance : public IOverlay
         void slotToTrack();
         void slotToRoute();
         void slotEdit();
+        void slotRevert();
+        void slotShow();
+        void slotShowBullets();
 
     private:
         friend class COverlayDB;
         friend class COverlayDistanceEditWidget;
 
         void calcDistance();
+        void drawArrows(const QPolygon& line, const QRect& viewport, QPainter& p);
 
         /// the polyline as list of points [rad]
         QList<pt_t> points;
@@ -107,10 +111,6 @@ class COverlayDistance : public IOverlay
         /// need to restore point if move command is aborted
         pt_t savePoint;
 
-        /// line name
-        QString name;
-        /// line comment
-        QString comment;
         /// the distance in [m]
         double distance;
         /// optional speed in km/s, <=0 is no speed
@@ -146,7 +146,7 @@ class COverlayDistance : public IOverlay
 
         bool isEdit;
 
-
+        static bool showBullets;
 };
 
 #define OVL_NOFLOAT 1e25f
