@@ -28,12 +28,11 @@
 #include <QtGui>
 
 COverlayTextBox::COverlayTextBox(const QString& text, double lon, double lat, const QPoint& anchor, const QRect& r, QObject * parent)
-: IOverlay(parent, "TextBox", QPixmap(":/icons/iconTextBox16x16"))
+: IOverlay(parent, "TextBox", ":/icons/iconTextBox16x16.png")
 , lon(lon)
 , lat(lat)
 , rect(r)
 , pt(anchor)
-, text(text)
 , doMove(false)
 , doSize(false)
 , doPos(false)
@@ -48,11 +47,13 @@ COverlayTextBox::COverlayTextBox(const QString& text, double lon, double lat, co
     rectEdit    = QRect(rect.topLeft()     + QPoint(20,2) , QSize(16, 16));
     rectDel     = QRect(rect.topRight()    - QPoint(18,-2), QSize(16, 16));
     rectSize    = QRect(rect.bottomRight() - QPoint(16,16), QSize(16, 16));
-    rectDoc     = QRect(rect.topLeft()     + QPoint(5,20)  , rect.size() - QSize(10, 40));
+    rectDoc     = QRect(rect.topLeft()     + QPoint(5,5)  , rect.size() - QSize(10, 10));
     rectAnchor  = QRect(QPoint(-7,-7), QSize(16, 16));
 
+    comment = text;
+
     doc = new QTextDocument(this);
-    doc->setHtml(text);
+    doc->setHtml(comment);
     doc->setPageSize(rectDoc.size());
 
 }
@@ -64,9 +65,9 @@ COverlayTextBox::~COverlayTextBox()
 }
 
 
-QPolygon COverlayTextBox::makePolyline(const QPoint& anchor, const QRect& r)
+QPolygonF COverlayTextBox::makePolyline(const QPoint& anchor, const QRect& r)
 {
-    QPolygon poly1, poly2;
+    QPolygonF poly1, poly2;
     poly1 << r.topLeft() << r.topRight() << r.bottomRight() << r.bottomLeft();
 
     if(!r.contains(anchor))
@@ -82,29 +83,37 @@ QPolygon COverlayTextBox::makePolyline(const QPoint& anchor, const QRect& r)
 
         if(anchor.x() < r.left())
         {
-            poly2 << anchor << (r.center() + QPoint(0,-h)) << (r.center() + QPoint(0,h));
+            poly2 << anchor << (r.center() + QPoint(0,-h)) << (r.center() + QPoint(0,h)) << anchor;
         }
         else if(r.right() < anchor.x())
         {
-            poly2 << anchor << (r.center() + QPoint(0,-h)) << (r.center() + QPoint(0,h));
+            poly2 << anchor << (r.center() + QPoint(0,-h)) << (r.center() + QPoint(0,h)) << anchor;
         }
         else if(anchor.y() < r.top())
         {
-            poly2 << anchor << (r.center() + QPoint(-w,0)) << (r.center() + QPoint(w,0));
+            poly2 << anchor << (r.center() + QPoint(-w,0)) << (r.center() + QPoint(w,0)) << anchor;
         }
         else if(r.bottom() < anchor.y())
         {
-            poly2 << anchor << (r.center() + QPoint(-w,0)) << (r.center() + QPoint(w,0));
+            poly2 << anchor << (r.center() + QPoint(-w,0)) << (r.center() + QPoint(w,0)) << anchor;
         }
 
-        poly1 = poly1.united(poly2);
+        QPainterPath path1;
+        path1.addRoundedRect(r,5,5);
+        QPainterPath path2;
+        path2.addPolygon(poly2);
+
+        path1 = path1.united(path2);
+
+
+        poly1 = path1.toFillPolygon();
     }
 
     return poly1;
 }
 
 
-void COverlayTextBox::draw(QPainter& p)
+void COverlayTextBox::draw(QPainter& p, const QRect& viewport)
 {
     double x = lon;
     double y = lat;
@@ -116,7 +125,7 @@ void COverlayTextBox::draw(QPainter& p)
     if(selected == this)
     {
         p.setBrush(Qt::white);
-        p.setPen(QPen(Qt::red, 2));
+        p.setPen(QPen(Qt::red,3));
         p.drawPolygon(polyline);
 
         p.drawPixmap(rectMove, QPixmap(":/icons/iconMoveMap16x16.png"));
@@ -135,7 +144,7 @@ void COverlayTextBox::draw(QPainter& p)
         else
         {
             p.setBrush(Qt::white);
-            p.setPen(Qt::black);
+            p.setPen(QPen(Qt::darkGray,2));
         }
         p.drawPolygon(polyline);
     }
@@ -152,7 +161,7 @@ void COverlayTextBox::draw(QPainter& p)
 
 bool COverlayTextBox::isCloseEnough(const QPoint& pt)
 {
-    QPolygon box = polyline;
+    QPolygonF box = polyline;
 
     double x = lon;
     double y = lat;
@@ -160,7 +169,7 @@ bool COverlayTextBox::isCloseEnough(const QPoint& pt)
     CMapDB::self().getMap().convertRad2Pt(x,y);
     box.translate(x,y);
 
-    QRect r = box.boundingRect();
+    QRectF r = box.boundingRect();
     r.setTopLeft(r.topLeft() - QPoint(8,8));
     r.setBottomRight(r.bottomRight() + QPoint(8,8));
 
@@ -189,13 +198,15 @@ QString COverlayTextBox::getInfo()
 
 void COverlayTextBox::save(QDataStream& s)
 {
-    s << lon << lat << pt << rect << text << _key_;
+    s << lon << lat << pt << rect << comment << getKey();
 }
 
 
 void COverlayTextBox::load(QDataStream& s)
 {
-    s >> lon >> lat >> pt >> rect >> text >> _key_;
+    QString key;
+    s >> lon >> lat >> pt >> rect >> comment >> key;
+    setKey(key);
 }
 
 
@@ -214,7 +225,7 @@ void COverlayTextBox::mouseMoveEvent(QMouseEvent * e)
         rectDel  = QRect(rect.topRight()    - QPoint(18,-2), QSize(16, 16));
         rectSize = QRect(rect.bottomRight() - QPoint(16,16), QSize(16, 16));
 
-        rectDoc  = QRect(rect.topLeft()     + QPoint(5,20)  , rect.size() - QSize(10, 40));
+        rectDoc     = QRect(rect.topLeft()     + QPoint(5,5)  , rect.size() - QSize(10, 10));
         doc->setPageSize(rectDoc.size());
 
         polyline = makePolyline(QPoint(0,0), rect);
@@ -229,7 +240,7 @@ void COverlayTextBox::mouseMoveEvent(QMouseEvent * e)
         rectDel  = QRect(rect.topRight()    - QPoint(18,-2), QSize(16, 16));
         rectSize = QRect(rect.bottomRight() - QPoint(16,16), QSize(16, 16));
 
-        rectDoc  = QRect(rect.topLeft()     + QPoint(5,20)  , rect.size() - QSize(10, 40));
+        rectDoc     = QRect(rect.topLeft()     + QPoint(5,5)  , rect.size() - QSize(10, 10));
         doc->setPageSize(rectDoc.size());
 
         polyline = makePolyline(QPoint(0,0), rect);
@@ -243,7 +254,7 @@ void COverlayTextBox::mouseMoveEvent(QMouseEvent * e)
         rectEdit    = QRect(rect.topLeft()     + QPoint(20,2) , QSize(16, 16));
         rectDel     = QRect(rect.topRight()    - QPoint(18,-2), QSize(16, 16));
         rectSize    = QRect(rect.bottomRight() - QPoint(16,16), QSize(16, 16));
-        rectDoc     = QRect(rect.topLeft()     + QPoint(5,20)  , rect.size() - QSize(10, 40));
+        rectDoc     = QRect(rect.topLeft()     + QPoint(5,5)  , rect.size() - QSize(10, 10));
 
         doc->setPageSize(rectDoc.size());
 
@@ -291,18 +302,19 @@ void COverlayTextBox::mousePressEvent(QMouseEvent * e)
     }
     else if(rectEdit.contains(pos))
     {
-        CDlgEditText dlg(text, theMainWindow->getCanvas());
+        CDlgEditText dlg(comment, theMainWindow->getCanvas());
         dlg.exec();
-        doc->setHtml(text);
+        doc->setHtml(comment);
         theMainWindow->getCanvas()->update();
         emit sigChanged();
     }
     else if(rectDel.contains(pos))
     {
-        QStringList keys(key());
+        QStringList keys(getKey());
         COverlayDB::self().delOverlays(keys);
         QApplication::restoreOverrideCursor();
         doSpecialCursor = false;
+        theMainWindow->getCanvas()->setMouseMode(CCanvas::eMouseMoveArea);
     }
 }
 
@@ -324,7 +336,7 @@ void COverlayTextBox::mouseReleaseEvent(QMouseEvent * e)
         rectEdit    = QRect(rect.topLeft()     + QPoint(20,2) , QSize(16, 16));
         rectDel     = QRect(rect.topRight()    - QPoint(18,-2), QSize(16, 16));
         rectSize    = QRect(rect.bottomRight() - QPoint(16,16), QSize(16, 16));
-        rectDoc     = QRect(rect.topLeft()     + QPoint(5,20)  , rect.size() - QSize(10, 40));
+        rectDoc     = QRect(rect.topLeft()     + QPoint(5,5)  , rect.size() - QSize(10, 10));
         rectAnchor  = QRect(QPoint(-9,-9), QSize(16, 16));
 
         lon = e->pos().x();
