@@ -31,10 +31,11 @@ COverlayToolWidget::COverlayToolWidget(QTabWidget * parent)
     setupUi(this);
     setObjectName("Overlay");
 
-    parent->addTab(this,QIcon(":/icons/iconOverlay16x16"),"");
+    parent->addTab(this,QIcon(":/icons/iconOverlay16x16.png"),"");
     parent->setTabToolTip(parent->indexOf(this), tr("Draw"));
 
     connect(&COverlayDB::self(), SIGNAL(sigChanged()), this, SLOT(slotDBChanged()));
+    connect(&COverlayDB::self(), SIGNAL(sigModified()), this, SLOT(slotDBChanged()));
     connect(listOverlays,SIGNAL(itemDoubleClicked(QListWidgetItem*) ),this,SLOT(slotItemDoubleClicked(QListWidgetItem*)));
     connect(listOverlays,SIGNAL(itemClicked(QListWidgetItem*) ),this,SLOT(slotItemClicked(QListWidgetItem*)));
     connect(listOverlays,SIGNAL(itemSelectionChanged()),this,SLOT(slotSelectionChanged()));
@@ -55,15 +56,39 @@ void COverlayToolWidget::slotDBChanged()
 
     listOverlays->clear();
 
-    QMap<QString, IOverlay*>& overlays                  = COverlayDB::self().overlays;
-    QMap<QString, IOverlay*>::const_iterator overlay    = overlays.begin();
-    while(overlay != overlays.end())
+    QMap<QString, IOverlay*>& overlays  = COverlayDB::self().overlays;
+    QList<COverlayDB::keys_t> keys      = COverlayDB::self().keys();
+
+    COverlayDB::keys_t key;
+
+    foreach(key, keys)
     {
+        IOverlay * ovl = overlays[key.key];
+
         QListWidgetItem * item = new QListWidgetItem(listOverlays);
-        item->setIcon((*overlay)->icon);
-        item->setText((*overlay)->getInfo());
-        item->setData(Qt::UserRole, overlay.key());
-        ++overlay;
+
+        item->setText(ovl->getInfo());
+        item->setToolTip(ovl->getComment());
+        item->setData(Qt::UserRole, ovl->getKey());
+
+        QPixmap icon(16, 32);
+        icon.fill(QColor(255,255,255,0));
+
+        QPainter p(&icon);
+
+        p.drawPixmap(0,0, ovl->getIcon());
+        if(ovl->visible())
+        {
+            p.drawPixmap(0,16, QPixmap(":/icons/iconOk16x16.png"));
+        }
+        else
+        {
+            p.drawPixmap(0,16, QPixmap(":/icons/iconClear16x16.png"));
+        }
+
+        item->setIcon(icon);
+
+
     }
 
     listOverlays->sortItems();
@@ -72,14 +97,9 @@ void COverlayToolWidget::slotDBChanged()
 
 void COverlayToolWidget::slotItemDoubleClicked(QListWidgetItem * item)
 {
-    QString key = item->data(Qt::UserRole).toString();
-    QMap<QString,IOverlay*>& overlays = COverlayDB::self().overlays;
-    if(!overlays.contains(key))
-    {
-        return;
-    }
-
-    overlays[key]->makeVisible();
+    QStringList keys;
+    keys << item->data(Qt::UserRole).toString();
+    COverlayDB::self().makeVisible(keys);
 }
 
 void COverlayToolWidget::slotItemClicked(QListWidgetItem * item)
@@ -115,10 +135,10 @@ void COverlayToolWidget::slotContextMenu(const QPoint& pos)
 
         QMenu contextMenu;
         COverlayDB::self().customMenu(item->data(Qt::UserRole).toString(), contextMenu);
-        //        if(contextMenu.isEmpty())
-        //        {
-        //            contextMenu.addAction(QPixmap(),tr("<---->"));
-        //        }
+        if(!contextMenu.isEmpty())
+        {
+            contextMenu.addSeparator();
+        }
         contextMenu.addAction(QPixmap(":/icons/iconZoomArea16x16.png"),tr("Zoom to fit"),this,SLOT(slotZoomToFit()));
         contextMenu.addAction(QPixmap(":/icons/iconClear16x16.png"),tr("Delete"),this,SLOT(slotDelete()),Qt::CTRL + Qt::Key_Delete);
 
@@ -129,29 +149,14 @@ void COverlayToolWidget::slotContextMenu(const QPoint& pos)
 
 void COverlayToolWidget::slotZoomToFit()
 {
-    QRectF r;
+    QStringList keys;
     QListWidgetItem * item;
     const QList<QListWidgetItem*>& items = listOverlays->selectedItems();
     foreach(item,items)
     {
-        IOverlay * ovl =  COverlayDB::self().getOverlayByKey(item->data(Qt::UserRole).toString());
-
-        if(r.isNull() && !ovl->getBoundingRectF().isNull())
-        {
-            r = ovl->getBoundingRectF();
-        }
-        else if(!ovl->getBoundingRectF().isNull())
-        {
-            r |= ovl->getBoundingRectF();
-        }
-
+        keys << item->data(Qt::UserRole).toString();
     }
-
-    if (!r.isNull ())
-    {
-        CMapDB::self().getMap().zoom(r.left() * DEG_TO_RAD, r.top() * DEG_TO_RAD, r.right() * DEG_TO_RAD, r.bottom() * DEG_TO_RAD);
-    }
-
+    COverlayDB::self().makeVisible(keys);
 }
 
 
