@@ -38,9 +38,14 @@ class COverlayToolWidget : public QWidget, private Ui::IOverlayToolWidget
     private slots:
         void slotDBChanged();
         void slotItemDoubleClicked(QListWidgetItem * item);
+        void slotItemClicked(QListWidgetItem * item);
+        void slotSelectionChanged();
         void slotContextMenu(const QPoint& pos);
         void slotDelete();
         void slotZoomToFit();
 
+    private:
+        bool originator;
+
 };
 #endif                           //COVERLAYTOOLWIDGET_H
