@@ -45,12 +45,13 @@ CPlot::CPlot(CPlotData::axis_type_e type, mode_e mode, QWidget * parent)
 , showScale(true)
 , thinLine(false)
 , cursorFocus(false)
+, needsRedraw(true)
+, mouseMoveMode(false)
+, checkClick(false)
 , posMouse(-1,-1)
+, selTrkPt(0)
 {
-    if(mode == eIcon)
-    {
-        setMouseTracking(true);
-    }
+    setMouseTracking(true);
     setSizePolicy(QSizePolicy::MinimumExpanding,QSizePolicy::MinimumExpanding);
 
     if(mode == eIcon)
@@ -85,6 +86,28 @@ double CPlot::getXValByPixel(int px)
     return m_pData->x().pt2val(px - left);
 }
 
+double CPlot::getYValByPixel(int px)
+{
+    if(m_pData->lines.isEmpty())
+    {
+        return 0;
+    }
+
+    double xx = getXValByPixel(px);
+
+    const QPolygonF& line = m_pData->lines[0].points;
+    foreach(const QPointF& pt, line)
+    {
+        if(xx <= pt.x())
+        {
+            return pt.y();
+        }
+
+    }
+
+    return 0;
+}
+
 
 void CPlot::setYLabel(const QString& str)
 {
@@ -129,6 +152,8 @@ void CPlot::newLine(const QPolygonF& line, const QPointF& focus, const QString&
     setSizes();
     m_pData->x().setScale( rectGraphArea.width() );
     m_pData->y().setScale( rectGraphArea.height() );
+
+    needsRedraw = true;
     update();
 
 }
@@ -152,6 +177,8 @@ void CPlot::addLine(const QPolygonF& line, const QString& label)
     setSizes();
     m_pData->x().setScale( rectGraphArea.width() );
     m_pData->y().setScale( rectGraphArea.height() );
+
+    needsRedraw = true;
     update();
 }
 
@@ -171,18 +198,20 @@ void CPlot::addTag(CPlotData::point_t& tag)
 void CPlot::paintEvent(QPaintEvent * )
 {
     QPainter p(this);
-    USE_ANTI_ALIASING(p, true);
     draw(p);
 }
 
 
-void CPlot::resizeEvent(QResizeEvent * )
+void CPlot::resizeEvent(QResizeEvent * e)
 {
     setSizes();
 
     initialYMin = m_pData->y().min();
     initialYMax = m_pData->y().max();
 
+    buffer = QImage(e->size(), QImage::Format_ARGB32);
+
+    needsRedraw = true;
     update();
 }
 
@@ -309,9 +338,96 @@ void CPlot::setSizeDrawArea()
     m_pData->y().setScale( rectGraphArea.height() );
 }
 
+void CPlot::draw(QPainter& p, const QSize& s)
+{
+    resize(s);
+    QResizeEvent e(s,s);
+    resizeEvent(&e);
+
+    draw(p);
+}
 
 void CPlot::draw(QPainter& p)
 {
+
+    if(needsRedraw)
+    {
+        draw();
+        needsRedraw = false;
+    }
+
+    p.drawImage(0,0,buffer);
+
+    int x = posMouse.x();
+    if(x != -1)
+    {
+        USE_ANTI_ALIASING(p, true);
+        p.setPen(QPen(Qt::red,2));
+        p.drawLine(x, rectGraphArea.top(), x, rectGraphArea.bottom());
+
+        CTrack * track = CTrackDB::self().highlightedTrack();
+        if(selTrkPt && track)
+        {
+            QString str = track->getTrkPtInfo(*selTrkPt);
+
+            double y = getYValByPixel(x);
+            y = m_pData->y().val2pt(y);
+            y = bottom - y;
+
+            p.setPen(CCanvas::penBorderBlue);
+            p.setBrush(CCanvas::brushBackWhite);
+            p.drawEllipse(QRect(x - 5,  y - 5, 11, 11));
+
+
+            if(!str.isEmpty())
+            {
+                QFont           f = CResources::self().getMapFont();
+                QFontMetrics    fm(f);
+                QRect           r1 = fm.boundingRect(QRect(0,0,300,0), Qt::AlignLeft|Qt::AlignTop|Qt::TextWordWrap, str);
+
+
+                if((r1.width() + 45 + x) > right)
+                {
+                    x = x - 45 - r1.width();
+                }
+                else
+                {
+                    x = x + 45;
+                }
+
+                if(r1.height() + y > bottom)
+                {
+                    y = y - r1.height();
+                }
+
+
+                r1.moveTopLeft(QPoint(x,y));
+
+                QRect r2 = r1;
+                r2.setWidth(r1.width() + 20);
+                r2.moveLeft(r1.left() - 10);
+                r2.setHeight(r1.height() + 20);
+                r2.moveTop(r1.top() - 10);
+
+
+                p.setPen(QPen(CCanvas::penBorderBlue));
+                p.setBrush(CCanvas::brushBackWhite);
+                PAINT_ROUNDED_RECT(p,r2);
+
+                p.setFont(CResources::self().getMapFont());
+                p.setPen(Qt::darkBlue);
+                p.drawText(r1, Qt::AlignLeft|Qt::AlignTop|Qt::TextWordWrap,str);
+            }
+        }
+    }
+}
+
+void CPlot::draw()
+{
+    buffer.fill(Qt::transparent);
+    QPainter p(&buffer);
+    USE_ANTI_ALIASING(p, true);
+
     if(mode == eNormal)
     {
         p.fillRect(rect(),Qt::white);
@@ -320,7 +436,7 @@ void CPlot::draw(QPainter& p)
     {
         QRect r = rect();
         r.adjust(2,2,-2,-2);
-        if(cursorFocus)
+        if(cursorFocus || posMouse.x() != -1)
         {
             p.setPen(CCanvas::penBorderBlue);
             p.setBrush(QColor(255,255,255,255));
@@ -362,18 +478,6 @@ void CPlot::draw(QPainter& p)
     drawTags(p);
 
     drawLegend(p);
-
-    if(mode == eIcon)
-    {
-        int x = posMouse.x();
-        if(x != -1)
-        {
-            p.setPen(QPen(Qt::red,2));
-            p.drawLine(x, rectGraphArea.top(), x, rectGraphArea.bottom());
-        }
-
-    }
-
 }
 
 
@@ -636,7 +740,7 @@ void CPlot::drawData(QPainter& p)
             if(ptx >= left && ptx <= right)
             {
                 background << QPointF(ptx,pty);
-                foreground << QPointF(ptx, pty);
+                foreground << QPointF(ptx,pty);
             }
             ++point;
         }
@@ -806,6 +910,7 @@ void CPlot::resetZoom()
     initialYMin = m_pData->y().min();
     initialYMax = m_pData->y().max();
 
+    needsRedraw = true;
     update();
 }
 
@@ -835,8 +940,6 @@ void CPlot::slotSave()
 
     QImage img(size(), QImage::Format_ARGB32);
     QPainter p;
-    USE_ANTI_ALIASING(p, true);
-
     p.begin(&img);
     p.fillRect(rect(), QBrush(Qt::white));
     draw(p);
@@ -857,6 +960,8 @@ void CPlot::zoom(CPlotAxis &axis, bool in, int curInt)
     setSizes();
     m_pData->x().setScale( rectGraphArea.width() );
     m_pData->y().setScale( rectGraphArea.height() );
+
+    needsRedraw = true;
     update();
 }
 
@@ -864,40 +969,33 @@ void CPlot::zoom(CPlotAxis &axis, bool in, int curInt)
 void CPlot::wheelEvent ( QWheelEvent * e )
 {
     bool in = CResources::self().flipMouseWheel() ? (e->delta() > 0) : (e->delta() < 0);
+
+    needsRedraw = true;
+
     if (hZoomAct->isChecked())
+    {
         zoom(m_pData->x(), in, e->pos().x() - left);
+    }
     if (vZoomAct->isChecked())
+    {
         zoom(m_pData->y(), in, - e->pos().y() + bottom);
+    }
 }
 
 
 void CPlot::mouseMoveEvent(QMouseEvent * e)
 {
-    if(mode == eIcon)
+    posMouse = QPoint(-1,-1);
+
+    if(checkClick)
     {
-        posMouse = QPoint(-1,-1);
-        CTrack * trk = CTrackDB::self().highlightedTrack();
-        if(trk == 0)
-        {
-            return;
-        }
-
-        QPoint pos = e->pos();
-        double dist = getXValByPixel(pos.x());
-
-        if(dist < 0 || dist > trk->getTotalDistance())
-        {
-            return;
-        }
-
-        posMouse = e->pos();
-
-        emit activePointSignal(dist);
-
-
+        checkClick      = false;
+        mouseMoveMode   = true;
     }
-    else{
-        checkClick = false;
+
+    if(mouseMoveMode)
+    {
+        needsRedraw = true;
 
         CPlotAxis &xaxis = m_pData->x();
         xaxis.move(startMovePos.x() - e->pos().x());
@@ -907,29 +1005,70 @@ void CPlot::mouseMoveEvent(QMouseEvent * e)
 
         startMovePos = e->pos();
     }
+    else
+    {
+        CTrack * trk = CTrackDB::self().highlightedTrack();
+        if(trk == 0)
+        {
+            return;
+        }
+
+        QPoint pos = e->pos();
+
+        double min,max;
+        if(m_pData->axisType == CPlotData::eLinear)
+        {
+            min = 0;
+            max = trk->getTotalDistance();
+        }
+        else
+        {
+            min = trk->getStartTimestamp().toTime_t();
+            max = trk->getEndTimestamp().toTime_t();
+        }
+
+        double x = getXValByPixel(pos.x());
+
+        if(x < min || x > max)
+        {
+            return;
+        }
+
+        posMouse = e->pos();
+
+        emit sigFocusPoint(x);
+    }
     update();
 }
 
 
 void CPlot::mouseReleaseEvent(QMouseEvent * e)
 {
+    needsRedraw = true;
+
     if(mode == eNormal)
     {
         if (e->button() == Qt::LeftButton)
         {
             QApplication::restoreOverrideCursor();
         }
-        if (checkClick && e->button() == Qt::LeftButton)
+        if (checkClick && e->button() == Qt::LeftButton && !mouseMoveMode)
         {
+            checkClick = false;
+
             QPoint pos = e->pos();
             double dist = getXValByPixel(pos.x());
-            emit activePointSignal(dist);
+            emit sigActivePoint(dist);
+
+            update();
         }
     }
     else
     {
         emit sigClicked();
     }
+
+    mouseMoveMode = false;
 }
 
 
@@ -950,14 +1089,17 @@ void CPlot::mousePressEvent(QMouseEvent * e)
 void CPlot::leaveEvent(QEvent * event)
 {
     cursorFocus = false;
-    posMouse = QPoint(-1, -1);
+    needsRedraw = true;
+    posMouse    = QPoint(-1, -1);
     QApplication::restoreOverrideCursor();
+
     update();
 }
 
 void CPlot::enterEvent(QEvent * event)
 {
     cursorFocus = true;
+    needsRedraw = true;
     QApplication::setOverrideCursor(Qt::PointingHandCursor);
     update();
 }
@@ -967,10 +1109,14 @@ void CPlot::slotTrkPt(CTrack::pt_t * pt)
     if(pt == 0)
     {
         posMouse = QPoint(-1,-1);
-        return;
     }
-    int x = m_pData->x().val2pt(pt->distance);
-    int y = m_pData->y().val2pt(pt->altitude);
-    posMouse = QPoint(x, y);
+    else
+    {
+        int x       = m_pData->x().val2pt(pt->distance);
+        int y       = m_pData->y().val2pt(pt->altitude);
+        posMouse    = QPoint(x + left, y);
+    }
+    needsRedraw = true;
     update();
 }
+
