@@ -28,6 +28,7 @@
 #include <QPixmap>
 
 class CRoute;
+class QDomDocument;
 
 class CRouteDB : public IDB
 {
@@ -41,7 +42,8 @@ class CRouteDB : public IDB
 
         void delRoute(const QString& key, bool silent);
 
-        CRoute * getRoute(const QString& key);
+        CRoute * getRouteByKey(const QString& key);
+
 
         void delRoutes(const QStringList& keys);
         /// load database data from gpx
@@ -50,7 +52,7 @@ class CRouteDB : public IDB
         void saveGPX(CGpx& gpx, const QStringList& keys);
 
         /// load database data from QLandkarte binary
-        void loadQLB(CQlb& qlb);
+        void loadQLB(CQlb& qlb, bool newKey);
         /// save database data to QLandkarte binary
         void saveQLB(CQlb& qlb);
 
@@ -69,13 +71,20 @@ class CRouteDB : public IDB
 
         QRectF getBoundingRectF(const QString key);
 
-        struct keys_t{QString key; QString name; QPixmap icon;};
+        struct keys_t{QString key; QString name; QPixmap icon; quint32 time;};
         /// get all keys in the database
         QList<keys_t> keys();
 
         static bool keyLessThanAlpha(keys_t&  s1, keys_t&  s2);
+        static bool keyLessThanTime(keys_t&  s1, keys_t&  s2);
 
+        void makeVisible(const QStringList& keys);
 
+        void loadSecondaryRoute(const QString& key, QDomDocument& xml);
+
+        void reset(const QString& key);
+
+        bool contains(const QString& key){return routes.contains(key);}
         signals:
         void sigHighlightRoute(CRoute * route);
 
@@ -83,6 +92,8 @@ class CRouteDB : public IDB
         friend class CMainWindow;
 
         CRouteDB(QTabWidget * tb, QObject * parent);
+        void drawArrows(const QPolygon& line, const QRect& viewport, QPainter& p);
+        void drawLine(const QPolygon& line, const QRect& extViewport, QPainter& p);
 
         quint32 cnt;
         static CRouteDB * m_self;
