@@ -19,17 +19,27 @@
 #ifndef CSEARCH_H
 #define CSEARCH_H
 
-#include <QObject>
+#include "IItem.h"
 
-class CSearch : public QObject
+class CSearch : public IItem
 {
     Q_OBJECT;
     public:
         CSearch(QObject * parent);
         virtual ~CSearch();
 
+        QString getInfo();
+
+        void setIcon(const QString& str){}
+
+
         qreal   lon;
         qreal   lat;
-        QString query;
+        QString street;
+        QString postalCode;
+        QString municipal;
+        QString country;
+        QString countryCode;
+
 };
 #endif                           //CSEARCH_H
