@@ -42,10 +42,16 @@ class CSearchDB : public IDB
 
         static CSearchDB& self(){return *m_self;}
 
+        enum hosts_t
+        {
+             eOpenRouteService
+            ,eGoogle
+        };
+
         void draw(QPainter& p, const QRect& rect, bool& needsRedraw);
 
         /// start a query with given string
-        void search(const QString& str);
+        void search(const QString& str, hosts_t host);
         /// get iterator access to track point list
         QMap<QString,CSearch*>::iterator begin(){return results.begin();}
         /// get iterator access to track point list
@@ -55,35 +61,51 @@ class CSearchDB : public IDB
 
         void delResults(const QStringList& keys);
 
-        void loadGPX(CGpx& gpx){};
-        void saveGPX(CGpx& gpx, const QStringList& ){};
+        void loadGPX(CGpx& gpx){}
+        void saveGPX(CGpx& gpx, const QStringList& ){}
 
-        void loadQLB(CQlb& qlb){};
-        void saveQLB(CQlb& qlb){};
+        void loadQLB(CQlb& qlb, bool newKey){}
+        void saveQLB(CQlb& qlb){}
 
-        void upload(const QStringList&){};
-        void download(){};
+        void upload(const QStringList&){}
+        void download(){}
 
         void clear();
 
         void add(const QString& label, double lon, double lat);
 
+        void selSearchByKey(const QString& key);
+
+        bool contains(const QString& key){return results.contains(key);}
+
         signals:
         void sigStatus(const QString& msg);
         void sigFinished();
 
     private slots:
         void slotSetupLink();
-        void slotRequestStarted(int );
-        void slotRequestFinished(int , bool error);
+        void slotRequestFinishedGoogle(int , bool error);
+        void slotRequestFinishedOpenRouteService(int , bool error);
 
     private:
         friend class CMainWindow;
 
+        void startGoogle(const QString& str);
+        void startOpenRouteService(const QString& str);
+
         CSearchDB(QTabWidget * tb, QObject * parent);
         static CSearchDB * m_self;
+        static const QString xls_ns;
+        static const QString sch_ns;
+        static const QString gml_ns;
+        static const QString xlink_ns;
+        static const QString xsi_ns;
+        static const QString schemaLocation;
+
+
 
         QHttp * google;
+        QHttp * ors;
         CSearch tmpResult;
         QMap<QString,CSearch*> results;
 };
