@@ -41,7 +41,7 @@ CSearchToolWidget::CSearchToolWidget(QTabWidget * parent)
 
     connect(listResults,SIGNAL(itemClicked(QListWidgetItem*)),this,SLOT(slotItemClicked(QListWidgetItem*)));
 
-    parent->insertTab(0,this,QIcon(":/icons/iconSearch16x16"),"");
+    parent->insertTab(0,this,QIcon(":/icons/iconSearch16x16.png"),"");
     parent->setTabToolTip(parent->indexOf(this), tr("Search"));
 
     contextMenu = new QMenu(this);
@@ -51,6 +51,20 @@ CSearchToolWidget::CSearchToolWidget(QTabWidget * parent)
 
     connect(listResults,SIGNAL(customContextMenuRequested(const QPoint&)),this,SLOT(slotContextMenu(const QPoint&)));
 
+    comboHost->addItem(tr("OpenRouteService"), CSearchDB::eOpenRouteService);
+    comboHost->addItem(tr("Google"), CSearchDB::eGoogle);
+
+    QSettings cfg;
+    cfg.beginGroup("search");
+    int idx = comboHost->findData(cfg.value("host", CSearchDB::eOpenRouteService));
+    if(idx != -1)
+    {
+        comboHost->setCurrentIndex(idx);
+    }
+
+    cfg.endGroup();
+
+    connect(comboHost, SIGNAL(currentIndexChanged(int)), this, SLOT(slotHostChanged(int)));
 }
 
 
@@ -59,14 +73,27 @@ CSearchToolWidget::~CSearchToolWidget()
 
 }
 
+void CSearchToolWidget::selSearchByKey(const QString& key)
+{
+    for(int i=0; i<listResults->count(); ++i)
+    {
+        QListWidgetItem * item = listResults->item(i);
+        if(item && item->data(Qt::UserRole) == key)
+        {
+            listResults->setCurrentItem(item);
+        }
+    }
+
+}
 
 void CSearchToolWidget::slotReturnPressed()
 {
     QString line = lineInput->text().trimmed();
     if(!line.isEmpty())
     {
-        CSearchDB::self().search(line);
         lineInput->setEnabled(false);
+        CSearchDB::self().search(line, (CSearchDB::hosts_t)comboHost->itemData(comboHost->currentIndex()).toInt());
+
     }
 }
 
@@ -86,8 +113,9 @@ void CSearchToolWidget::slotDBChanged()
     while(result != CSearchDB::self().end())
     {
         QListWidgetItem * item = new QListWidgetItem(listResults);
-        item->setText((*result)->query);
-
+        item->setText((*result)->getInfo());
+        item->setData(Qt::UserRole, (*result)->getKey());
+        item->setIcon((*result)->getIcon());
         ++result;
     }
 
@@ -108,7 +136,7 @@ void CSearchToolWidget::slotContextMenu(const QPoint& pos)
 
 void CSearchToolWidget::slotItemClicked(QListWidgetItem* item)
 {
-    CSearch * result = CSearchDB::self().getResultByKey(item->text());
+    CSearch * result = CSearchDB::self().getResultByKey(item->data(Qt::UserRole).toString());
     if(result)
     {
         theMainWindow->getCanvas()->move(result->lon, result->lat);
@@ -123,7 +151,7 @@ void CSearchToolWidget::slotDelete()
     const QList<QListWidgetItem*>& items = listResults->selectedItems();
     foreach(item,items)
     {
-        keys << item->text();
+        keys << item->data(Qt::UserRole).toString();
     }
     CSearchDB::self().delResults(keys);
 }
@@ -133,7 +161,7 @@ void CSearchToolWidget::slotCopyPosition()
 {
     QListWidgetItem * item = listResults->currentItem();
     if(item == 0) return;
-    CSearch * result = CSearchDB::self().getResultByKey(item->text());
+    CSearch * result = CSearchDB::self().getResultByKey(item->data(Qt::UserRole).toString());
     if(result == 0) return;
 
     QString position;
@@ -149,11 +177,11 @@ void CSearchToolWidget::slotAdd()
 {
     QListWidgetItem * item = listResults->currentItem();
     if(item == 0) return;
-    CSearch * result = CSearchDB::self().getResultByKey(item->text());
+    CSearch * result = CSearchDB::self().getResultByKey(item->data(Qt::UserRole).toString());
     if(result == 0) return;
 
     float ele = CMapDB::self().getDEM().getElevation(result->lon * DEG_TO_RAD, result->lat * DEG_TO_RAD);
-    CWptDB::self().newWpt(result->lon * DEG_TO_RAD, result->lat * DEG_TO_RAD, ele);
+    CWptDB::self().newWpt(result->lon * DEG_TO_RAD, result->lat * DEG_TO_RAD, ele, result->getName());
 }
 
 
@@ -173,3 +201,11 @@ void CSearchToolWidget::keyPressEvent(QKeyEvent * e)
         QWidget::keyPressEvent(e);
     }
 }
+
+void CSearchToolWidget::slotHostChanged(int idx)
+{
+    QSettings cfg;
+    cfg.beginGroup("search");
+    cfg.setValue("host", comboHost->itemData(idx).toInt());
+    cfg.endGroup();
+}
