@@ -116,6 +116,10 @@ QDataStream& operator >>(QDataStream& s, CTrack& track)
                     s1 >> trkpt.timestamp;
                     s1 >> trkpt.flags;
 
+                    trkpt._lon = trkpt.lon;
+                    trkpt._lat = trkpt.lat;
+                    trkpt._ele = trkpt.ele;
+
                     track << trkpt;
                 }
                 break;
@@ -161,31 +165,20 @@ QDataStream& operator >>(QDataStream& s, CTrack& track)
                 QList<CTrack::pt_t>::iterator pt1 = track.track.begin();
                 while (pt1 != track.track.end())
                 {
-                                 ///< [m]
-                    s1 >> pt1->altitude;
-                                 ///< [m]
-                    s1 >> pt1->height;
-                                 ///< [m/s]
-                    s1 >> pt1->velocity;
-                                 ///< []
-                    s1 >> pt1->heading;
-                                 ///< []
-                    s1 >> pt1->magnetic;
-                                 ///<
+                    s1 >> pt1->altitude;    ///< [m]
+                    s1 >> pt1->height;      ///< [m]
+                    s1 >> pt1->velocity;    ///< [m/s]
+                    s1 >> pt1->heading;     ///< [deg]
+                    s1 >> pt1->magnetic;    ///< [deg]
                     s1 >> pt1->vdop;
-                                 ///<
                     s1 >> pt1->hdop;
-                                 ///<
                     s1 >> pt1->pdop;
-                    s1 >> pt1->x;///< [m] cartesian gps coordinate
-                    s1 >> pt1->y;///< [m] cartesian gps coordinate
-                    s1 >> pt1->z;///< [m] cartesian gps coordinate
-                                 ///< [m/s] velocity
-                    s1 >> pt1->vx;
-                                 ///< [m/s] velocity
-                    s1 >> pt1->vy;
-                                 ///< [m/s] velocity
-                    s1 >> pt1->vz;
+                    s1 >> pt1->x;           ///< [m] cartesian gps coordinate
+                    s1 >> pt1->y;           ///< [m] cartesian gps coordinate
+                    s1 >> pt1->z;           ///< [m] cartesian gps coordinate
+                    s1 >> pt1->vx;          ///< [m/s] velocity
+                    s1 >> pt1->vy;          ///< [m/s] velocity
+                    s1 >> pt1->vz;          ///< [m/s] velocity
                     pt1++;
                 }
 
@@ -219,6 +212,31 @@ QDataStream& operator >>(QDataStream& s, CTrack& track)
                 break;
             }
 #endif
+            case CTrack::eTrkShdw:
+            {
+                QDataStream s1(&entry->data, QIODevice::ReadOnly);
+                s1.setVersion(QDataStream::Qt_4_5);
+                quint32 n;
+
+                quint32 nTrkPts1 = 0;
+
+                s1 >> nTrkPts1;
+                if(nTrkPts1 != nTrkPts)
+                {
+                    QMessageBox::warning(0, QObject::tr("Corrupt track ..."), QObject::tr("Number of trackpoints is not equal the number of shadow data trackpoints."), QMessageBox::Ignore,QMessageBox::Ignore);
+                    break;
+                }
+
+                for(n = 0; n < nTrkPts; ++n)
+                {
+                    CTrack::pt_t& trkpt = track.track[n];
+                    s1 >> trkpt._lon;
+                    s1 >> trkpt._lat;
+                    s1 >> trkpt._ele;
+                }
+                break;
+            }
+
             default:;
         }
 
@@ -311,25 +329,20 @@ QDataStream& operator <<(QDataStream& s, CTrack& track)
         s4 << (quint32)trkpts.size();
         while(trkpt != trkpts.end())
         {
-                                 ///< [m]
-            s4 << trkpt->altitude;
-            s4 << trkpt->height; ///< [m]
-
-                                 ///< [m/s]
-            s4 << trkpt->velocity;
-            s4 << trkpt->heading;///< [deg]
-
-                                 ///< [deg]
-            s4 << trkpt->magnetic;
-            s4 << trkpt->vdop;   ///<
-            s4 << trkpt->hdop;   ///<
-            s4 << trkpt->pdop;   ///<
-            s4 << trkpt->x;      ///< [m] cartesian gps coordinate
-            s4 << trkpt->y;      ///< [m] cartesian gps coordinate
-            s4 << trkpt->z;      ///< [m] cartesian gps coordinate
-            s4 << trkpt->vx;     ///< [m/s] velocity
-            s4 << trkpt->vy;     ///< [m/s] velocity
-            s4 << trkpt->vz;     ///< [m/s] velocity
+            s4 << trkpt->altitude;  ///< [m]
+            s4 << trkpt->height;    ///< [m]
+            s4 << trkpt->velocity;  ///< [m/s]
+            s4 << trkpt->heading;   ///< [deg]
+            s4 << trkpt->magnetic;  ///< [deg]
+            s4 << trkpt->vdop;      ///<
+            s4 << trkpt->hdop;      ///<
+            s4 << trkpt->pdop;      ///<
+            s4 << trkpt->x;         ///< [m] cartesian gps coordinate
+            s4 << trkpt->y;         ///< [m] cartesian gps coordinate
+            s4 << trkpt->z;         ///< [m] cartesian gps coordinate
+            s4 << trkpt->vx;        ///< [m/s] velocity
+            s4 << trkpt->vy;        ///< [m/s] velocity
+            s4 << trkpt->vz;        ///< [m/s] velocity
             ++trkpt;
         }
 
@@ -361,6 +374,28 @@ QDataStream& operator <<(QDataStream& s, CTrack& track)
         entries << entryTrkGpxExt;
     }
 #endif
+
+    //---------------------------------------
+    // prepare track shadow data
+    //---------------------------------------
+    trk_head_entry_t entryShdwPts;
+    entryShdwPts.type = CTrack::eTrkShdw;
+    QDataStream s6(&entryShdwPts.data, QIODevice::WriteOnly);
+    s6.setVersion(QDataStream::Qt_4_5);
+
+    trkpt = trkpts.begin();
+
+    s6 << (quint32)trkpts.size();
+    while(trkpt != trkpts.end())
+    {
+        s6 << trkpt->_lon;
+        s6 << trkpt->_lat;
+        s6 << trkpt->_ele;
+        ++trkpt;
+    }
+
+    entries << entryShdwPts;
+
     //---------------------------------------
     // prepare terminator
     //---------------------------------------
@@ -545,7 +580,8 @@ void CTrack::replaceElevationByLocal()
     const int size = track.size();
     for(int i = 0; i<size; i++)
     {
-        track[i].ele = map.getElevation(track[i].lon * DEG_TO_RAD, track[i].lat * DEG_TO_RAD);
+        track[i].ele    = map.getElevation(track[i].lon * DEG_TO_RAD, track[i].lat * DEG_TO_RAD);
+        track[i]._ele   = track[i].ele;
     }
     rebuild(false);
     emit sigChanged();
@@ -615,7 +651,8 @@ void CTrack::slotRequestFinished(int id, bool error)
         {
             if(idx < track.size())
             {
-                track[idx++].ele = val.toDouble();
+                track[idx++].ele    = val.toDouble();
+                track[idx++]._ele   = val.toDouble();
             }
         }
 
@@ -704,6 +741,7 @@ void CTrack::hide(bool ok)
 
 #define A 0.22140
 
+
 void CTrack::rebuild(bool reindex)
 {
 
@@ -715,6 +753,7 @@ void CTrack::rebuild(bool reindex)
 
     visiblePointCount = 0;
     totalTime       = 0;
+    totalTimeMoving = 0;
     totalDistance   = 0;
     totalAscend     = 0;
     totalDescend    = 0;
@@ -725,6 +764,7 @@ void CTrack::rebuild(bool reindex)
     float maxSpeed  = -WPT_NOFLOAT;
     float minSpeed  =  WPT_NOFLOAT;
 
+
     // reindex track if desired
     if(reindex)
     {
@@ -738,11 +778,6 @@ void CTrack::rebuild(bool reindex)
         pt1 = track.begin();
     }
 
-//    if(!track.isEmpty() && (track.first().timestamp != 0))
-//    {
-//        timestamp = track.first().timestamp;
-//    }
-
     // skip leading deleted points
     while((pt1 != track.end()) && (pt1->flags & pt_t::eDeleted))
     {
@@ -855,6 +890,7 @@ void CTrack::rebuild(bool reindex)
         avgspeed1       = avgspeed0;
         pt2->avgspeed   = avgspeed0;
 
+
         if(pt2->ele   > maxEle)   {maxEle   = pt2->ele;   ptMaxEle   = *pt2;}
         if(pt2->ele   < minEle)   {minEle   = pt2->ele;   ptMinEle   = *pt2;}
         if(pt2->speed > maxSpeed) {maxSpeed = pt2->speed; ptMaxSpeed = *pt2;}
@@ -862,13 +898,17 @@ void CTrack::rebuild(bool reindex)
 
         pt2->timeSinceStart = t2 - t1;
 
+        if(dt > 0 && (pt2->delta/dt > 0.2))
+        {
+            totalTimeMoving += dt;
+
+        }
+
         pt1 = pt2;
     }
 
     totalTime = t2 - t1;
-
     emit sigChanged();
-
 }
 
 
@@ -963,10 +1003,12 @@ QString CTrack::getInfo()
     QString str     = getName();
     double distance = getTotalDistance();
 
+    // ---------------------------
     IUnit::self().meter2distance(getTotalDistance(), val1, unit1);
     str += tr("\nlength: %1 %2").arg(val1).arg(unit1);
     str += tr(", points: %1 (%2)").arg(visiblePointCount).arg(getTrackPoints().count());
 
+    // ---------------------------
     quint32 ttime = getTotalTime();
     quint32 days  = ttime / 86400;
 
@@ -984,6 +1026,25 @@ QString CTrack::getInfo()
     IUnit::self().meter2speed(distance / ttime, val1, unit1);
     str += tr(", speed: %1 %2").arg(val1).arg(unit1);
 
+    // ---------------------------
+    ttime = getTotalTimeMoving();
+    days  = ttime / 86400;
+
+    time = QTime();
+    time = time.addSecs(ttime);
+    if(days)
+    {
+        str += tr("\nmoving: %1:").arg(days) + time.toString("HH:mm:ss");
+    }
+    else
+    {
+        str += tr("\nmoving: ") + time.toString("HH:mm:ss");
+    }
+
+    IUnit::self().meter2speed(distance / ttime, val1, unit1);
+    str += tr(", speed: %1 %2").arg(val1).arg(unit1);
+
+    // ---------------------------
     str += tr("\nstart: %1").arg(getStartTimestamp().isNull() ? tr("-") : getStartTimestamp().toString());
     str += tr("\nend: %1").arg(getEndTimestamp().isNull() ? tr("-") : getEndTimestamp().toString());
 
@@ -1005,6 +1066,77 @@ void CTrack::setIcon(const QString& str)
 }
 
 
+QString CTrack::getTrkPtInfo(pt_t& trkpt)
+{
+    QString str, val, unit;
+
+    if(trkpt.timestamp != 0x00000000 && trkpt.timestamp != 0xFFFFFFFF)
+    {
+        QDateTime time = QDateTime::fromTime_t(trkpt.timestamp);
+        time.setTimeSpec(Qt::LocalTime);
+        str = time.toString();
+
+        quint32 total = getTotalTime();
+        if(total)
+        {
+            quint32 t1s = trkpt.timeSinceStart;
+            quint32 t2s = total - trkpt.timeSinceStart;
+
+            quint32 t1h = qreal(t1s)/3600;
+            quint32 t2h = qreal(t2s)/3600;
+
+            quint32 t1m = quint32(qreal(t1s - t1h * 3600)/60  + 0.5);
+            quint32 t2m = quint32(qreal(t2s - t2h * 3600)/60  + 0.5);
+
+            quint32 t1p = quint32(qreal(100 * t1s) / total + 0.5);
+            quint32 t2p = 100 - t1p;
+
+
+            str += "\n";
+            str += tr("%4 %3 %1:%2h (%5%)").arg(t1h).arg(t1m, 2, 10, QChar('0')).arg(QChar(0x21A4)).arg(QChar(0x2690)).arg(t1p);
+            str += tr(" | (%5%) %1:%2h %3 %4").arg(t2h).arg(t2m, 2, 10, QChar('0')).arg(QChar(0x21A6)).arg(QChar(0x2691)).arg(t2p);
+        }
+
+    }
+
+    if(str.count()) str += "\n";
+    IUnit::self().meter2distance(trkpt.distance, val, unit);
+    str += tr("%5 %4 %1%2 (%3%)").arg(val).arg(unit).arg(trkpt.distance * 100.0 / getTotalDistance(),0,'f',0).arg(QChar(0x21A4)).arg(QChar(0x2690));
+    IUnit::self().meter2distance(getTotalDistance() - trkpt.distance, val, unit);
+    str += tr(" | (%3%) %1%2 %4 %5").arg(val).arg(unit).arg((getTotalDistance() - trkpt.distance) * 100.0 / getTotalDistance(),0,'f',0).arg(QChar(0x21A6)).arg(QChar(0x2691));
+
+    if(trkpt.ele != WPT_NOFLOAT)
+    {
+        if(str.count()) str += "\n";
+        IUnit::self().meter2elevation(trkpt.ele, val, unit);
+        str += tr("elevation: %1 %2").arg(val).arg(unit);
+    }
+
+
+
+    //-----------------------------------------------------------------------------------------------------------
+    //TODO: HOVERTEXT FOR EXTENSIONS
+#ifdef GPX_EXTENSIONS
+    if (!trkpt.gpx_exts.values.empty())
+    {
+        QList<QString> ext_list = trkpt.gpx_exts.values.keys();
+        QString ex_name, ex_val;
+
+        for(int i=0; i < trkpt.gpx_exts.values.size(); ++i)
+        {
+            ex_name = ext_list.value(i);
+            ex_val = trkpt.gpx_exts.getValue(ex_name);
+
+            if (ex_val != "") {str += tr("\n %1: %2 ").arg(ex_name).arg(ex_val);}
+
+        }
+
+    }
+#endif
+
+
+    return str;
+}
 
 QDataStream& operator >>(QDataStream& s, CFlags& flag)
 {
@@ -1022,3 +1154,4 @@ QDataStream& operator <<(QDataStream& s, CFlags& flag)
     return s;
 }
 
+
