@@ -68,7 +68,7 @@ class CTrack : public IItem
 
         virtual ~CTrack();
         int ref;
-        enum type_e {eEnd,eBase,eTrkPts,eTrain,eTrkExt1,eTrkGpxExt};
+        enum type_e {eEnd,eBase,eTrkPts,eTrain,eTrkExt1,eTrkGpxExt,eTrkShdw};
 
 #ifdef GPX_EXTENSIONS
         CGpxExtTr tr_ext;        //TODO: CGpxExtPt -> tr_ext
@@ -89,6 +89,7 @@ class CTrack : public IItem
                 ascend(0), descend(0), heartReateBpm(-1), cadenceRpm(-1), slope(0), timeSinceStart(0),
                 fix(""), sat(0), velocity(WPT_NOFLOAT), heading(WPT_NOFLOAT),
                 vdop(WPT_NOFLOAT), hdop(WPT_NOFLOAT), pdop(WPT_NOFLOAT),
+                _lon(WPT_NOFLOAT),_lat(WPT_NOFLOAT),_ele(WPT_NOFLOAT),
                 flags(0), px_valid(FALSE), dem(WPT_NOFLOAT), editItem(NULL){}
 
             bool operator==(const pt_t& pt){return pt.idx == idx;}
@@ -150,6 +151,15 @@ class CTrack : public IItem
             CGpxExtPt gpx_exts;  //TODO: CGpxExtPt -> gpx_exts
 #endif
 
+            // track shadow data (copy of original data)
+            /// longitude [deg]
+            float   _lon;
+            /// latitude [deg]
+            float   _lat;
+            /// elevation [m]
+            float   _ele;
+
+
             /// display flags
             CFlags flags;
             /// the current location in pixel
@@ -186,18 +196,23 @@ class CTrack : public IItem
         double getTotalDistance(){return totalDistance;}
         /// get the total time covered by the track in seconds
         quint32 getTotalTime(){return totalTime;}
+        /// get the total time while moving around
+        quint32 getTotalTimeMoving(){return totalTimeMoving;}
         /// select tarckpoint by index
         void setPointOfFocus(int idx, bool eraseSelection, bool moveMap);
         /// set point of focus to a point with a given distance from start
         pt_t * getPointOfFocus(double dist);
         ///
         QDateTime getStartTimestamp();
+        ///
         QDateTime getEndTimestamp();
         /// get the ascend in [m]
         double getAscend(){return totalAscend;}
         /// get the descend in [m]
         double getDescend(){return totalDescend;}
 
+        QString getTrkPtInfo(pt_t& trkpt);
+
         QRectF getBoundingRectF();
         void sortByTimestamp();
         CTrack& operator+=(const CTrack& trk);
@@ -238,6 +253,8 @@ class CTrack : public IItem
         friend QDataStream& operator >>(QDataStream& s, CTrack& track);
         friend QDataStream& operator <<(QDataStream& s, CTrack& track);
 
+        void medianFilter();
+
         static QDir path;
 
         /// a track URL
@@ -256,6 +273,8 @@ class CTrack : public IItem
 
         /// total time covered by all track points
         quint32 totalTime;
+        /// total time moving
+        quint32 totalTimeMoving;
         /// total distance of track [m]
         double  totalDistance;
 
