@@ -63,11 +63,13 @@ CTrackDB::CTrackDB(QTabWidget * tb, QObject * parent)
 : IDB(tb,parent)
 , cnt(0)
 , showBullets(true)
+, showMinMax(true)
 {
     m_self      = this;
 
     QSettings cfg;
     showBullets = cfg.value("track/showBullets", showBullets).toBool();
+    showMinMax = cfg.value("track/showMinMax", showMinMax).toBool();
     toolview    = new CTrackToolWidget(tb);
     undoStack   = CUndoStackModel::getInstance();
 
@@ -78,6 +80,7 @@ CTrackDB::~CTrackDB()
 {
     QSettings cfg;
     cfg.setValue("track/showBullets", showBullets);
+    cfg.setValue("track/showMinMax", showMinMax);
 }
 
 
@@ -259,9 +262,12 @@ void CTrackDB::loadGPX(CGpx& gpx)
 
                 pt.lon = trkpt.attribute("lon").toDouble();
                 pt.lat = trkpt.attribute("lat").toDouble();
+                pt._lon = pt.lon;
+                pt._lat = pt.lat;
 
                 tmpelem = trkptmap.value("ele");
                 if(!tmpelem.isNull()) pt.ele = tmpelem.text().toDouble();
+                pt._ele = pt.ele;
 
                 tmpelem = trkptmap.value("time");
                 if(!tmpelem.isNull())
@@ -775,6 +781,7 @@ void CTrackDB::splitTrack(int idx)
 
     CTrack * track1 = new CTrack(this);
     track1->setName(theTrack->getName() + "_1");
+    track1->setColor(theTrack->getColorIdx());
     for(i = 0; (i <= idx) && (trkpt != track.end()); ++i)
     {
         *track1 << *trkpt++;
@@ -782,6 +789,7 @@ void CTrackDB::splitTrack(int idx)
 
     CTrack * track2 = new CTrack(this);
     track2->setName(theTrack->getName() + "_2");
+    track2->setColor(theTrack->getColorIdx());
     for( ;(trkpt != track.end()); ++i)
     {
         *track2 << *trkpt++;
@@ -1105,7 +1113,7 @@ void CTrackDB::draw(QPainter& p, const QRect& rect, bool& needsRedraw)
 
         QString val, unit;
 
-        if(CResources::self().showTrackMax())
+        if(showMinMax)
         {
             if((*track)->ptMaxEle.ele != WPT_NOFLOAT)
             {
@@ -1252,6 +1260,7 @@ void CTrackDB::revertTrack(const QString& key)
     CTrack *tnew = new CTrack(this);
 
     tnew->name = torg->name + tr("_rev");
+    tnew->setColor(torg->getColorIdx());
 
     QList<CTrack::pt_t> track = torg->track;
     while(track.size())
