@@ -145,7 +145,8 @@ CTrackEditWidget::CTrackEditWidget(QWidget * parent)
     connect(treePoints,SIGNAL(customContextMenuRequested(const QPoint&)),this,SLOT(slotContextMenu(const QPoint&)));
 
     connect(comboColor, SIGNAL(currentIndexChanged(int)), this, SLOT(slotColorChanged(int)));
-    connect(lineName, SIGNAL(textChanged(const QString&)), this, SLOT(slotNameChanged(const QString&)));
+    connect(lineName, SIGNAL(returnPressed()), this, SLOT(slotNameChanged()));
+    connect(lineName, SIGNAL(textChanged(QString)), this, SLOT(slotNameChanged(QString)));
 }
 
 
@@ -694,8 +695,13 @@ void CTrackEditWidget::slotApply()
         while(trkpt != trkpts.end())
         {
             trkpt->flags &= ~CTrack::pt_t::eDeleted;
+            trkpt->lon = trkpt->_lon;
+            trkpt->lat = trkpt->_lat;
+            trkpt->ele = trkpt->_ele;
+
             ++trkpt;
         }
+
         checkResetDelTrkPt->setChecked(false);
         originator = false;
     }
@@ -844,7 +850,7 @@ void CTrackEditWidget::slotToggleStatDistance()
     {
         trackStatSpeedDist = new CTrackStatSpeedWidget(ITrackStat::eOverDistance, this);
         theMainWindow->getCanvasTab()->setTabPosition(QTabWidget::South);
-        theMainWindow->getCanvasTab()->addTab(trackStatSpeedDist, tr("Speed/Dist."));
+        theMainWindow->getCanvasTab()->addTab(trackStatSpeedDist, tr("Speed/Dist."));        
     }
     else
     {
@@ -1154,8 +1160,27 @@ void CTrackEditWidget::slotColorChanged(int idx)
 void CTrackEditWidget::slotNameChanged(const QString& name)
 {
     if(track.isNull()) return;
-
     QString _name_ = track->getName();
+    QPalette palette = lineName->palette();
+    if(_name_ != name)
+    {
+        palette.setColor(QPalette::Base, QColor(255, 128, 128));
+    }
+    else
+    {
+        palette.setColor(QPalette::Base, QColor(255, 255, 255));
+    }
+    lineName->setPalette(palette);
+}
+
+void CTrackEditWidget::slotNameChanged()
+{
+    if(track.isNull()) return;
+
+    QString  name  = lineName->text();
+    QString _name_ = track->getName();
+
+    QPalette palette = lineName->palette();
 
     if(_name_ != name)
     {
@@ -1164,6 +1189,11 @@ void CTrackEditWidget::slotNameChanged(const QString& name)
         emit CTrackDB::self().sigModified();
         emit CTrackDB::self().sigModified(track->getKey());
         qDebug() << "void CTrackEditWidget::slotNameChanged(const QString& name)";
+
+        palette.setColor(QPalette::Base, QColor(128, 255, 128));
     }
+
+
+    lineName->setPalette(palette);
 }
 
