@@ -19,16 +19,24 @@
 #ifndef CWPT_H
 #define CWPT_H
 
+
+#include "IItem.h"
+
 #include <QObject>
 #include <QPixmap>
 #include <QString>
 #include <QList>
 #include <QFile>
 #include <QDir>
+#include <QList>
+#include <QSet>
 
 #define WPT_NOFLOAT 1e25f
 
-class CWptDB;
+class IDB;
+class QDomNode;
+class QDomDocument;
+class QDomElement;
 
 /// waypoint data object
 /**
@@ -74,20 +82,76 @@ class CWptDB;
 
 </pre>
 */
-class CWpt : public QObject
+class CWpt : public IItem
 {
     Q_OBJECT;
     public:
-        CWpt(CWptDB * parent);
+        CWpt(QObject * parent);
         virtual ~CWpt();
 
-        const QString& key();
+        enum geocacheservice_e {eGC, eOC, eTC};
+
+        struct geocachelog_t
+        {
+            geocachelog_t() : id(0){}
+            quint32 id;
+            QString date;
+            QString type;
+            QString finderId;
+            QString finder;
+            QString text;
+        };
+
+        struct geocache_t
+        {
+            geocache_t() : service(eOC), hasData(false), id(0), available(true), archived(false), difficulty(0), terrain(0), exportBuddies(false){}
+            geocacheservice_e service;
+            bool hasData;
+            quint32 id;
+            bool available;
+            bool archived;
+            float difficulty;
+            float terrain;
+            QString status;
+            QString name;
+            QString owner;
+            QString ownerId;
+            QString type;
+            QString container;
+            QString shortDesc;
+            QString longDesc;
+            QString hint;
+            QString country;
+            QString state;
+            QString locale;
+            QList<geocachelog_t> logs;
+            bool exportBuddies;
+
+        };
+
         const QString filename(const QDir& dir = CWpt::path);
-        enum type_e {eEnd,eBase,eImage};
+        enum type_e {eEnd,eBase,eImage,eGeoCache};
         static QDir& getWptPath(){return path;}
 
-    private:
-        void genKey();
+        void setIcon(const QString& str);
+        QString getInfo();
+
+        QString getExtInfo(bool showHidden);
+
+        QPixmap getIcon();
+
+        const geocache_t& getGeocacheData(){return geocache;}
+
+        void loadGpxExt(const QDomNode& wpt);
+        void saveGpxExt(QDomNode& wpt, bool isExport);
+
+        bool isGeoCache(){return geocache.hasData;}
+        bool isMovable(){return !(geocache.hasData||(bool)sticky);}
+        bool isDeletable(){return !(sticky);}
+        bool hasHiddenInformation();
+
+        void showBuddies(bool show);
+        bool hasBuddies();
 
         // eBase: base information
     private:
@@ -95,21 +159,36 @@ class CWpt : public QObject
         friend QDataStream& operator <<(QDataStream& s, CWpt& wpt);
         friend class CDlgEditWpt;
         friend class CDlgWptEdit;
+        friend class CWptDB;
         static QDir path;
-        static quint32 keycnt;
-        QString _key_;
+
+        void loadGcExt(const QDomNode& gpxCache);
+        void loadOcExt(const QDomNode& gpxCache);
+        void saveGcExt(QDomElement& gpxCache, bool isExport);
+        void saveOcExt(QDomElement& gpxCache, bool isExport);
+
+        void setEntry(const QString& tag, const QString& val, QDomDocument& gpx, QDomElement& parent);
+        void setEntryHtml(const QString& tag, const QString& val, QDomDocument& gpx, QDomElement& parent);
+        QString getEntry(const QString& tag, const QDomNode& parent);
+        QString getEntryHtml(const QString& tag, const QDomNode& parent);
+        QString htmlScale(float val);
+        QString insertBuddies(const QString& html);        
+
+        geocache_t geocache;
+
+        static const QString html;
+        static const QString htmlFrame;
 
     public:
+        quint32 selected;
         quint32 sticky;
-        quint32 timestamp;
-        QString icon;
-        QString name;
-        QString comment;
         float   lat;             ///< [deg]
         float   lon;             ///< [deg]
         float   ele;             ///< [m]
         float   prx;             ///< [m]
         QString link;
+        QString urlname;
+        QString type;
 
         struct image_t
         {
@@ -120,6 +199,16 @@ class CWpt : public QObject
         };
         QList<image_t> images;
 
+        struct buddy_t
+        {
+            QString name;
+            QSet<QString> pos;
+            float lon;
+            float lat;
+        };
+
+        QList<buddy_t> buddies;
+
 };
 
 QDataStream& operator >>(QDataStream& s, CWpt& wpt);
