@@ -56,13 +56,17 @@ static exif_content_get_ifd_t f_exif_content_get_ifd;
 
 CWptDB::CWptDB(QTabWidget * tb, QObject * parent)
 : IDB(tb,parent)
+, showNames(true)
 {
+    QSettings cfg;
+    showNames = cfg.value("waypoint/showNames", showNames).toBool();
+
     m_self      = this;
     toolview    = new CWptToolWidget(tb);
 
     CQlb qlb(this);
     qlb.load(QDir::home().filePath(CONFIGDIR "sticky.qlb"));
-    loadQLB(qlb);
+    loadQLB(qlb, false);
 
 #ifdef HAS_EXIF
 #ifdef WIN32
@@ -80,11 +84,15 @@ CWptDB::CWptDB(QTabWidget * tb, QObject * parent)
 #endif
 #endif
 
+    connect(toolview, SIGNAL(sigChanged()), SIGNAL(sigChanged()));
 }
 
 
 CWptDB::~CWptDB()
 {
+    QSettings cfg;
+    cfg.setValue("waypoint/showNames", showNames);
+
     CQlb qlb(this);
 
     QMap<QString, CWpt*>::const_iterator wpt = wpts.begin();
@@ -113,6 +121,10 @@ bool CWptDB::keyLessThanComment(CWptDB::keys_t&  s1, CWptDB::keys_t&  s2)
 
 bool CWptDB::keyLessThanIcon(CWptDB::keys_t&  s1, CWptDB::keys_t&  s2)
 {
+    if(s1.icon.toLower() == s2.icon.toLower())
+    {
+        return keyLessThanAlpha(s1,s2);
+    }
     return s1.icon.toLower() < s2.icon.toLower();
 }
 
@@ -121,10 +133,16 @@ bool CWptDB::keyLessThanDistance(CWptDB::keys_t&  s1, CWptDB::keys_t&  s2)
     return s1.d < s2.d;
 }
 
+bool CWptDB::keyLessThanTime(CWptDB::keys_t&  s1, CWptDB::keys_t&  s2)
+{
+    return s1.time < s2.time;
+}
+
 
 void CWptDB::clear()
 {
     delWpt(wpts.keys());
+    CWpt::resetKeyCnt();
     emit sigChanged();
 }
 
@@ -142,11 +160,40 @@ QList<CWptDB::keys_t> CWptDB::keys()
 
         k2.key      = k1;
         k2.name     = wpts[k1]->name;
-        k2.comment  = wpts[k1]->comment.left(32);
-        k2.icon     = wpts[k1]->icon;
+        k2.time     = wpts[k1]->timestamp;
+
+        // pick comment/descripton, what ever fits
+        if(wpts[k1]->comment.isEmpty())
+        {
+            k2.comment  = wpts[k1]->description;
+        }
+        else
+        {
+            k2.comment  = wpts[k1]->comment;
+        }
+
+        k2.comment.remove(QRegExp("<head.*[^>]*><\\/head>"));
+        k2.comment.remove(QRegExp("<[^>]*>"));
+        k2.comment = k2.comment.simplified();
+
+        // truncate comment if necessary
+        if(k2.comment.size() > 33)
+        {
+            k2.comment = k2.comment.left(30) + "...";
+        }
+
+        if(wpts[k1]->geocache.hasData)
+        {
+            k2.icon     = wpts[k1]->geocache.type;
+        }
+        else
+        {
+            k2.icon     = wpts[k1]->iconString;
+        }
         k2.lon      = wpts[k1]->lon;
         k2.lat      = wpts[k1]->lat;
         k2.d        = 0;
+        k2.isCache  = wpts[k1]->geocache.hasData;
 
         k << k2;
     }
@@ -159,6 +206,9 @@ QList<CWptDB::keys_t> CWptDB::keys()
         case CWptToolWidget::eSortByName:
             qSort(k.begin(), k.end(), CWptDB::keyLessThanAlpha);
             break;
+        case CWptToolWidget::eSortByTime:
+            qSort(k.begin(), k.end(), CWptDB::keyLessThanTime);
+            break;
         case CWptToolWidget::eSortByComment:
             qSort(k.begin(), k.end(), CWptDB::keyLessThanComment);
             break;
@@ -193,15 +243,16 @@ QList<CWptDB::keys_t> CWptDB::keys()
 }
 
 
-CWpt * CWptDB::newWpt(float lon, float lat, float ele)
+CWpt * CWptDB::newWpt(float lon, float lat, float ele, const QString& name)
 {
-    CWpt * wpt = new CWpt(this);
-    wpt->lon = lon * RAD_TO_DEG;
-    wpt->lat = lat * RAD_TO_DEG;
-    wpt->ele = ele;
+    CWpt * wpt  = new CWpt(this);
+    wpt->lon    = lon * RAD_TO_DEG;
+    wpt->lat    = lat * RAD_TO_DEG;
+    wpt->ele    = ele;
+    wpt->name   = name;
 
     QSettings cfg;
-    wpt->icon = cfg.value("waypoint/lastSymbol","").toString();
+    wpt->setIcon(cfg.value("waypoint/lastSymbol","").toString());
 
     CDlgEditWpt dlg(*wpt,theMainWindow->getCanvas());
     if(dlg.exec() == QDialog::Rejected)
@@ -209,9 +260,9 @@ CWpt * CWptDB::newWpt(float lon, float lat, float ele)
         delete wpt;
         return 0;
     }
-    wpts[wpt->key()] = wpt;
+    wpts[wpt->getKey()] = wpt;
 
-    cfg.setValue("waypoint/lastSymbol",wpt->icon);
+    cfg.setValue("waypoint/lastSymbol",wpt->iconString);
 
     emit sigChanged();
     emit sigModified();
@@ -244,9 +295,13 @@ void CWptDB::delWpt(const QString& key, bool silent, bool saveSticky)
             return;
         }
     }
-    delete wpts.take(key);
-    if(!silent) emit sigChanged();
-    emit sigModified();
+    CWpt * wpt =  wpts.take(key);
+    wpt->deleteLater();
+    if(!silent)
+    {
+        emit sigChanged();
+        emit sigModified();
+    }
 }
 
 
@@ -258,26 +313,29 @@ void CWptDB::delWpt(const QStringList& keys, bool saveSticky)
         delWpt(key,true, saveSticky);
     }
 
-    emit sigChanged();
-    emit sigModified();
+    if(!keys.isEmpty())
+    {
+        emit sigChanged();
+        emit sigModified();
+    }
 }
 
 
 void CWptDB::addWpt(CWpt * wpt, bool silent)
 {
-    if(wpts.contains(wpt->key()))
+    if(wpts.contains(wpt->getKey()))
     {
-        if(wpts[wpt->key()]->sticky)
+        if(wpts[wpt->getKey()]->sticky)
         {
             delete wpt;
             return;
         }
         else
         {
-            delWpt(wpt->key(), true);
+            delWpt(wpt->getKey(), true);
         }
     }
-    wpts[wpt->key()] = wpt;
+    wpts[wpt->getKey()] = wpt;
 
     if(!silent)
     {
@@ -293,18 +351,41 @@ void CWptDB::setProxyDistance(const QStringList& keys, double dist)
     foreach(key,keys)
     {
         wpts[key]->prx = dist;
+        emit sigModified(key);
     }
     emit sigChanged();
     emit sigModified();
+
 }
 
+void CWptDB::setIcon(const QStringList& keys, const QString& iconName)
+{
+    QString key;
+    foreach(key,keys)
+    {
+        CWpt * wpt = wpts[key];
+
+        // no icon change for geocaches
+        if(!wpt->geocache.hasData)
+        {
+            wpt->setIcon(iconName);
+            emit sigModified(key);
+        }
+    }
+    emit sigChanged();
+    emit sigModified();
+
+}
 
 void CWptDB::loadGPX(CGpx& gpx)
 {
+    bool hasItems = false;
     const QDomNodeList& waypoints = gpx.elementsByTagName("wpt");
     uint N = waypoints.count();
+
     for(uint n = 0; n < N; ++n)
     {
+        hasItems = true;
         const QDomNode& waypoint = waypoints.item(n);
 
         CWpt * wpt = new CWpt(this);
@@ -322,7 +403,7 @@ void CWptDB::loadGPX(CGpx& gpx)
         }
         if(waypoint.namedItem("desc").isElement())
         {
-            wpt->comment = waypoint.namedItem("desc").toElement().text();
+            wpt->description = waypoint.namedItem("desc").toElement().text();
         }
         if(waypoint.namedItem("link").isElement())
         {
@@ -334,9 +415,13 @@ void CWptDB::loadGPX(CGpx& gpx)
         {
             wpt->link = waypoint.namedItem("url").toElement().text();
         }
+        if(waypoint.namedItem("urlname").isElement())
+        {
+            wpt->urlname = waypoint.namedItem("urlname").toElement().text();
+        }
         if(waypoint.namedItem("sym").isElement())
         {
-            wpt->icon =  waypoint.namedItem("sym").toElement().text();
+            wpt->setIcon(waypoint.namedItem("sym").toElement().text());
         }
         if(waypoint.namedItem("ele").isElement())
         {
@@ -347,13 +432,26 @@ void CWptDB::loadGPX(CGpx& gpx)
           QString timetext = waypoint.namedItem("time").toElement().text();
           (void)parseTimestamp(timetext, wpt->timestamp);
         }
+        if(waypoint.namedItem("type").isElement())
+        {
+            wpt->type = waypoint.namedItem("type").toElement().text();
+        }
+
+        if(waypoint.namedItem("parent").isElement())
+        {
+            wpt->setParentWpt(waypoint.namedItem("parent").toElement().text());
+        }
+
 
         if(waypoint.namedItem("extensions").isElement())
         {
+            QDomElement tmpelem;
             const QDomNode& ext = waypoint.namedItem("extensions");
             QMap<QString,QDomElement> extensionsmap = CGpx::mapChildElements(ext);
-            QDomElement tmpelem = extensionsmap.value(CGpx::gpxx_ns + ":" + "WaypointExtension");
 
+
+            // old garmin proximity format namespace
+            tmpelem = extensionsmap.value(CGpx::gpxx_ns + ":" + "WaypointExtension");
             if(!tmpelem.isNull())
             {
                 QMap<QString,QDomElement> waypointextensionmap = CGpx::mapChildElements(tmpelem);
@@ -365,6 +463,27 @@ void CWptDB::loadGPX(CGpx& gpx)
                 }
             }
 
+            // new garmin proximity format namespace
+            tmpelem = extensionsmap.value(CGpx::gpxwpx_ns + ":" + "WaypointExtension");
+            if(!tmpelem.isNull())
+            {
+                QMap<QString,QDomElement> waypointextensionmap = CGpx::mapChildElements(tmpelem);
+
+                tmpelem = waypointextensionmap.value(CGpx::gpxwpx_ns + ":" + "Proximity");
+                if(!tmpelem.isNull())
+                {
+                    wpt->prx = tmpelem.text().toDouble();
+                }
+            }
+
+
+            tmpelem = extensionsmap.value(CGpx::ql_ns + ":" + "parent");
+            if(!tmpelem.isNull())
+            {
+                wpt->setParentWpt(tmpelem.text());
+            }
+
+
             // QLandkarteGT backward compatibility
             if (gpx.version() == CGpx::qlVer_1_0)
             {
@@ -375,16 +494,23 @@ void CWptDB::loadGPX(CGpx& gpx)
             }
         }
 
-        if(wpt->lat == 1000 || wpt->lon == 1000 || wpt->name.isEmpty())
+        if(wpt->lat == 1000 || wpt->lon == 1000 || (wpt->name.isEmpty() && wpt->comment.isEmpty()))
         {
             delete wpt;
             continue;
         }
 
+        wpt->loadGpxExt(waypoint);
+
         addWpt(wpt, true);
     }
 
-    emit sigChanged();
+    CWpt::resetKeyCnt();
+
+    if(hasItems)
+    {
+        emit sigChanged();
+    }
 }
 
 
@@ -409,7 +535,7 @@ void CWptDB::saveGPX(CGpx& gpx, const QStringList& keys)
 
         // waypoint filtering
         // if keys list is not empty the waypoints key has to be in the list
-        if(!keys.isEmpty() && !keys.contains(wpt->key()))
+        if(!keys.isEmpty() && !keys.contains(wpt->getKey()))
         {
             ++_key;
             continue;
@@ -443,13 +569,27 @@ void CWptDB::saveGPX(CGpx& gpx, const QStringList& keys)
 
         if(!wpt->comment.isEmpty())
         {
+            QString comment = wpt->comment;
+            comment.remove(QRegExp("<head.*[^>]*><\\/head>"));
+            comment.remove(QRegExp("<[^>]*>"));
+            comment = comment.simplified();
+
+
             QDomElement cmt = gpx.createElement("cmt");
             waypoint.appendChild(cmt);
-            QDomText _cmt_ = gpx.createTextNode(wpt->comment);
+            QDomText _cmt_ = gpx.createTextNode(comment);
             cmt.appendChild(_cmt_);
         }
 
-        if(!wpt->link.isEmpty())
+        if(!wpt->description.isEmpty())
+        {
+            QDomElement desc = gpx.createElement("desc");
+            waypoint.appendChild(desc);
+            QDomText _desc_ = gpx.createTextNode(wpt->description);
+            desc.appendChild(_desc_);
+        }
+
+        if(!wpt->link.isEmpty() && wpt->urlname.isEmpty())
         {
             QDomElement link = gpx.createElement("link");
             waypoint.appendChild(link);
@@ -460,12 +600,46 @@ void CWptDB::saveGPX(CGpx& gpx, const QStringList& keys)
             text.appendChild(_text_);
         }
 
+        if(!wpt->link.isEmpty() && !wpt->urlname.isEmpty())
+        {
+            QDomElement url = gpx.createElement("url");
+            waypoint.appendChild(url);
+            QDomText _url_ = gpx.createTextNode(wpt->link);
+            url.appendChild(_url_);
+
+            QDomElement urlname = gpx.createElement("urlname");
+            waypoint.appendChild(urlname);
+            QDomText _urlname_ = gpx.createTextNode(wpt->urlname);
+            urlname.appendChild(_urlname_);
+        }
+
         QDomElement sym = gpx.createElement("sym");
         waypoint.appendChild(sym);
-        QDomText _sym_ = gpx.createTextNode(wpt->icon);
+        QDomText _sym_ = gpx.createTextNode(wpt->iconString);
         sym.appendChild(_sym_);
 
-        if(wpt->prx != 1e25f)
+        if(!wpt->type.isEmpty())
+        {
+            QDomElement type = gpx.createElement("type");
+            waypoint.appendChild(type);
+            QDomText _type_ = gpx.createTextNode(wpt->type);
+            type.appendChild(_type_);
+        }
+
+        if(gpx.getExportMode() == CGpx::eOcmExport)
+        {
+            if(!wpt->getParentWpt().isEmpty())
+            {
+                QDomElement parent = gpx.createElement("parent");
+                parent.setAttribute("xmlns", "http://opencachemanage.sourceforge.net/schema1");
+                waypoint.appendChild(parent);
+                QDomText _parent_ = gpx.createTextNode(wpt->getParentWpt());
+                parent.appendChild(_parent_);
+            }
+        }
+
+
+        if(wpt->prx != 1e25f || !wpt->getParentWpt().isEmpty())
         {
             QDomElement extensions = gpx.createElement("extensions");
             waypoint.appendChild(extensions);
@@ -479,14 +653,73 @@ void CWptDB::saveGPX(CGpx& gpx, const QStringList& keys)
                 QDomText _proximity_ = gpx.createTextNode(QString::number(wpt->prx));
                 proximity.appendChild(_proximity_);
             }
+
+
+            if(!wpt->getParentWpt().isEmpty() && (gpx.getExportMode() == CGpx::eQlgtExport))
+            {
+                QDomElement parent = gpx.createElement("ql:parent");
+                extensions.appendChild(parent);
+                QDomText _parent_ = gpx.createTextNode(wpt->getParentWpt());
+                parent.appendChild(_parent_);
+            }
         }
 
+        wpt->saveGpxExt(waypoint, gpx.getExportMode());
+
+        // export buddy waypoints
+        if(wpt->geocache.exportBuddies)
+        {
+            wpt->showBuddies(true);
+            const QList<CWpt::buddy_t>& buddies = wpt->buddies;
+            foreach(const CWpt::buddy_t& buddy, buddies)
+            {
+                QDomElement waypoint = gpx.createElement("wpt");
+                root.appendChild(waypoint);
+                str.sprintf("%1.8f", buddy.lat*RAD_TO_DEG);
+                waypoint.setAttribute("lat",str);
+                str.sprintf("%1.8f", buddy.lon*RAD_TO_DEG);
+                waypoint.setAttribute("lon",str);
+
+                QDomElement name = gpx.createElement("name");
+                waypoint.appendChild(name);
+                QDomText _name_ = gpx.createTextNode(buddy.name);
+                name.appendChild(_name_);
+
+                QDomElement sym = gpx.createElement("sym");
+                waypoint.appendChild(sym);
+                QDomText _sym_ = gpx.createTextNode("Civil");
+                sym.appendChild(_sym_);
+
+                if(gpx.getExportMode() == CGpx::eOcmExport)
+                {
+                    QDomElement parent = gpx.createElement("parent");
+                    parent.setAttribute("xmlns", "http://opencachemanage.sourceforge.net/schema1");
+                    waypoint.appendChild(parent);
+                    QDomText _parent_ = gpx.createTextNode(wpt->getName());
+                    parent.appendChild(_parent_);
+                }
+                else if(gpx.getExportMode() == CGpx::eQlgtExport)
+                {
+                    QDomElement extensions = gpx.createElement("extensions");
+                    waypoint.appendChild(extensions);
+
+                    QDomElement parent = gpx.createElement("ql:parent");
+                    extensions.appendChild(parent);
+                    QDomText _parent_ = gpx.createTextNode(wpt->getName());
+                    parent.appendChild(_parent_);
+                }
+            }
+
+            wpt->showBuddies(false);
+        }
+
+
         ++_key;
     }
 }
 
 
-void CWptDB::loadQLB(CQlb& qlb)
+void CWptDB::loadQLB(CQlb& qlb, bool newKey)
 {
     QDataStream stream(&qlb.waypoints(),QIODevice::ReadOnly);
     stream.setVersion(QDataStream::Qt_4_5);
@@ -495,10 +728,19 @@ void CWptDB::loadQLB(CQlb& qlb)
     {
         CWpt * wpt = new CWpt(this);
         stream >> *wpt;
+
+        if(newKey)
+        {
+            wpt->setKey(wpt->getKey() + QString("%1").arg(QDateTime::currentDateTime().toTime_t()));
+        }
+
         addWpt(wpt,true);
     }
 
-    emit sigChanged();
+    if(qlb.waypoints().size())
+    {
+        emit sigChanged();
+    }
 
 }
 
@@ -564,19 +806,43 @@ void CWptDB::download()
 }
 
 
-void CWptDB::selWptByKey(const QString& key)
+void CWptDB::selWptByKey(const QString& key, bool selectMode)
 {
     CWptToolWidget * t = qobject_cast<CWptToolWidget*>(toolview);
     if(t)
     {
+        if(selectMode && wpts.contains(key))
+        {
+            wpts[key]->selected =! wpts[key]->selected;
+        }
+
         t->selWptByKey(key);
+        gainFocus();
     }
 }
 
+//void CWptDB::updateToolview()
+//{
+//    CWptToolWidget * t = qobject_cast<CWptToolWidget*>(toolview);
+//    if(t)
+//    {
+//        t->slotDBChanged();
+//        gainFocus();
+//    }
+//}
+
 
 void CWptDB::draw(QPainter& p, const QRect& rect, bool& needsRedraw)
 {
     IMap& map = CMapDB::self().getMap();
+    QColor color = CResources::self().wptTextColor();
+
+    QPixmap pixOk(":/icons/iconOk10x10.png");
+
+    // added by AD
+    QList<QRect> blockAreas;
+    QFontMetrics fm(CResources::self().getMapFont());
+    // end added by AD
 
     QMap<QString,CWpt*>::const_iterator wpt = wpts.begin();
     while(wpt != wpts.end())
@@ -587,28 +853,146 @@ void CWptDB::draw(QPainter& p, const QRect& rect, bool& needsRedraw)
 
         if(rect.contains(QPoint(u,v)))
         {
-            QPixmap icon = getWptIconByName((*wpt)->icon);
+            QPixmap icon = (*wpt)->getIcon();
             QPixmap back = QPixmap(icon.size());
             back.fill(Qt::white);
             back.setMask(icon.alphaChannel().createMaskFromColor(Qt::black));
+
+            int o =  icon.width() >>1;
+
             // draw waypoint icon
-            p.drawPixmap(u-8 , v-8, back);
-            p.drawPixmap(u-8 , v-7, back);
-            p.drawPixmap(u-8 , v-6, back);
-            p.drawPixmap(u-7 , v-8, back);
 
-            p.drawPixmap(u-7 , v-6, back);
-            p.drawPixmap(u-6 , v-8, back);
-            p.drawPixmap(u-6 , v-7, back);
-            p.drawPixmap(u-6 , v-6, back);
+            p.drawPixmap(u - (o + 1) , v - (o + 1), back);
+            p.drawPixmap(u - (o + 1) , v - (o + 0), back);
+            p.drawPixmap(u - (o + 1) , v - (o - 1), back);
 
-            p.drawPixmap(u-7 , v-7, icon);
+            p.drawPixmap(u - (o + 0) , v - (o + 1), back);
+            p.drawPixmap(u - (o + 0) , v - (o - 1), back);
 
-            CCanvas::drawText((*wpt)->name,p,QPoint(u,v - 10));
+            p.drawPixmap(u - (o - 1) , v - (o + 1), back);
+            p.drawPixmap(u - (o - 1) , v - (o + 0), back);
+            p.drawPixmap(u - (o - 1) , v - (o - 1), back);
 
+            p.drawPixmap(u - o , v - o, icon);
+
+            if((*wpt)->selected)
+            {
+                p.setPen(Qt::NoPen);
+                p.setBrush(Qt::white);
+                p.drawEllipse(u - 2, v - 2, 14, 14);
+                p.drawPixmap(u, v, pixOk);
+            }
+
+            // added by AD
+            blockAreas << QRect(u - o , v - o, icon.width(), icon.height());
+        }
+
+        if(!(*wpt)->buddies.isEmpty())
+        {
+            QPixmap icon(":/icons/iconWaypoint16x16.png");
+            CWpt::buddy_t buddy;
+            QList<CWpt::buddy_t>& buddies = (*wpt)->buddies;
+            foreach(buddy, buddies)
+            {
+                double x = buddy.lon;
+                double y = buddy.lat;
+                map.convertRad2Pt(x,y);
+
+                p.setBrush(CCanvas::brushBackWhite);
+                p.setPen(CCanvas::penBorderBlue);
+                p.drawLine(u,v,x,y);
+                p.drawEllipse(QPoint(x,y),12,12);
+                p.drawPixmap(x - 8, y - 8, icon);
+            }
+        }
+
+        ++wpt;
+    }
+
+    // added by AD
+    // draw the labels
+    wpt = wpts.begin();
+    while(wpt != wpts.end())
+    {
+        double u = (*wpt)->lon * DEG_TO_RAD;
+        double v = (*wpt)->lat * DEG_TO_RAD;
+        map.convertRad2Pt(u,v);
+
+        if(rect.contains(QPoint(u,v)))
+        {
+            QPixmap icon = (*wpt)->getIcon();
+
+            if(showNames)
+            {
+                QString name;
+
+                if((*wpt)->isGeoCache())
+                {
+                    name = (*wpt)->getGeocacheData().name + " (" + (*wpt)->getName() + ")";
+                }
+                else
+                {
+                    name = (*wpt)->getName();
+                }
+
+                QRect textArea = fm.boundingRect(name);
+                bool intersects;
+
+                // try above
+                textArea.moveCenter(QPoint(u, v - (icon.height() >> 1) - textArea.height()));
+                intersects = false;
+                for (int k = 0; k < blockAreas.size() && !intersects; ++k)
+                {
+                    intersects = textArea.intersects(blockAreas.at(k));
+                }
+
+                if (intersects)
+                {
+                    // try below
+                    textArea.moveCenter(QPoint(u, v + ((icon.height() + textArea.height()) >> 1)));
+                    intersects = false;
+                    for (int k = 0; k < blockAreas.size() && !intersects; ++k)
+                    {
+                        intersects = textArea.intersects(blockAreas.at(k));
+                    }
+
+                    if (intersects)
+                    {
+                        // try right
+                        textArea.moveCenter(QPoint(u + ((icon.height() + textArea.height() + textArea.width()) >> 1),
+                                                   v - (textArea.height() >> 2)));
+                        intersects = false;
+                        for (int k = 0; k < blockAreas.size() && !intersects; ++k)
+                        {
+                            intersects = textArea.intersects(blockAreas.at(k));
+                        }
+
+                        if (intersects)
+                        {
+                            // try left
+                            textArea.moveCenter(QPoint(u - ((icon.height() + (textArea.height() >> 1) + textArea.width()) >> 1),
+                                                       v - (textArea.height() >> 2)));
+                            intersects = false;
+                            for (int k = 0; k < blockAreas.size() && !intersects; ++k)
+                            {
+                                intersects = textArea.intersects(blockAreas.at(k));
+                            }
+                        }
+                    }
+                }
+
+                if (!intersects)
+                {
+                    blockAreas << textArea;
+                    // compensate for drawText magic and plot
+                    textArea.translate(0, textArea.height());
+                    CCanvas::drawText(name, p, textArea.center(), color);
+                }
+            }
         }
         ++wpt;
     }
+    // end added by AD
 
     wpt = wpts.begin();
     while(wpt != wpts.end())
@@ -750,7 +1134,7 @@ void CWptDB::createWaypointsFromImages()
 
     QSettings cfg;
     QString path = cfg.value("path/images", "./").toString();
-    path = QFileDialog::getExistingDirectory(0, tr("Select path..."), path, QFileDialog::DontUseNativeDialog);
+    path = QFileDialog::getExistingDirectory(0, tr("Select path..."), path, FILE_DIALOG_FLAGS);
 
     if(path.isEmpty()) return;
 
@@ -762,10 +1146,19 @@ void CWptDB::createWaypointsFromImages()
     QStringList files = dir.entryList(filter, QDir::Files);
     QString file;
 
+    quint32 progCnt = 0;
+    QProgressDialog progress(tr("Read EXIF tags from pictures."), tr("Abort"), 0, files.size());
+
+
     foreach(file, files)
     {
         //         qDebug() << "---------------" << file << "---------------";
 
+        progress.setValue(progCnt++);
+        if (progress.wasCanceled()) break;
+        qApp->processEvents();
+
+
         ExifData * exifData = f_exif_data_new_from_file(dir.filePath(file).toLocal8Bit());
 
         exifGPS_t exifGPS;
@@ -774,9 +1167,9 @@ void CWptDB::createWaypointsFromImages()
 
         CWpt * wpt      = new CWpt(this);
         wpt->lon        = exifGPS.lon * exifGPS.lon_sign;
-        wpt->lat        = exifGPS.lat * exifGPS.lon_sign;
+        wpt->lat        = exifGPS.lat * exifGPS.lat_sign;
         wpt->timestamp  = exifGPS.timestamp;
-        wpt->icon       = "Flag, Red";
+        wpt->setIcon("Flag, Red");
         wpt->name       = file;
 
         qDebug() << wpt->name << wpt->lon << wpt->lat;
@@ -810,3 +1203,55 @@ void CWptDB::createWaypointsFromImages()
     emit sigModified();
 }
 #endif
+
+void CWptDB::makeVisible(const QStringList& keys)
+{
+
+
+    if(keys.isEmpty())
+    {
+        return;
+    }
+
+    QRectF r;
+    QString key;
+    foreach(key, keys)
+    {
+
+        CWpt * wpt =  wpts[key];
+
+        if(r.isNull())
+        {
+            r = QRectF(wpt->lon, wpt->lat, 0.0001, 0.0001);
+        }
+        else
+        {
+            r |= QRectF(wpt->lon, wpt->lat, 0.0001, 0.0001);
+        }
+
+    }
+
+    if (!r.isNull ())
+    {
+        CMapDB::self().getMap().zoom(r.left() * DEG_TO_RAD, r.top() * DEG_TO_RAD, r.right() * DEG_TO_RAD, r.bottom() * DEG_TO_RAD);
+    }
+
+
+}
+
+void CWptDB::getListOfGeoCaches(QStringList& caches)
+{
+    keys_t _key_;
+    QList<CWptDB::keys_t> _keys_ = keys();
+
+    caches.clear();
+
+    foreach(_key_, _keys_)
+    {
+        if(_key_.isCache)
+        {
+            caches << _key_.name;
+        }
+    }
+
+}
