@@ -44,7 +44,7 @@ class CWptDB : public IDB
         /// get iterator access to track point list
         QMap<QString,CWpt*> ::iterator end(){return wpts.end();}
 
-        struct keys_t{QString key; QString name; QString comment; QString icon; qreal lon; qreal lat; qreal d;};
+        struct keys_t{QString key; QString name; quint32 time; QString comment; QString icon; qreal lon; qreal lat; qreal d; bool isCache;};
 
         /// get all keys in the database
         QList<keys_t> keys();
@@ -59,7 +59,7 @@ class CWptDB : public IDB
 
             @return A temporary pointer to the waypoint object or 0 if the waypoint dialog was canceled.
         */
-        CWpt * newWpt(float lon, float lat, float ele);
+        CWpt * newWpt(float lon, float lat, float ele, const QString& name);
 
         /// get pointer access to waypoint via it's key
         CWpt * getWptByKey(const QString& key);
@@ -70,19 +70,22 @@ class CWptDB : public IDB
         void delWpt(const QString& key, bool silent = false, bool saveSticky = true);
 
         void setProxyDistance(const QStringList& keys, double dist);
+        void setIcon(const QStringList& keys, const QString& iconName);
 
         void loadGPX(CGpx& gpx);
         void saveGPX(CGpx& gpx, const QStringList& keys);
-        void loadQLB(CQlb& qlb);
+        void loadQLB(CQlb& qlb, bool newKey);
         void saveQLB(CQlb& qlb);
 
         void upload(const QStringList& keys);
         void download();
         void clear();
-        void selWptByKey(const QString& key);
+        void selWptByKey(const QString& key, bool selectMode);
+        void makeVisible(const QStringList& keys);
 
         int count(){return wpts.count();}
 
+
 #ifdef HAS_EXIF
         void createWaypointsFromImages();
 
@@ -103,8 +106,14 @@ class CWptDB : public IDB
         static bool keyLessThanComment(CWptDB::keys_t&  s1, CWptDB::keys_t&  s2);
         static bool keyLessThanIcon(CWptDB::keys_t&  s1, CWptDB::keys_t&  s2);
         static bool keyLessThanDistance(CWptDB::keys_t&  s1, CWptDB::keys_t&  s2);
+        static bool keyLessThanTime(CWptDB::keys_t&  s1, CWptDB::keys_t&  s2);
 
+        bool getShowNames(){return showNames;}
+        void setShowNames(bool yes){showNames = yes;  emit sigChanged();}
 
+        void getListOfGeoCaches(QStringList& caches);
+
+        bool contains(const QString& key){return wpts.contains(key);}
 
     private:
         friend class CMainWindow;
@@ -117,5 +126,7 @@ class CWptDB : public IDB
 
         QMap<QString,CWpt*> wpts;
 
+        bool showNames;
+
 };
 #endif                           //CWPTDB_H
