@@ -30,6 +30,8 @@
 #include "GeoMath.h"
 #include "IUnit.h"
 #include "CMapDB.h"
+#include "CDlgWpt2Rte.h"
+#include "CDlgWptIcon.h"
 
 #include <QtGui>
 
@@ -41,23 +43,34 @@ CWptToolWidget::CWptToolWidget(QTabWidget * parent)
 {
     setupUi(this);
     setObjectName("Waypoints");
-    parent->addTab(this,QIcon(":/icons/iconWaypoint16x16"),"");
+    parent->addTab(this,QIcon(":/icons/iconWaypoint16x16.png"),"");
     parent->setTabToolTip(parent->indexOf(this), tr("Waypoints"));
 
     connect(&CWptDB::self(), SIGNAL(sigChanged()), this, SLOT(slotDBChanged()));
-    connect(listWpts,SIGNAL(itemDoubleClicked(QListWidgetItem*)),this,SLOT(slotItemClicked(QListWidgetItem*)));
+    connect(listWpts,SIGNAL(itemDoubleClicked(QListWidgetItem*)),this,SLOT(slotItemDoubleClicked(QListWidgetItem*)));
+    connect(listWpts,SIGNAL(itemClicked(QListWidgetItem*)),this,SLOT(slotItemClicked(QListWidgetItem*)));
 
     listWpts->setSortingEnabled(false);
 
     contextMenu     = new QMenu(this);
-    actCopyPos      = contextMenu->addAction(QPixmap(":/icons/iconClipboard16x16.png"),tr("Copy Position"),this,SLOT(slotCopyPosition()),Qt::CTRL + Qt::Key_C);
     actEdit         = contextMenu->addAction(QPixmap(":/icons/iconEdit16x16.png"),tr("Edit..."),this,SLOT(slotEdit()));
+    actCopyPos      = contextMenu->addAction(QPixmap(":/icons/iconClipboard16x16.png"),tr("Copy Position"),this,SLOT(slotCopyPosition()),Qt::CTRL + Qt::Key_C);
+    contextMenu->addSeparator();
     actProximity    = contextMenu->addAction(QPixmap(":/icons/iconProximity16x16.png"),tr("Proximity ..."),this,SLOT(slotProximity()));
+    actIcon         = contextMenu->addAction(QPixmap(":/icons/iconWaypoint16x16.png"),tr("Icon ..."),this,SLOT(slotIcon()));
     actMakeRte      = contextMenu->addAction(QPixmap(":/icons/iconRoute16x16.png"),tr("Make Route ..."),this,SLOT(slotMakeRoute()));
-    actZoomToFit    = contextMenu->addAction(QPixmap(":/icons/iconZoomArea16x16.png"),tr("Zoom to fit"),this,SLOT(slotZoomToFit()));
+    actResetSel     = contextMenu->addAction(QPixmap(":/icons/iconClear16x16.png"),tr("Reset selection"),this,SLOT(slotResetSel()));
+    contextMenu->addSeparator();
+    actShowNames    = contextMenu->addAction(tr("Show Names"),this,SLOT(slotShowNames()));
+    contextMenu->addSeparator();
+    actZoomToFit    = contextMenu->addAction(QPixmap(":/icons/iconZoomArea16x16.png"),tr("Zoom to fit"),this,SLOT(slotZoomToFit()));    
     actDelete       = contextMenu->addAction(QPixmap(":/icons/iconClear16x16.png"),tr("Delete"),this,SLOT(slotDelete()),Qt::CTRL + Qt::Key_Delete);
+    actDeleteNonSel = contextMenu->addAction(QPixmap(":/icons/iconClear16x16.png"),tr("Delete non-selected"),this,SLOT(slotDeleteNonSel()));
     actDeleteBy     = contextMenu->addAction(QPixmap(":/icons/iconClear16x16.png"),tr("Delete by ..."),this,SLOT(slotDeleteBy()));
 
+    actShowNames->setCheckable(true);
+    actShowNames->setChecked(CWptDB::self().getShowNames());
+
     connect(listWpts,SIGNAL(customContextMenuRequested(const QPoint&)),this,SLOT(slotContextMenu(const QPoint&)));
 
 
@@ -65,16 +78,20 @@ CWptToolWidget::CWptToolWidget(QTabWidget * parent)
     toolSortComment->setIcon(QPixmap(":/icons/iconText16x16.png"));
     toolSortIcon->setIcon(QPixmap(":/icons/iconWaypoint16x16.png"));
     toolSortPosition->setIcon(QPixmap(":/icons/iconLiveLog16x16.png"));
+    toolSortTime->setIcon(QPixmap(":/icons/iconTime16x16.png"));
+
+    connect(toolSortAlpha, SIGNAL(clicked()), SIGNAL(sigChanged()));
+    connect(toolSortComment, SIGNAL(clicked()), SIGNAL(sigChanged()));
+    connect(toolSortIcon, SIGNAL(clicked()),SIGNAL(sigChanged()));
+    connect(toolSortPosition, SIGNAL(clicked()), SIGNAL(sigChanged()));
+    connect(toolSortTime, SIGNAL(clicked()), SIGNAL(sigChanged()));
 
-    connect(toolSortAlpha, SIGNAL(clicked()), this, SLOT(slotDBChanged()));
-    connect(toolSortComment, SIGNAL(clicked()), this, SLOT(slotDBChanged()));
-    connect(toolSortIcon, SIGNAL(clicked()), this, SLOT(slotDBChanged()));
-    connect(toolSortPosition, SIGNAL(clicked()), this, SLOT(slotDBChanged()));
 
     connect(linePosition, SIGNAL(textChanged(const QString&)), this, SLOT(slotPosTextChanged(const QString&)));
 
     QSettings cfg;
     toolSortAlpha->setChecked(cfg.value("waypoint/sortAlpha", true).toBool());
+    toolSortTime->setChecked(cfg.value("waypoint/sortTime", true).toBool());
     toolSortComment->setChecked(cfg.value("waypoint/sortComment", true).toBool());
     toolSortIcon->setChecked(cfg.value("waypoint/sortIcon", false).toBool());
     toolSortPosition->setChecked(cfg.value("waypoint/sortPosition", false).toBool());
@@ -87,12 +104,28 @@ CWptToolWidget::~CWptToolWidget()
 {
     QSettings cfg;
     cfg.setValue("waypoint/sortAlpha", toolSortAlpha->isChecked());
+    cfg.setValue("waypoint/sortTime", toolSortTime->isChecked());
     cfg.setValue("waypoint/sortComment", toolSortComment->isChecked());
     cfg.setValue("waypoint/sortIcon", toolSortIcon->isChecked());
     cfg.setValue("waypoint/sortPosition", toolSortPosition->isChecked());
     cfg.setValue("waypoint/position", linePosition->text());
 }
 
+void CWptToolWidget::collectSelectedWaypoints(QList<CWpt*>& selWpts)
+{
+    CWptDB::keys_t key;
+    QList<CWptDB::keys_t> keys = CWptDB::self().keys();
+
+    foreach(key, keys)
+    {
+        CWpt * wpt = CWptDB::self().getWptByKey(key.key);
+
+        if(wpt->selected)
+        {
+            selWpts << wpt;
+        }
+    }
+}
 
 void CWptToolWidget::keyPressEvent(QKeyEvent * e)
 {
@@ -126,6 +159,10 @@ void CWptToolWidget::slotDBChanged()
     {
         sortmode = eSortByName;
     }
+    else if(toolSortTime->isChecked())
+    {
+        sortmode = eSortByTime;
+    }
     else if(toolSortComment->isChecked())
     {
         sortmode = eSortByComment;
@@ -151,8 +188,8 @@ void CWptToolWidget::slotDBChanged()
         CWpt * wpt = CWptDB::self().getWptByKey(key.key);
 
         QListWidgetItem * item = new QListWidgetItem(listWpts);
-        item->setIcon(getWptIconByName(wpt->icon));
-        item->setData(Qt::UserRole, wpt->key());
+        item->setIcon(wpt->getIcon().scaled(16,16,Qt::IgnoreAspectRatio, Qt::SmoothTransformation));
+        item->setData(Qt::UserRole, wpt->getKey());
 
         if(toolSortComment->isChecked())
         {
@@ -162,15 +199,10 @@ void CWptToolWidget::slotDBChanged()
             {
                 name = key.name;
             }
-            else
-            {
-                item->setToolTip(key.name);
-            }
         }
         else
         {
             name = key.name;
-            item->setToolTip(key.comment);
         }
 
         if(wpt->sticky)
@@ -188,12 +220,15 @@ void CWptToolWidget::slotDBChanged()
         {
             item->setText(name);
         }
+
+        item->setToolTip(wpt->getInfo());
+        item->setCheckState(wpt->selected ? Qt::Checked : Qt::Unchecked);
     }
 }
 
 
-void CWptToolWidget::slotItemClicked(QListWidgetItem* item)
-{
+void CWptToolWidget::slotItemDoubleClicked(QListWidgetItem* item)
+{    
     CWpt * wpt = CWptDB::self().getWptByKey(item->data(Qt::UserRole).toString());
     if(wpt)
     {
@@ -201,24 +236,34 @@ void CWptToolWidget::slotItemClicked(QListWidgetItem* item)
     }
 }
 
+void CWptToolWidget::slotItemClicked(QListWidgetItem* item)
+{
+    CWpt * wpt = CWptDB::self().getWptByKey(item->data(Qt::UserRole).toString());
+    if(wpt)
+    {
+        wpt->selected = item->checkState() == Qt::Checked;
+    }
+}
+
 
 void CWptToolWidget::slotContextMenu(const QPoint& pos)
 {
-    int cnt = listWpts->selectedItems().count();
+    QList<CWpt*> selWpts;
+    collectSelectedWaypoints(selWpts);
+    actDeleteNonSel->setEnabled(!selWpts.isEmpty());
 
+    int cnt = listWpts->selectedItems().count();
     if(cnt > 0)
     {
         if(cnt > 1)
         {
             actCopyPos->setEnabled(false);
             actEdit->setEnabled(false);
-            actMakeRte->setEnabled(true);
         }
         else
         {
             actCopyPos->setEnabled(true);
             actEdit->setEnabled(true);
-            actMakeRte->setEnabled(false);
         }
 
         QPoint p = listWpts->mapToGlobal(pos);
@@ -241,15 +286,47 @@ void CWptToolWidget::slotEdit()
 void CWptToolWidget::slotDelete()
 {
     QStringList keys;
-    QListWidgetItem * item;
-    const QList<QListWidgetItem*>& items = listWpts->selectedItems();
-    foreach(item,items)
+    QList<CWpt*> selWpts;
+    collectSelectedWaypoints(selWpts);
+
+    if(selWpts.isEmpty())
     {
-        keys << item->data(Qt::UserRole).toString();
+
+        QListWidgetItem * item;
+        const QList<QListWidgetItem*>& items = listWpts->selectedItems();
+        foreach(item,items)
+        {
+            keys << item->data(Qt::UserRole).toString();
+        }
+    }
+    else
+    {
+        foreach(CWpt* wpt, selWpts)
+        {
+            keys << wpt->getKey();
+        }
     }
     CWptDB::self().delWpt(keys, false);
 }
 
+void CWptToolWidget::slotDeleteNonSel()
+{
+    QStringList nonSelWpts;
+    CWptDB::keys_t key;
+    QList<CWptDB::keys_t> keys = CWptDB::self().keys();
+
+    foreach(key, keys)
+    {
+        CWpt * wpt = CWptDB::self().getWptByKey(key.key);
+
+        if(!wpt->selected)
+        {
+            nonSelWpts << wpt->getKey();
+        }
+    }
+
+    CWptDB::self().delWpt(nonSelWpts);
+}
 
 void CWptToolWidget::slotDeleteBy()
 {
@@ -277,21 +354,14 @@ void CWptToolWidget::slotCopyPosition()
 void CWptToolWidget::slotZoomToFit()
 {
 
-    const QList<QListWidgetItem*>& items = listWpts->selectedItems();
-    QList<QListWidgetItem*>::const_iterator item = items.begin();
-
-    CWpt * wpt = CWptDB::self().getWptByKey((*item)->data(Qt::UserRole).toString());
-
-    QRectF r(wpt->lon, wpt->lat, 0.001, 0.001);
-
-    while(item != items.end())
+    QStringList keys;
+    QList<QListWidgetItem*> items = listWpts->selectedItems();
+    QListWidgetItem* item;
+    foreach(item, items)
     {
-        wpt = CWptDB::self().getWptByKey((*item)->data(Qt::UserRole).toString());
-        r |= QRectF(wpt->lon, wpt->lat, 0.001, 0.001);
-        ++item;
+        keys << item->data(Qt::UserRole).toString();
     }
-
-    CMapDB::self().getMap().zoom(r.left() * DEG_TO_RAD, r.top() * DEG_TO_RAD, r.right() * DEG_TO_RAD, r.bottom() * DEG_TO_RAD);
+    CWptDB::self().makeVisible(keys);
 }
 
 
@@ -302,7 +372,13 @@ void CWptToolWidget::selWptByKey(const QString& key)
         QListWidgetItem * item = listWpts->item(i);
         if(item && item->data(Qt::UserRole) == key)
         {
-            listWpts->setCurrentItem(item);
+            CWpt * wpt = CWptDB::self().getWptByKey(key);
+            if(wpt)
+            {
+                item->setCheckState(wpt->selected ? Qt::Checked : Qt::Unchecked);
+            }
+
+            listWpts->setCurrentItem(item);            
         }
     }
 }
@@ -335,37 +411,102 @@ void CWptToolWidget::slotProximity()
         dist = IUnit::self().str2distance(str);
 
         QStringList keys;
-        foreach(item,items)
+        QList<CWpt*> selWpts;
+        collectSelectedWaypoints(selWpts);
+
+        if(selWpts.count())
         {
-            keys << item->data(Qt::UserRole).toString();
+            foreach(CWpt* wpt, selWpts)
+            {
+                keys << wpt->getKey();
+            }
+        }
+        else
+        {
+            foreach(item,items)
+            {
+                keys << item->data(Qt::UserRole).toString();
+            }
         }
         CWptDB::self().setProxyDistance(keys,(dist == 0 ? WPT_NOFLOAT : dist));
     }
 }
 
 
+void CWptToolWidget::slotIcon()
+{
+    QToolButton button(this);
+    button.hide();
+
+    CDlgWptIcon dlg(button);
+    dlg.exec();
+
+    if(!button.objectName().isEmpty())
+    {
+        QStringList keys;
+        QList<CWpt*> selWpts;
+        collectSelectedWaypoints(selWpts);
+
+        if(selWpts.count())
+        {
+            foreach(CWpt* wpt, selWpts)
+            {
+                keys << wpt->getKey();
+            }
+        }
+        else
+        {
+            QListWidgetItem * item;
+            const QList<QListWidgetItem*>& items = listWpts->selectedItems();
+
+            foreach(item,items)
+            {
+                keys << item->data(Qt::UserRole).toString();
+            }
+        }
+        CWptDB::self().setIcon(keys,button.objectName());
+    }
+}
+
+
 void CWptToolWidget::slotMakeRoute()
 {
-    const QList<QListWidgetItem*>& items = listWpts->selectedItems();
-    if(items.count() < 2) return;
+    QList<CWpt*> selWpts;
+    collectSelectedWaypoints(selWpts);
 
-    CRoute * route = new CRoute(&CRouteDB::self());
-
-    QListWidgetItem * item;
-    foreach(item,items)
-    {
-        CWpt * wpt = CWptDB::self().getWptByKey(item->data(Qt::UserRole).toString());
-        if(wpt)
-        {
-            route->addPosition(wpt->lon, wpt->lat);
-        }
-    }
-
-    CRouteDB::self().addRoute(route, false);
+    CDlgWpt2Rte dlg(selWpts);
+    dlg.exec();
 }
 
+
 void CWptToolWidget::slotPosTextChanged(const QString& text)
 {
-    float lon = 0, lat = 0;
-    toolSortPosition->setEnabled(GPS_Math_Str_To_Deg(text, lon, lat, true));
+    float lon   = 0, lat = 0;
+    bool ok     = GPS_Math_Str_To_Deg(text, lon, lat, true);
+    toolSortPosition->setEnabled(ok);
+    if(ok)
+    {
+        slotDBChanged();
+    }
+}
+
+void CWptToolWidget::slotShowNames()
+{
+    CWptDB::self().setShowNames(!CWptDB::self().getShowNames());
+}
+
+
+void CWptToolWidget::slotResetSel()
+{
+    CWptDB::keys_t key;
+    QList<CWptDB::keys_t> keys = CWptDB::self().keys();
+
+    foreach(key, keys)
+    {
+        CWpt * wpt = CWptDB::self().getWptByKey(key.key);
+        wpt->selected = false;
+    }
+
+    slotDBChanged();
+    theMainWindow->getCanvas()->update();
 }
