@@ -26,7 +26,7 @@
 #include <stdio.h>
 #include <string.h>
 
-#define DBG
+#undef DBG
 
 IGarminTyp::IGarminTyp(format_e format, QObject * parent)
 : QObject(parent)
@@ -192,7 +192,7 @@ bool IGarminTyp::parsePolygon(QDataStream& in, QMap<quint32, polygon_property>&
     {
         quint16 t16_1, t16_2, subtyp;
         quint8  t8;
-        quint32 typ, offset;
+        quint32 typ, offset=0;
         bool hasLocalization = false;
         bool hasTextColor = false;
         quint8 ctyp;
@@ -483,7 +483,7 @@ bool IGarminTyp::parsePolyline(QDataStream& in, QMap<quint32, polyline_property>
     {
         quint16 t16_1, t16_2, subtyp;
         quint8  t8_1, t8_2;
-        quint32 typ, offset;
+        quint32 typ, offset=0;
         bool hasLocalization = false;
         bool hasTextColor = false;
         bool renderMode = false;
@@ -777,6 +777,8 @@ bool IGarminTyp::parsePolyline(QDataStream& in, QMap<quint32, polyline_property>
                 qDebug() << "Failed polyline" <<  hex << ":" << typ <<  ctyp << rows ;
                 continue;
         }
+        property.imgDay     = property.imgDay.convertToFormat(QImage::Format_ARGB32_Premultiplied);
+        property.imgNight   = property.imgNight.convertToFormat(QImage::Format_ARGB32_Premultiplied);
         if(hasLocalization)
         {
             qint16 len;
@@ -994,6 +996,9 @@ void IGarminTyp::decodeBitmap(QDataStream &in, QImage &img, int w, int h, int bp
 {
     int x = 0,j = 0;
     quint8 color;
+
+    if(bpp == 0) return;
+
     for (int y = 0; y < h; y++)
     {
         while ( x < w )
@@ -1027,7 +1032,7 @@ void IGarminTyp::decodeBitmap(QDataStream &in, QImage &img, int w, int h, int bp
 
 bool IGarminTyp::parsePoint(QDataStream& in, QMap<quint32, point_property>& points)
 {
-    bool tainted = false;
+    //    bool tainted = false;
 
     if(!sectPoints.arrayModulo || ((sectPoints.arraySize % sectPoints.arrayModulo) != 0))
     {
@@ -1041,7 +1046,7 @@ bool IGarminTyp::parsePoint(QDataStream& in, QMap<quint32, point_property>& poin
     {
         quint16 t16_1, t16_2, subtyp;
         quint8  t8_1;
-        quint32 typ, offset;
+        quint32 typ, offset=0;
         bool hasLocalization = false;
         bool hasTextColor = false;
         quint8 langcode;
