@@ -19,25 +19,41 @@
 #ifndef IMAPSELECTION_H
 #define IMAPSELECTION_H
 
+#include "IItem.h"
+
 #include <QString>
 #include <QObject>
+#include <QMap>
+#include <QPair>
 class QPainter;
 class QRect;
 
-class IMapSelection : public QObject
+
+#define TILESIZE 1024
+
+class IMapSelection : public IItem
 {
     Q_OBJECT;
     public:
+        enum head_type_e {eHeadEnd,eHeadBase,eHeadRaster,eHeadGarmin};
+        struct sel_head_entry_t
+        {
+            sel_head_entry_t() : type(eHeadEnd), offset(0) {}
+            qint32      type;
+            quint32     offset;
+            QByteArray  data;
+        };
+
         enum type_e {eNone, eRaster, eGarmin};
 
-        IMapSelection(type_e type, QObject * parent) : QObject(parent), type(type), lon1(0), lat1(0), lon2(0), lat2(0){};
+        IMapSelection(type_e type, QObject * parent) : IItem(parent), type(type), lon1(0), lat1(0), lon2(0), lat2(0){}
         virtual ~IMapSelection(){}
 
-        void operator=(const IMapSelection& ms)
+        void operator=(IMapSelection& ms)
         {
-            key         = ms.key;
+            setKey(ms.getKey());
             mapkey      = ms.mapkey;
-            description = ms.description;
+            name        = ms.name;
 
             lon1        = ms.lon1;
             lat1        = ms.lat1;
@@ -45,20 +61,27 @@ class IMapSelection : public QObject
             lat2        = ms.lat2;
         }
 
-        virtual void draw(QPainter& p, const QRect& rect){};
+        virtual QDataStream& operator>>(QDataStream&) = 0;
+
+        virtual void draw(QPainter& p, const QRect& rect){}
 
         virtual bool isEmpty(){return false;}
 
+        void setTimestamp(quint32 t){timestamp = t;}
+
         static QString focusedMap;
 
         type_e type;
-        QString key;
         QString mapkey;
-        QString description;
 
         double lon1;             ///< top left longitude [rad]
         double lat1;             ///< top left latitude [rad]
         double lon2;             ///< bottom right longitude [rad]
         double lat2;             ///< bottom right latitude [rad]
+
+
+        QRect rect();
+
+
 };
 #endif                           //IMAPSELECTION_H
