@@ -90,9 +90,11 @@ QDataStream& operator >>(QDataStream& s, COverlayDB& db)
                 }
                 else if(type == "Distance")
                 {
+                    IOverlay * ovl;
                     float speed;
                     QString name;
                     QString comment;
+                    QString parentWpt;
                     int size, idx = 0;
                     COverlayDistance::pt_t pt;
                     QList<COverlayDistance::pt_t> points;
@@ -103,8 +105,9 @@ QDataStream& operator >>(QDataStream& s, COverlayDB& db)
                         pt.idx = idx++;
                         points << pt;
                     }
-                    s1 >> speed >> key;
-                    db.addDistance(name, comment, speed, points, key);
+                    s1 >> speed >> key >> parentWpt;
+                    ovl = db.addDistance(name, comment, speed, points, key);
+                    ovl->setParentWpt(parentWpt);
                 }
                 break;
             }
@@ -199,15 +202,14 @@ void operator <<(QFile& f, IOverlay& ovl)
 
 
 QPointer<IOverlay> IOverlay::selected = 0;
-int IOverlay::count = 0;
 
-IOverlay::IOverlay(QObject * parent, const QString& type, const QPixmap& icon)
-: QObject(parent)
+IOverlay::IOverlay(QObject * parent, const QString& type, const QString& iconString)
+: IItem(parent)
 , type(type)
-, icon(icon)
 , highlight(false)
+, isVisible(true)
 {
-
+    setIcon(iconString);
 }
 
 
@@ -222,14 +224,8 @@ void IOverlay::select(IOverlay * s)
     selected = s;
 }
 
-void IOverlay::genKey()
+void IOverlay::setIcon(const QString& str)
 {
-    _key_ = QString("%1%2%3").arg(type).arg(QDateTime::currentDateTime().toString()).arg(count++);
-}
-
-
-const QString& IOverlay::key()
-{
-    if(_key_.isEmpty()) genKey();
-    return _key_;
+    iconPixmap = QPixmap(str);
+    iconString = str;
 }
