@@ -168,20 +168,22 @@ int main(int argc, char ** argv)
 #endif
     QApplication theApp(argc,argv);
     processOptions();
+#ifndef WIN32
     qInstallMsgHandler(myMessageOutput);
+#endif
 
 #ifdef ENABLE_TRANSLATION
     {
         QString resourceDir = QLibraryInfo::location(QLibraryInfo::TranslationsPath);
         QTranslator *qtTranslator = new QTranslator(0);
         if (qtTranslator->load(QLatin1String("qt_") + locale,resourceDir))
-		{
+        {
             theApp.installTranslator(qtTranslator);
-		}
-		else if (qtTranslator->load(QLatin1String("qt_") + locale,QCoreApplication::applicationDirPath()))
-		{
-			theApp.installTranslator(qtTranslator);
-		}
+        }
+        else if (qtTranslator->load(QLatin1String("qt_") + locale,QCoreApplication::applicationDirPath()))
+        {
+            theApp.installTranslator(qtTranslator);
+        }
 
         QStringList dirList;
 #ifndef Q_WS_MAC
@@ -234,6 +236,7 @@ int main(int argc, char ** argv)
     QCoreApplication::setApplicationName("QLandkarteGT");
     QCoreApplication::setOrganizationName("QLandkarteGT");
     QCoreApplication::setOrganizationDomain("qlandkarte.org");
+    QApplication::setWindowIcon(QIcon(":/icons/qlandkartegt.png"));
 
 #ifdef WIN32
     QCoreApplication::addLibraryPath(QCoreApplication::applicationDirPath());
@@ -245,9 +248,6 @@ int main(int argc, char ** argv)
     if (!qlOpts->nosplash)
     {
         splash = new QSplashScreen(QPixmap(":/pics/splash.png"));
-#if defined(Q_WS_MAC)
-        splash->setWindowFlags(Qt::WindowStaysOnTopHint | Qt::SplashScreen);
-#endif
         splash->show();
     }
     CMainWindow w;
@@ -265,8 +265,6 @@ int main(int argc, char ** argv)
 
     int res  = theApp.exec();
 
-    GDALDestroyDriverManager();
-
     delete qlOpts;
 
     return res;
